library("lsmeans")
library(lme4)

#####SETTING UP THE DATA#####
#'load already set up haploid data files
nys <- read.csv("GrowthRateAssays/data_output/lgrNys2Haps.csv", sep=",", as.is=TRUE)
ypd <- read.csv("GrowthRateAssays/data_output/lgrYPDHaps.csv", sep=",", as.is=TRUE)

#'remove omits, outliers
nys <- nys[is.na(nys$omit)&is.na(nys$out),]
ypd <- ypd[is.na(ypd$omit)&is.na(ypd$out),]

#####T-TESTS BETWEEN STRAINS WITH AND WITHOUT DSC2 MUTATION#####
#'possible strains: erg7, erg5 erg7
#'nystatin2
#'erg7
t.test(nys[nys$Line=="12a",]$lgr.nys, nys[nys$Line=="12l",]$lgr.nys, alternative="two.sided")
#results of Welch two sample t-test: t = -0.37608, df = 49.558, p-value = 0.7085

#'erg5 erg7
t.test(nys[nys$Line=="1258a",]$lgr.nys, nys[nys$Line=="1258l",]$lgr.nys, alternative="two.sided")
#results of Welch two sample t-test: t = -1.0076, df = 37.656, p-value = 0.3201

#'ypd
#'erg7
t.test(ypd[ypd$Line=="12a",]$lgr.ypd, ypd[ypd$Line=="12l",]$lgr.ypd, alternative="two.sided")
#results of Welch two sample t-test: t = 0.27337, df = 50, p-value = 0.7857

#'erg5 erg7
t.test(ypd[ypd$Line=="1258a",]$lgr.ypd, ypd[ypd$Line=="1258l",]$lgr.ypd, alternative="two.sided")
#results of Welch two sample t-test: t = -2.3195, df = 35.971, p-value = 0.02616
#'erg5 erg7 matalpha strain (wt for mutation in dsc2) has a higher growth rate in ypd

#'plot the difference between erg5 erg7 mata and matalpha
boxplot(lgr.ypd~Line, dat=ypd[ypd$Line=="1258l"|ypd$Line=="1258a",], ylab="Max growth rate in YPD")
stripchart(lgr.ypd~Line, dat=ypd[ypd$Line=="1258l"|ypd$Line=="1258a",], vertical=TRUE, method="jitter", add=TRUE, pch=20)
#'different from each other, but the effect size is not very big

#'repeat t-tests, averaging by day (less pseudoreplication)
nys.ag <- aggregate(nys["lgr.nys"], nys[c("Line","Day")], mean)
ypd.ag <- aggregate(ypd["lgr.ypd"], ypd[c("Line","Day")], mean)

#'nystatin2
#'erg7
t.test(nys.ag[nys.ag$Line=="12a",]$lgr.nys, nys.ag[nys.ag$Line=="12l",]$lgr.nys, alternative="two.sided")
#results of Welch two sample t-test: t = -0.38579, df = 7.4858, p-value = 0.7104

#'erg5 erg7
t.test(nys.ag[nys.ag$Line=="1258a",]$lgr.nys, nys.ag[nys.ag$Line=="1258l",]$lgr.nys, alternative="two.sided")
#results of Welch two sample t-test: t = -0.98221, df = 7.9974, p-value = 0.3548

#'ypd
#'erg7
t.test(ypd.ag[ypd.ag$Line=="12a",]$lgr.ypd, ypd.ag[ypd.ag$Line=="12l",]$lgr.ypd, alternative="two.sided")
#results of Welch two sample t-test: t = 0.46243, df = 6.5182, p-value = 0.6588

#'erg5 erg7
t.test(ypd.ag[ypd.ag$Line=="1258a",]$lgr.ypd, ypd.ag[ypd.ag$Line=="1258l",]$lgr.ypd, alternative="two.sided")
#results of Welch two sample t-test: t = -1.9035, df = 7.8703, p-value = 0.09406

#####ADD DSC2 AS A FACTOR IN THE MIXED EFFECTS MODEL#####
#'add allele information for dsc2 - "w" = wildtype, "m" = mutant
nys$dsc2 <- "w"
ypd$dsc2 <- "w"

dsc2mut <- c("12a","1245a","1245l", "1258a")
nys$dsc2[nys$Line %in% dsc2mut] <- "m"
ypd$dsc2[ypd$Line %in% dsc2mut] <- "m"

#'make mat, day, plate, genotype into factors
nys$nbm8 <- factor(nys$nbm8, levels=c("w","m"))
nys$nbm12 <- factor(nys$nbm12, levels=c("w","m"))
nys$nbm45 <- factor(nys$nbm45, levels=c("w","m"))
nys$nbm58 <- factor(nys$nbm58, levels=c("w","m"))
nys$dsc2 <- factor(nys$dsc2, levels=c("w","m"))
nys$Day <- factor(nys$Day)
nys$mat <- factor(nys$mat)
nys$Plate <- factor(nys$Plate)

ypd$nbm8 <- factor(ypd$nbm8, levels=c("w","m"))
ypd$nbm12 <- factor(ypd$nbm12, levels=c("w","m"))
ypd$nbm45 <- factor(ypd$nbm45, levels=c("w","m"))
ypd$nbm58 <- factor(ypd$nbm58, levels=c("w","m"))
ypd$dsc2 <- factor(ypd$dsc2, levels=c("w","m"))
ypd$Day <- factor(ypd$Day)
ypd$mat <- factor(ypd$mat)
ypd$Plate <- factor(ypd$Plate)

#####MODEL - NYSTATIN2 HAPLOIDS BOTH MATING TYPES TOGETHER#####
#'write full model
#'plate within day as random effect
dat <- nys[is.na(nys$omit)&is.na(nys$out),]
nys.haps.dsc2.model <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm12 +  nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat)

#'check assumptions
par(mfrow=c(2,2))
plot(fitted(nys.haps.dsc2.model),residuals(nys.haps.dsc2.model))
abline(h=0)
hist(residuals(nys.haps.dsc2.model))
qqnorm(residuals(nys.haps.dsc2.model))
qqline(residuals(nys.haps.dsc2.model))
#'plot
boxplot(lgr.nys ~ mat*nbm8*nbm12*nbm45*nbm58*dsc2, dat, las=2)

#'estimates from model
summary(nys.haps.dsc2.model)

#'find P-values by dropping terms one at a time
#'full model to compare to
Mfull <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'drop interaction terms one by one
M1.1 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.2 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.3 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.4 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm12 + nbm8*nbm45 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.5 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm12 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.6 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'anova comparing full model to model with one interaction term dropped
anova(Mfull, M1.1)
anova(Mfull, M1.2)
anova(Mfull, M1.3)
anova(Mfull, M1.4)
anova(Mfull, M1.5)
anova(Mfull, M1.6)

#'move on to mating type and dsc2
M1.7 <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.8 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
anova(Mfull, M1.7)
#'MAT significant now - P = 0.04789
#'We believe that the barely significant P value in this case is due to over-fitting of an unbalanced design.  
#'Investigating the effect visually, there are two lines (nbm12:58 and nbm8:12) where mat-a and mat-alpha differ 
#'in opposite directions (perhaps because of day effects).  DSC2 is then statistically used to account for the 
#'nbm12:58 a/alpha difference, leaving MAT to account for the nbm8:12 difference.
#'boxplot to visualize the data
boxplot(lgr.nys ~ mat*nbm8*nbm12*nbm45*nbm58*dsc2, dat, las=2)

anova(Mfull, M1.8)
#'DSC2 marginally significant - P = 0.07308

#'find the least-squares means (and confidence intervals) for each line
nys.dsc2.lsmeans <- summary(lsmeans(nys.haps.dsc2.model, c("nbm8","nbm12","nbm45","nbm58","dsc2")))

#'tell it which comparisons to do - doesn't include doubles with wt
con <- summary(contrast(lsmeans(nys.haps.dsc2.model, c("nbm8","nbm12","nbm45","nbm58","dsc2")), method="pairwise"))
lines.in <- c("w,w,w,w,w - m,w,w,w,w","w,w,w,w,w - w,m,w,w,w", "w,w,w,w,w - w,w,m,w,w", "w,w,w,w,w - w,w,w,m,w","m,w,w,w,w - m,m,w,w,w", "m,w,w,w,w - m,w,m,w,w", "m,w,w,w,w - m,w,w,m,w", "w,m,w,w,w - m,m,w,w,w", "w,m,w,w,w - w,m,m,w,m", "w,m,w,w,w - w,m,w,m,w", "w,w,m,w,w - m,w,m,w,w", "w,w,m,w,w - w,m,m,w,m", "w,w,m,w,w - w,w,m,m,w", "w,w,w,m,w - m,w,w,m,w", "w,w,w,m,w - w,m,w,m,w", "w,w,w,m,w - w,w,m,m,w","w,w,w,w,w - w,m,w,w,m","m,m,w,w,w - w,m,w,w,m","w,m,w,w,m - w,m,m,w,m","w,m,w,m,w - w,m,w,w,m","w,m,w,w,w - w,m,w,m,m","w,w,w,m,w - w,m,w,m,m","w,m,w,w,m - w,m,w,m,m")
ind.in <- c()
for (i in lines.in){
  ind.in <- c(ind.in, grep(i, con$contrast))
}

#'do the desired contrasts
nys.dsc2.contrasts <- summary(contrast(lsmeans(nys.haps.dsc2.model, c("nbm8","nbm12","nbm45","nbm58","dsc2")), method="pairwise")[ind.in])

#'write output of least-squares means and desired contrasts
write.csv(format(nys.dsc2.lsmeans, digits=5), "DSC2/data_output/Nys2DSC2Means.csv", row.names=FALSE)
write.csv(format(nys.dsc2.contrasts, digits=5), "DSC2/data_output/Nys2DSC2Contrasts.csv", row.names=FALSE)

#####MODEL - YPD HAPLOIDS BOTH MATING TYPES TOGETHER#####
#'write full model
#'plate within day as random effect
dat <- ypd[is.na(ypd$omit)&is.na(ypd$out),]
ypd.haps.dsc2.model <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm12 +  nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat)

#'check assumptions
par(mfrow=c(2,2))
plot(fitted(ypd.haps.dsc2.model),residuals(ypd.haps.dsc2.model))
abline(h=0)
hist(residuals(ypd.haps.dsc2.model))
qqnorm(residuals(ypd.haps.dsc2.model))
qqline(residuals(ypd.haps.dsc2.model))
#'plot
boxplot(lgr.ypd ~ mat*nbm8*nbm12*nbm45*nbm58*dsc2, dat, las=2)

#'estimates from model
summary(ypd.haps.dsc2.model)

#'find P-values by dropping terms one at a time
#'full model to compare to
Mfull <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'drop interaction terms one by one
M1.1 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.2 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.3 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.4 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm12 + nbm8*nbm45 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.5 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm12 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.6 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'anova comparing full model to model with one interaction term dropped
anova(Mfull, M1.1)
anova(Mfull, M1.2)
anova(Mfull, M1.3)
anova(Mfull, M1.4)
anova(Mfull, M1.5)
anova(Mfull, M1.6)

#'move on to mating type and dsc2
M1.7 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + dsc2 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.8 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
anova(Mfull, M1.7)
#'MAT not significant
anova(Mfull, M1.8)
#'dsc2 not significant

#'find the least-squares means (and confidence intervals) for each line
ypd.dsc2.lsmeans <- summary(lsmeans(ypd.haps.dsc2.model, c("nbm8","nbm12","nbm45","nbm58","dsc2")))

#'tell it which comparisons to do - doesn't include doubles with wt
con <- summary(contrast(lsmeans(ypd.haps.dsc2.model, c("nbm8","nbm12","nbm45","nbm58","dsc2")), method="pairwise"))
lines.in <- c("w,w,w,w,w - m,w,w,w,w","w,w,w,w,w - w,m,w,w,w", "w,w,w,w,w - w,w,m,w,w", "w,w,w,w,w - w,w,w,m,w","m,w,w,w,w - m,m,w,w,w", "m,w,w,w,w - m,w,m,w,w", "m,w,w,w,w - m,w,w,m,w", "w,m,w,w,w - m,m,w,w,w", "w,m,w,w,w - w,m,m,w,m", "w,m,w,w,w - w,m,w,m,w", "w,w,m,w,w - m,w,m,w,w", "w,w,m,w,w - w,m,m,w,m", "w,w,m,w,w - w,w,m,m,w", "w,w,w,m,w - m,w,w,m,w", "w,w,w,m,w - w,m,w,m,w", "w,w,w,m,w - w,w,m,m,w","w,w,w,w,w - w,m,w,w,m","m,m,w,w,w - w,m,w,w,m","w,m,w,w,m - w,m,m,w,m","w,m,w,m,w - w,m,w,w,m","w,m,w,w,w - w,m,w,m,m","w,w,w,m,w - w,m,w,m,m","w,m,w,w,m - w,m,w,m,m")
ind.in <- c()
for (i in lines.in){
  ind.in <- c(ind.in, grep(i, con$contrast))
}

#'do the desired contrasts
ypd.dsc2.contrasts <- summary(contrast(lsmeans(ypd.haps.dsc2.model, c("nbm8","nbm12","nbm45","nbm58","dsc2")), method="pairwise")[ind.in])

#'write output of least-squares means and desired contrasts
write.csv(format(ypd.dsc2.lsmeans, digits=5), "DSC2/data_output/YPDDSC2Means.csv", row.names=FALSE)
write.csv(format(ypd.dsc2.contrasts, digits=5), "DSC2/data_output/YPDDSC2Contrasts.csv", row.names=FALSE)

#####MODELS WITH STRAINS CONTAINING MUTATIONS IN DSC2 EXCLUDED#####
#'can't include NBM12*NBM45 (erg3*erg7) in the models because both MATa and MATalpha have the mutation in DSC2

#####MODEL - NYSTATIN2 HAPLOIDS BOTH MATING TYPES TOGETHER#####
#'write full model
#'plate within day as random effect
dat <- nys[is.na(nys$omit)&is.na(nys$out)&nys$dsc2=="w",]
nys.haps.nodsc2.model <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 +  nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat)

#'check assumptions
par(mfrow=c(2,2))
plot(fitted(nys.haps.nodsc2.model),residuals(nys.haps.nodsc2.model))
abline(h=0)
hist(residuals(nys.haps.nodsc2.model))
qqnorm(residuals(nys.haps.nodsc2.model))
qqline(residuals(nys.haps.nodsc2.model))
#'plot
boxplot(lgr.nys ~ mat*nbm8*nbm12*nbm45*nbm58, dat, las=2)

#'estimates from model
summary(nys.haps.nodsc2.model)

#'find P-values by dropping terms one at a time
#'full model to compare to
Mfull <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'drop interaction terms one by one
M1.1 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.2 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#M1.3 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.4 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.5 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.6 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'anova comparing full model to model with one interaction term dropped
anova(Mfull, M1.1)
anova(Mfull, M1.2)
#anova(Mfull, M1.3)
anova(Mfull, M1.4)
anova(Mfull, M1.5)
anova(Mfull, M1.6)

#'move on to mating type
M1.7 <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
anova(Mfull, M1.7)
#'MAT significant now - P = 0.04911
#'We believe that the barely significant P value in this case is due to over-fitting of an unbalanced design.  
#'Investigating the effect visually, there are two lines (nbm12:58 and nbm8:12) where mat-a and mat-alpha differ 
#'in opposite directions (perhaps because of day effects).  Removal of all strains carrying the dsc2 mutation removes
#'one of the nbm12:58 lines (and therefore removes the nbm12:58 a/alpha difference), leaving MAT to account for the 
#'nbm8:12 difference.
#'boxplot to visualize the data
boxplot(lgr.nys ~ mat*nbm8*nbm12*nbm45*nbm58, dat, las=2)

#'find the least-squares means (and confidence intervals) for each line
nys.nodsc2.lsmeans <- summary(lsmeans(nys.haps.nodsc2.model, c("nbm8","nbm12","nbm45","nbm58")))

#'tell it which comparisons to do - doesn't include doubles with wt
con <- summary(contrast(lsmeans(nys.haps.nodsc2.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise"))
lines.in <- c("w,w,w,w - m,w,w,w","w,w,w,w - w,m,w,w", "w,w,w,w - w,w,m,w", "w,w,w,w - w,w,w,m","m,w,w,w - m,m,w,w", "m,w,w,w - m,w,m,w", "m,w,w,w - m,w,w,m", "w,m,w,w - m,m,w,w", "w,m,w,w - w,m,w,m", "w,w,m,w - m,w,m,w", "w,w,m,w - w,w,m,m", "w,w,w,m - m,w,w,m", "w,w,w,m - w,m,w,m", "w,w,w,m - w,w,m,m")
ind.in <- c()
for (i in lines.in){
  ind.in <- c(ind.in, grep(i, con$contrast))
}

#'do the desired contrasts
nys.nodsc2.contrasts <- summary(contrast(lsmeans(nys.haps.nodsc2.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise")[ind.in])

#'write output of least-squares means and desired contrasts
write.csv(format(nys.nodsc2.lsmeans, digits=5), "DSC2/data_output/Nys2NoDSC2Means.csv", row.names=FALSE)
write.csv(format(nys.nodsc2.contrasts, digits=5), "DSC2/data_output/Nys2NoDSC2Contrasts.csv", row.names=FALSE)

#####MODEL - YPD HAPLOIDS BOTH MATING TYPES TOGETHER#####
#'write full model
#'plate within day as random effect
dat <- ypd[is.na(ypd$omit)&is.na(ypd$out)&ypd$dsc2=="w",]
ypd.haps.nodsc2.model <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 +  nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat)

#'check assumptions
par(mfrow=c(2,2))
plot(fitted(ypd.haps.nodsc2.model),residuals(ypd.haps.nodsc2.model))
abline(h=0)
hist(residuals(ypd.haps.nodsc2.model))
qqnorm(residuals(ypd.haps.nodsc2.model))
qqline(residuals(ypd.haps.nodsc2.model))
#'plot
boxplot(lgr.ypd ~ mat*nbm8*nbm12*nbm45*nbm58, dat, las=2)

#'estimates from model
summary(ypd.haps.nodsc2.model)

#'find P-values by dropping terms one at a time
#'full model to compare to
Mfull <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'drop interaction terms one by one
M1.1 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.2 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#M1.3 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.4 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.5 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.6 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'anova comparing full model to model with one interaction term dropped
anova(Mfull, M1.1)
anova(Mfull, M1.2)
#anova(Mfull, M1.3)
anova(Mfull, M1.4)
anova(Mfull, M1.5)
anova(Mfull, M1.6)

#'move on to mating type
M1.7 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
anova(Mfull, M1.7)
#'MAT not significant

#'find the least-squares means (and confidence intervals) for each line
ypd.nodsc2.lsmeans <- summary(lsmeans(ypd.haps.nodsc2.model, c("nbm8","nbm12","nbm45","nbm58")))

#'tell it which comparisons to do - doesn't include doubles with wt
con <- summary(contrast(lsmeans(ypd.haps.nodsc2.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise"))
lines.in <- c("w,w,w,w - m,w,w,w","w,w,w,w - w,m,w,w", "w,w,w,w - w,w,m,w", "w,w,w,w - w,w,w,m","m,w,w,w - m,m,w,w", "m,w,w,w - m,w,m,w", "m,w,w,w - m,w,w,m", "w,m,w,w - m,m,w,w", "w,m,w,w - w,m,w,m", "w,w,m,w - m,w,m,w", "w,w,m,w - w,w,m,m", "w,w,w,m - m,w,w,m", "w,w,w,m - w,m,w,m", "w,w,w,m - w,w,m,m")
ind.in <- c()
for (i in lines.in){
  ind.in <- c(ind.in, grep(i, con$contrast))
}

#'do the desired contrasts
ypd.nodsc2.contrasts <- summary(contrast(lsmeans(ypd.haps.nodsc2.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise")[ind.in])

#'write output of least-squares means and desired contrasts
write.csv(format(ypd.nodsc2.lsmeans, digits=5), "DSC2/data_output/YPDNoDSC2Means.csv", row.names=FALSE)
write.csv(format(ypd.nodsc2.contrasts, digits=5), "DSC2/data_output/YPDNoDSC2Contrasts.csv", row.names=FALSE)

#####SET UP DATA FOR PLOTTING#####
#'load in data created in first half of file
nys.haps.d <- read.csv("DSC2/data_output/Nys2DSC2Means.csv", sep=",", as.is=TRUE)
ypd.haps.d <- read.csv("DSC2/data_output/YPDDSC2Means.csv", sep=",", as.is=TRUE)
nys.haps.nod <- read.csv("DSC2/data_output/Nys2NoDSC2Means.csv", sep=",", as.is=TRUE)
ypd.haps.nod <- read.csv("DSC2/data_output/YPDNoDSC2Means.csv", sep=",", as.is=TRUE)

nys.contr.d <- read.csv("DSC2/data_output/Nys2DSC2Contrasts.csv", sep=",", as.is=TRUE)
ypd.contr.d <- read.csv("DSC2/data_output/YPDDSC2Contrasts.csv", sep=",", as.is=TRUE)
nys.contr.nod <- read.csv("DSC2/data_output/Nys2NoDSC2Contrasts.csv", sep=",", as.is=TRUE)
ypd.contr.nod <- read.csv("DSC2/data_output/YPDNoDSC2Contrasts.csv", sep=",", as.is=TRUE)

#'make a column with line names as we usually use them
set_name.d <- function(data){
  data$line <- ""
  for (i in 1:length(data$line)){
    for (j in 1:5){
      if(data[i,j]=="m"){
        if(j==1){
          data$line[i] <- paste(data$line[i], "8m", sep="") 
        }
        if(j==2){
          data$line[i] <- paste(data$line[i], "12m", sep="") 
        }
        if(j==3){
          data$line[i] <- paste(data$line[i], "45m", sep="") 
        }
        if(j==4){
          data$line[i] <- paste(data$line[i], "58m", sep="") 
        }
        if(j==5){
          data$line[i] <- paste(data$line[i], "dsc", sep="") 
        }
      }
    }
  }
  return(data)
}

set_name <- function(data){
  data$line <- ""
  for (i in 1:length(data$line)){
    for (j in 1:5){
      if(data[i,j]=="m"){
        if(j==1){
          data$line[i] <- paste(data$line[i], "8m", sep="") 
        }
        if(j==2){
          data$line[i] <- paste(data$line[i], "12m", sep="") 
        }
        if(j==3){
          data$line[i] <- paste(data$line[i], "45m", sep="") 
        }
        if(j==4){
          data$line[i] <- paste(data$line[i], "58m", sep="") 
        }
      }
    }
  }
  return(data)
}

nys.haps.d <- set_name.d(nys.haps.d)
ypd.haps.d <- set_name.d(ypd.haps.d)
nys.haps.nod <- set_name(nys.haps.nod)
ypd.haps.nod <- set_name(ypd.haps.nod)

#'manually add the wt name
nys.haps.d$line[1] <- "wt"
ypd.haps.d$line[1] <- "wt"
nys.haps.nod$line[1] <- "wt"
ypd.haps.nod$line[1] <- "wt"

#'make a column with line names for use with contrasts
nys.haps.d$geno <- paste(nys.haps.d$nbm8, nys.haps.d$nbm12, nys.haps.d$nbm45, nys.haps.d$nbm58, nys.haps.d$dsc2, sep=",")
ypd.haps.d$geno <- paste(ypd.haps.d$nbm8, ypd.haps.d$nbm12, ypd.haps.d$nbm45, ypd.haps.d$nbm58, ypd.haps.d$dsc2, sep=",")
nys.haps.nod$geno <- paste(nys.haps.nod$nbm8, nys.haps.nod$nbm12, nys.haps.nod$nbm45, nys.haps.nod$nbm58, sep=",")
ypd.haps.nod$geno <- paste(ypd.haps.nod$nbm8, ypd.haps.nod$nbm12, ypd.haps.nod$nbm45, ypd.haps.nod$nbm58, sep=",")

#'make 2 new columns with lty values 
#'lty1 == 1 if double mutant significantly different from the first single mutant or if single mutant significantly different from the ancestor
#'lty2 == 1 if double mutant significantly different from the second single mutant or if single mutant significantly different from the ancestor
#'otherwise, lty==3
nys.haps.d$lty1 <- NA
nys.haps.d$lty2 <- NA
ypd.haps.d$lty1 <- NA
ypd.haps.d$lty2 <- NA

nys.haps.nod$lty1 <- NA
nys.haps.nod$lty2 <- NA
ypd.haps.nod$lty1 <- NA
ypd.haps.nod$lty2 <- NA

#'write function to set lty
set_lty <- function(data, contr, sngl1, sngl2, dbl, wt){  
  if (contr[contr$contrast==paste(data[data$line==sngl1,]$geno, data[data$line==dbl,]$geno, sep=" - "),]$p<0.05){
    data[data$line==dbl,]$lty1 <- 1
  }else{data[data$line==dbl,]$lty1 <- 3}
  
  if (contr[contr$contrast==paste(data[data$line==sngl2,]$geno, data[data$line==dbl,]$geno, sep=" - "),]$p<0.05){
    data[data$line==dbl,]$lty2 <- 1
  }else{data[data$line==dbl,]$lty2 <- 3}
  
  if (contr[contr$contrast==paste(data[data$line==wt,]$geno, data[data$line==sngl1,]$geno, sep=" - "),]$p<0.05){
    data[data$line==sngl1,]$lty1 <- 1
  }else{data[data$line==sngl1,]$lty1 <- 3}
  
  if (contr[contr$contrast==paste(data[data$line==wt,]$geno, data[data$line==sngl2,]$geno, sep=" - "),]$p<0.05){
    data[data$line==sngl2,]$lty1 <- 1
  }else{data[data$line==sngl2,]$lty1 <- 3}
  
  return(data)
}

#'set ltys
nys.haps.d <- set_lty(nys.haps.d, nys.contr.d, "8m", "12m", "8m12m", "wt")
nys.haps.d <- set_lty(nys.haps.d, nys.contr.d, "45m", "8m", "8m45m", "wt")
nys.haps.d <- set_lty(nys.haps.d, nys.contr.d, "58m", "8m", "8m58m", "wt")
nys.haps.d <- set_lty(nys.haps.d, nys.contr.d, "58m", "12m", "12m58m", "wt")
nys.haps.d <- set_lty(nys.haps.d, nys.contr.d, "45m", "58m", "45m58m", "wt")

ypd.haps.d <- set_lty(ypd.haps.d, ypd.contr.d, "8m", "12m", "8m12m", "wt")
ypd.haps.d <- set_lty(ypd.haps.d, ypd.contr.d, "45m", "8m", "8m45m", "wt")
ypd.haps.d <- set_lty(ypd.haps.d, ypd.contr.d, "58m", "8m", "8m58m", "wt")
ypd.haps.d <- set_lty(ypd.haps.d, ypd.contr.d, "58m", "12m", "12m58m", "wt")
ypd.haps.d <- set_lty(ypd.haps.d, ypd.contr.d, "45m", "58m", "45m58m", "wt")

nys.haps.nod <- set_lty(nys.haps.nod, nys.contr.nod, "8m", "12m", "8m12m", "wt")
nys.haps.nod <- set_lty(nys.haps.nod, nys.contr.nod, "45m", "8m", "8m45m", "wt")
nys.haps.nod <- set_lty(nys.haps.nod, nys.contr.nod, "58m", "8m", "8m58m", "wt")
nys.haps.nod <- set_lty(nys.haps.nod, nys.contr.nod, "58m", "12m", "12m58m", "wt")
nys.haps.nod <- set_lty(nys.haps.nod, nys.contr.nod, "45m", "58m", "45m58m", "wt")

ypd.haps.nod <- set_lty(ypd.haps.nod, ypd.contr.nod, "8m", "12m", "8m12m", "wt")
ypd.haps.nod <- set_lty(ypd.haps.nod, ypd.contr.nod, "45m", "8m", "8m45m", "wt")
ypd.haps.nod <- set_lty(ypd.haps.nod, ypd.contr.nod, "58m", "8m", "8m58m", "wt")
ypd.haps.nod <- set_lty(ypd.haps.nod, ypd.contr.nod, "58m", "12m", "12m58m", "wt")
ypd.haps.nod <- set_lty(ypd.haps.nod, ypd.contr.nod, "45m", "58m", "45m58m", "wt")

#'set colours of points
nys.haps.d$col <- NA
nys.haps.d[nys.haps.d$line=="wt",]$col <- "#BEBEBE"
nys.haps.d[nys.haps.d$line=="8m",]$col <- "#8B0000"
nys.haps.d[nys.haps.d$line=="12m",]$col <- "#87CEEB"
nys.haps.d[nys.haps.d$line=="45m",]$col <- "#FFD700"
nys.haps.d[nys.haps.d$line=="58m",]$col <- "#008B00"
nys.haps.d[nys.haps.d$line=="8m12m",]$col <- "#000000"
nys.haps.d[nys.haps.d$line=="8m45m",]$col <- "#000000"
nys.haps.d[nys.haps.d$line=="8m58m",]$col <- "#000000"
nys.haps.d[nys.haps.d$line=="12m45m",]$col <- "#000000"
nys.haps.d[nys.haps.d$line=="12m58m",]$col <- "#000000"
nys.haps.d[nys.haps.d$line=="45m58m",]$col <- "#000000"

ypd.haps.d$col <- NA
ypd.haps.d[ypd.haps.d$line=="wt",]$col <- "#BEBEBE"
ypd.haps.d[ypd.haps.d$line=="8m",]$col <- "#8B0000"
ypd.haps.d[ypd.haps.d$line=="12m",]$col <- "#87CEEB"
ypd.haps.d[ypd.haps.d$line=="45m",]$col <- "#FFD700"
ypd.haps.d[ypd.haps.d$line=="58m",]$col <- "#008B00"
ypd.haps.d[ypd.haps.d$line=="8m12m",]$col <- "#000000"
ypd.haps.d[ypd.haps.d$line=="8m45m",]$col <- "#000000"
ypd.haps.d[ypd.haps.d$line=="8m58m",]$col <- "#000000"
ypd.haps.d[ypd.haps.d$line=="12m45m",]$col <- "#000000"
ypd.haps.d[ypd.haps.d$line=="12m58m",]$col <- "#000000"
ypd.haps.d[ypd.haps.d$line=="45m58m",]$col <- "#000000"

nys.haps.nod$col <- NA
nys.haps.nod[nys.haps.nod$line=="wt",]$col <- "#BEBEBE"
nys.haps.nod[nys.haps.nod$line=="8m",]$col <- "#8B0000"
nys.haps.nod[nys.haps.nod$line=="12m",]$col <- "#87CEEB"
nys.haps.nod[nys.haps.nod$line=="45m",]$col <- "#FFD700"
nys.haps.nod[nys.haps.nod$line=="58m",]$col <- "#008B00"
nys.haps.nod[nys.haps.nod$line=="8m12m",]$col <- "#000000"
nys.haps.nod[nys.haps.nod$line=="8m45m",]$col <- "#000000"
nys.haps.nod[nys.haps.nod$line=="8m58m",]$col <- "#000000"
nys.haps.nod[nys.haps.nod$line=="12m45m",]$col <- "#000000"
nys.haps.nod[nys.haps.nod$line=="12m58m",]$col <- "#000000"
nys.haps.nod[nys.haps.nod$line=="45m58m",]$col <- "#000000"

ypd.haps.nod$col <- NA
ypd.haps.nod[ypd.haps.nod$line=="wt",]$col <- "#BEBEBE"
ypd.haps.nod[ypd.haps.nod$line=="8m",]$col <- "#8B0000"
ypd.haps.nod[ypd.haps.nod$line=="12m",]$col <- "#87CEEB"
ypd.haps.nod[ypd.haps.nod$line=="45m",]$col <- "#FFD700"
ypd.haps.nod[ypd.haps.nod$line=="58m",]$col <- "#008B00"
ypd.haps.nod[ypd.haps.nod$line=="8m12m",]$col <- "#000000"
ypd.haps.nod[ypd.haps.nod$line=="8m45m",]$col <- "#000000"
ypd.haps.nod[ypd.haps.nod$line=="8m58m",]$col <- "#000000"
ypd.haps.nod[ypd.haps.nod$line=="12m45m",]$col <- "#000000"
ypd.haps.nod[ypd.haps.nod$line=="12m58m",]$col <- "#000000"
ypd.haps.nod[ypd.haps.nod$line=="45m58m",]$col <- "#000000"

#'write function to make plots
plot_pair <- function(data, sngl1, dbl, sngl2, wt){
  plot(c(1,2,3), type="n", ylim=c(0.01,0.39), xlim=c(0.5,3.5), xaxt="n", yaxt="n", ylab="")
  lines(c(1,2), c(data[data$line==sngl1,]$lsmean,data[data$line==dbl,]$lsmean), lty=data[data$line==dbl,]$lty1)
  lines(c(2,3), c(data[data$line==dbl,]$lsmean,data[data$line==sngl2,]$lsmean), lty=data[data$line==dbl,]$lty2)
  lines(c(1,2), c(data[data$line==sngl1,]$lsmean,data[data$line==wt,]$lsmean), lty=data[data$line==sngl1,]$lty1)
  lines(c(2,3), c(data[data$line==wt,]$lsmean,data[data$line==sngl2,]$lsmean), lty=data[data$line==sngl2,]$lty1)
  points(1, data[data$line==sngl1,]$lsmean, pch=16, col=data[data$line==sngl1,]$col, cex=2)
  arrows(1, data[data$line==sngl1,]$lower.CL, 1, data[data$line==sngl1,]$upper.CL,length=0, col="black")
  points(2, data[data$line==dbl,]$lsmean, pch=16, col=data[data$line==dbl,]$col, cex=2)
  arrows(2, data[data$line==dbl,]$lower.CL, 2, data[data$line==dbl,]$upper.CL,length=0, col="black")
  points(3, data[data$line==sngl2,]$lsmean, pch=16, col=data[data$line==sngl2,]$col, cex=2)
  arrows(3, data[data$line==sngl2,]$lower.CL, 3, data[data$line==sngl2,]$upper.CL,length=0, col="black")
  points(2, data[data$line==wt,]$lsmean, pch=16, col=data[data$line==wt,]$col, cex=2)
  arrows(2, data[data$line==wt,]$lower.CL, 2, data[data$line==wt,]$upper.CL,length=0, col="black")
  points(2, data[data$line==sngl1,]$lsmean+data[data$line==sngl2,]$lsmean-(data[data$line==wt,]$lsmean), pch=4, col="black", cex=2)
}

#####PLOT ALL MAXIMUM GROWTH RATES IN TABLES - WITH STRAINS SEPARATED BY DSC2 ALLELE STATUS#####
pdf("DSC2/plots/HapGRPlotDSC2.pdf", width=7.5, height=6, family="ArialMT", pointsize=10)

par(mfrow=c(4,4), mar=c(0,0,0,0), oma=c(4,5,4,15))

#'erg3-erg3 (nbm45-nbm45)
plot(1, type="n", axes=F, xlab="", ylab="")
text(1,1,labels="erg3", cex=3, col=nys.haps.d[nys.haps.d$line=="45m",]$col)

#'erg3-erg5 (nbm45-nbm58)
plot_pair(nys.haps.d, "45m", "45m58m", "58m", "wt")
text(1,0.35,"S", cex=2, font=2)

#'erg3-erg6 (nbm45-nbm8)
plot_pair(nys.haps.d, "45m", "8m45m", "8m", "wt")
text(2,0.25,"notRS - marg", cex=0.75, font=2)

#'erg3-erg7 (nbm45-nbm12)
#'generate plot (both double mutants have mutation in DSC2 so that is what is plotted)
plot(c(1,2,3), type="n", ylim=c(0.01,0.39), xlim=c(0.5,3.5), xaxt="n", yaxt="n", ylab="")
lines(c(1,2), c(nys.haps.d[nys.haps.d$line=="45m",]$lsmean,nys.haps.d[nys.haps.d$line=="12m45mdsc",]$lsmean), lty=1)
lines(c(2,3), c(nys.haps.d[nys.haps.d$line=="12m45mdsc",]$lsmean,nys.haps.d[nys.haps.d$line=="12m",]$lsmean), lty=3)
lines(c(1,2), c(nys.haps.d[nys.haps.d$line=="45m",]$lsmean,nys.haps.d[nys.haps.d$line=="wt",]$lsmean), lty=nys.haps.d[nys.haps.d$line=="45m",]$lty1)
lines(c(2,3), c(nys.haps.d[nys.haps.d$line=="wt",]$lsmean,nys.haps.d[nys.haps.d$line=="12m",]$lsmean), lty=nys.haps.d[nys.haps.d$line=="12m",]$lty1)
points(1, nys.haps.d[nys.haps.d$line=="45m",]$lsmean, pch=16, col=nys.haps.d[nys.haps.d$line=="45m",]$col, cex=2)
arrows(1, nys.haps.d[nys.haps.d$line=="45m",]$lower.CL, 1, nys.haps.d[nys.haps.d$line=="45m",]$upper.CL,length=0, col="black")
points(2, nys.haps.d[nys.haps.d$line=="12m45mdsc",]$lsmean, pch=16, col="#000000", cex=2)
arrows(2, nys.haps.d[nys.haps.d$line=="12m45mdsc",]$lower.CL, 2, nys.haps.d[nys.haps.d$line=="12m45mdsc",]$upper.CL,length=0, col="black")
points(3, nys.haps.d[nys.haps.d$line=="12m",]$lsmean, pch=16, col=nys.haps.d[nys.haps.d$line=="12m",]$col, cex=2)
arrows(3, nys.haps.d[nys.haps.d$line=="12m",]$lower.CL, 3, nys.haps.d[nys.haps.d$line=="12m",]$upper.CL,length=0, col="black")
points(2, nys.haps.d[nys.haps.d$line=="wt",]$lsmean, pch=16, col=nys.haps.d[nys.haps.d$line=="wt",]$col, cex=2)
arrows(2, nys.haps.d[nys.haps.d$line=="wt",]$lower.CL, 2, nys.haps.d[nys.haps.d$line=="wt",]$upper.CL,length=0, col="black")
points(2, nys.haps.d[nys.haps.d$line=="45m",]$lsmean+nys.haps.d[nys.haps.d$line=="12m",]$lsmean-(nys.haps.d[nys.haps.d$line=="wt",]$lsmean), pch=4, col="black", cex=2)
#'plot erg7 (nbm12) with mutation in DSC2 and compare to other strains
lines(c(2,3.2), c(nys.haps.d[nys.haps.d$line=="12m45mdsc",]$lsmean,nys.haps.d[nys.haps.d$line=="12mdsc",]$lsmean), lty=3)
lines(c(2,3.2), c(nys.haps.d[nys.haps.d$line=="wt",]$lsmean,nys.haps.d[nys.haps.d$line=="12mdsc",]$lsmean), lty=1)
points(3.2, nys.haps.d[nys.haps.d$line=="12mdsc",]$lsmean, pch=16, col=nys.haps.d[nys.haps.d$line=="12m",]$col, cex=2)
arrows(3.2, nys.haps.d[nys.haps.d$line=="12mdsc",]$lower.CL, 3.2, nys.haps.d[nys.haps.d$line=="12mdsc",]$upper.CL,length=0, col="black")
#'plot no epistasis "X" for the strain pair erg3 (nbm45) and erg7 dsc2 (nbm12 dsc2)
points(2, nys.haps.d[nys.haps.d$line=="45m",]$lsmean+nys.haps.d[nys.haps.d$line=="12mdsc",]$lsmean-(nys.haps.d[nys.haps.d$line=="wt",]$lsmean), pch=4, col="red", cex=2)

text(1,0.35,"S", cex=2, font=2)
axis(4, las=1, at=c(0.05,0.1,0.15,0.20,0.25,0.30,0.35))

#'erg3-erg5 (nbm45-nbm58) - ypd
plot_pair(ypd.haps.d, "45m", "45m58m", "58m", "wt")
axis(2, las=1, at=c(0.05,0.1,0.15,0.20,0.25,0.30,0.35))

#'erg5-erg5 (nbm58-nbm58)
plot(1, type="n", axes=F, xlab="", ylab="")
text(1,1,labels="erg5", cex=3, col=nys.haps.d[nys.haps.d$line=="58m",]$col)

#'erg5-erg6 (nbm58-nbm8) 
plot_pair(nys.haps.d, "58m", "8m58m", "8m", "wt")

#'erg5-erg7 (nbm58-nbm12)
#'first plot only strains without mutation in DSC2
plot_pair(nys.haps.d, "58m", "12m58m", "12m", "wt")
#'plot erg5 erg7 (nbm12 nbm58) with mutation in DSC2 and compare to strains without mutation in DSC2
points(2.2, nys.haps.d[nys.haps.d$line=="12m58mdsc",]$lsmean, pch=16, col="#000000", cex=2)
lines(c(1,2.2), c(nys.haps.d[nys.haps.d$line=="58m",]$lsmean,nys.haps.d[nys.haps.d$line=="12m58mdsc",]$lsmean), lty=1)
lines(c(2.2,3), c(nys.haps.d[nys.haps.d$line=="12m58mdsc",]$lsmean,nys.haps.d[nys.haps.d$line=="12m",]$lsmean), lty=1)
arrows(2.2, nys.haps.d[nys.haps.d$line=="12m58mdsc",]$lower.CL, 2.2, nys.haps.d[nys.haps.d$line=="12m58mdsc",]$upper.CL,length=0, col="black")
#'plot erg7 (nbm12) with mutation in DSC2 and compare to strains without mutation in DSC2
lines(c(2,3.2), c(nys.haps.d[nys.haps.d$line=="12m58m",]$lsmean,nys.haps.d[nys.haps.d$line=="12mdsc",]$lsmean), lty=3)
lines(c(2,3.2), c(nys.haps.d[nys.haps.d$line=="wt",]$lsmean,nys.haps.d[nys.haps.d$line=="12mdsc",]$lsmean), lty=1)
points(3.2, nys.haps.d[nys.haps.d$line=="12mdsc",]$lsmean, pch=16, col=nys.haps.d[nys.haps.d$line=="12m",]$col, cex=2)
arrows(3.2, nys.haps.d[nys.haps.d$line=="12mdsc",]$lower.CL, 3.2, nys.haps.d[nys.haps.d$line=="12mdsc",]$upper.CL,length=0, col="black")
#'plot no epistasis "X" for the strain pair erg5 (nbm58) and erg7 dsc2 (nbm12 dsc2)
points(2, nys.haps.d[nys.haps.d$line=="58m",]$lsmean+nys.haps.d[nys.haps.d$line=="12mdsc",]$lsmean-(nys.haps.d[nys.haps.d$line=="wt",]$lsmean), pch=4, col="red", cex=2)
#'compare erg5 erg7 dsc2 (nbm58:nbm12 dsc2) with erg7 dsc2 (nbm12 dsc2)
lines(c(2.2,3.2), c(nys.haps.d[nys.haps.d$line=="12m58mdsc",]$lsmean,nys.haps.d[nys.haps.d$line=="12mdsc",]$lsmean), lty=3)

text(2,0.35,"S - 1 combination", cex=0.75, font=2)
axis(4, las=1, at=c(0.05,0.1,0.15,0.20,0.25,0.30,0.35))

#'erg3-erg6 (nbm45-nbm8) - ypd
plot_pair(ypd.haps.d, "45m", "8m45m", "8m", "wt")
axis(2, las=1, at=c(0.05,0.1,0.15,0.20,0.25,0.30,0.35))

#'erg5-erg6 (nbm58-nbm8) - ypd
plot_pair(ypd.haps.d, "58m", "8m58m", "8m", "wt")

#'erg6-erg6 (nbm8-nbm8) 
plot(1, type="n", axes=F, xlab="", ylab="")
text(1,1,labels="erg6", cex=3, col=nys.haps.d[nys.haps.d$line=="8m",]$col)

#'erg6-erg7 (nbm8-nbm12)
#'first plot only strains without mutation in DSC2
plot_pair(nys.haps.d, "8m", "8m12m", "12m", "wt")
#'plot erg7 (nbm12) with mutation in DSC2 and compare to strains without mutation in DSC2
lines(c(2,3.2), c(nys.haps.d[nys.haps.d$line=="8m12m",]$lsmean,nys.haps.d[nys.haps.d$line=="12mdsc",]$lsmean), lty=3)
lines(c(2,3.2), c(nys.haps.d[nys.haps.d$line=="wt",]$lsmean,nys.haps.d[nys.haps.d$line=="12mdsc",]$lsmean), lty=1)
points(3.2, nys.haps.d[nys.haps.d$line=="12mdsc",]$lsmean, pch=16, col=nys.haps.d[nys.haps.d$line=="12m",]$col, cex=2)
arrows(3.2, nys.haps.d[nys.haps.d$line=="12mdsc",]$lower.CL, 3.2, nys.haps.d[nys.haps.d$line=="12mdsc",]$upper.CL,length=0, col="black")
#'plot no epistasis "X" for the strain pair erg6 (nbm8) and erg7 dsc2 (nbm12 dsc2)
points(2, nys.haps.d[nys.haps.d$line=="8m",]$lsmean+nys.haps.d[nys.haps.d$line=="12mdsc",]$lsmean-(nys.haps.d[nys.haps.d$line=="wt",]$lsmean), pch=4, col="red", cex=2)

text(2,0.35,"RS - 1 combination (other marginal)", cex=0.75, font=2)
axis(4, las=1, at=c(0.05,0.1,0.15,0.20,0.25,0.30,0.35))

#'erg3-erg7 (nbm45-nbm12) - ypd
#'generate plot (both double mutants have mutation in DSC2 so that is what is plotted)
plot(c(1,2,3), type="n", ylim=c(0.01,0.39), xlim=c(0.5,3.5), xaxt="n", yaxt="n", ylab="")
lines(c(1,2), c(ypd.haps.d[ypd.haps.d$line=="45m",]$lsmean,ypd.haps.d[ypd.haps.d$line=="12m45mdsc",]$lsmean), lty=1)
lines(c(2,3), c(ypd.haps.d[ypd.haps.d$line=="12m45mdsc",]$lsmean,ypd.haps.d[ypd.haps.d$line=="12m",]$lsmean), lty=3)
lines(c(1,2), c(ypd.haps.d[ypd.haps.d$line=="45m",]$lsmean,ypd.haps.d[ypd.haps.d$line=="wt",]$lsmean), lty=ypd.haps.d[ypd.haps.d$line=="45m",]$lty1)
lines(c(2,3), c(ypd.haps.d[ypd.haps.d$line=="wt",]$lsmean,ypd.haps.d[ypd.haps.d$line=="12m",]$lsmean), lty=ypd.haps.d[ypd.haps.d$line=="12m",]$lty1)
points(1, ypd.haps.d[ypd.haps.d$line=="45m",]$lsmean, pch=16, col=ypd.haps.d[ypd.haps.d$line=="45m",]$col, cex=2)
arrows(1, ypd.haps.d[ypd.haps.d$line=="45m",]$lower.CL, 1, ypd.haps.d[ypd.haps.d$line=="45m",]$upper.CL,length=0, col="black")
points(2, ypd.haps.d[ypd.haps.d$line=="12m45mdsc",]$lsmean, pch=16, col="#000000", cex=2)
arrows(2, ypd.haps.d[ypd.haps.d$line=="12m45mdsc",]$lower.CL, 2, ypd.haps.d[ypd.haps.d$line=="12m45mdsc",]$upper.CL,length=0, col="black")
points(3, ypd.haps.d[ypd.haps.d$line=="12m",]$lsmean, pch=16, col=ypd.haps.d[ypd.haps.d$line=="12m",]$col, cex=2)
arrows(3, ypd.haps.d[ypd.haps.d$line=="12m",]$lower.CL, 3, ypd.haps.d[ypd.haps.d$line=="12m",]$upper.CL,length=0, col="black")
points(2, ypd.haps.d[ypd.haps.d$line=="wt",]$lsmean, pch=16, col=ypd.haps.d[ypd.haps.d$line=="wt",]$col, cex=2)
arrows(2, ypd.haps.d[ypd.haps.d$line=="wt",]$lower.CL, 2, ypd.haps.d[ypd.haps.d$line=="wt",]$upper.CL,length=0, col="black")
points(2, ypd.haps.d[ypd.haps.d$line=="45m",]$lsmean+ypd.haps.d[ypd.haps.d$line=="12m",]$lsmean-(ypd.haps.d[ypd.haps.d$line=="wt",]$lsmean), pch=4, col="black", cex=2)
#'plot erg7 (nbm12) with mutation in DSC2 and compare to other strains
lines(c(2,3.2), c(ypd.haps.d[ypd.haps.d$line=="12m45mdsc",]$lsmean,ypd.haps.d[ypd.haps.d$line=="12mdsc",]$lsmean), lty=3)
lines(c(2,3.2), c(ypd.haps.d[ypd.haps.d$line=="wt",]$lsmean,ypd.haps.d[ypd.haps.d$line=="12mdsc",]$lsmean), lty=1)
points(3.2, ypd.haps.d[ypd.haps.d$line=="12mdsc",]$lsmean, pch=16, col=ypd.haps.d[ypd.haps.d$line=="12m",]$col, cex=2)
arrows(3.2, ypd.haps.d[ypd.haps.d$line=="12mdsc",]$lower.CL, 3.2, ypd.haps.d[ypd.haps.d$line=="12mdsc",]$upper.CL,length=0, col="black")
#'plot no epistasis "X" for the strain pair erg3 (nbm45) and erg7 dsc2 (nbm12 dsc2)
points(2, ypd.haps.d[ypd.haps.d$line=="45m",]$lsmean+ypd.haps.d[ypd.haps.d$line=="12mdsc",]$lsmean-(ypd.haps.d[ypd.haps.d$line=="wt",]$lsmean), pch=4, col="red", cex=2)

axis(2, las=1, at=c(0.05,0.1,0.15,0.20,0.25,0.30,0.35))

#'erg5-erg7 (nbm58-nbm12) - ypd
#'first plot only strains without mutation in DSC2
plot_pair(ypd.haps.d, "58m", "12m58m", "12m", "wt")
#’plot erg5 erg7 (nbm12 nbm58) with mutation in DSC2 and compare to strains without mutation in DSC2
lines(c(1,2.2), c(ypd.haps.d[ypd.haps.d$line=="58m",]$lsmean,ypd.haps.d[ypd.haps.d$line=="12m58mdsc",]$lsmean), lty=1)
lines(c(2.2,3), c(ypd.haps.d[ypd.haps.d$line=="12m58mdsc",]$lsmean,ypd.haps.d[ypd.haps.d$line=="12m",]$lsmean), lty=3)
points(2.2, ypd.haps.d[ypd.haps.d$line=="12m58mdsc",]$lsmean, pch=16, col="#000000", cex=2)
arrows(2.2, ypd.haps.d[ypd.haps.d$line=="12m58mdsc",]$lower.CL, 2.2, ypd.haps.d[ypd.haps.d$line=="12m58mdsc",]$upper.CL,length=0, col="black")
#’plot erg7 (nbm12) with mutation in DSC2 and compare to strains without mutation in DSC2
lines(c(2,3.2), c(ypd.haps.d[ypd.haps.d$line=="12m58m",]$lsmean,ypd.haps.d[ypd.haps.d$line=="12mdsc",]$lsmean), lty=3)
lines(c(2,3.2), c(ypd.haps.d[ypd.haps.d$line=="wt",]$lsmean,ypd.haps.d[ypd.haps.d$line=="12mdsc",]$lsmean), lty=1)
points(3.2, ypd.haps.d[ypd.haps.d$line=="12mdsc",]$lsmean, pch=16, col=ypd.haps.d[ypd.haps.d$line=="12m",]$col, cex=2)
arrows(3.2, ypd.haps.d[ypd.haps.d$line=="12mdsc",]$lower.CL, 3.2, ypd.haps.d[ypd.haps.d$line=="12mdsc",]$upper.CL,length=0, col="black")
#'plot no epistasis "X" for the strain pair erg5 (nbm58) and erg7 dsc2 (nbm12 dsc2)
points(2, ypd.haps.d[ypd.haps.d$line=="58m",]$lsmean+ypd.haps.d[ypd.haps.d$line=="12mdsc",]$lsmean-(ypd.haps.d[ypd.haps.d$line=="wt",]$lsmean), pch=4, col="red", cex=2)
#’compare erg5 erg7 dsc2 (nbm58:12 dsc2) with erg7 dsc2 (nbm12 dsc2)
lines(c(2.2,3.2), c(ypd.haps.d[ypd.haps.d$line=="12m58mdsc",]$lsmean,ypd.haps.d[ypd.haps.d$line=="12mdsc",]$lsmean), lty=3)

#'erg6-erg7 (nbm8-nbm12) - ypd
#'first plot only strains without mutation in DSC2
plot_pair(ypd.haps.d, "8m", "8m12m", "12m", "wt")
#'plot erg7 (nbm12) with mutation in DSC2 and compare to strains without mutation in DSC2
lines(c(2,3.2), c(ypd.haps.d[ypd.haps.d$line=="8m12m",]$lsmean,ypd.haps.d[ypd.haps.d$line=="12mdsc",]$lsmean), lty=3)
lines(c(2,3.2), c(ypd.haps.d[ypd.haps.d$line=="wt",]$lsmean,ypd.haps.d[ypd.haps.d$line=="12mdsc",]$lsmean), lty=1)
points(3.2, ypd.haps.d[ypd.haps.d$line=="12mdsc",]$lsmean, pch=16, col=ypd.haps.d[ypd.haps.d$line=="12m",]$col, cex=2)
arrows(3.2, ypd.haps.d[ypd.haps.d$line=="12mdsc",]$lower.CL, 3.2, ypd.haps.d[ypd.haps.d$line=="12mdsc",]$upper.CL,length=0, col="black")
#'plot no epistasis "X" for the strain pair erg6 (nbm8) and erg7 dsc2 (nbm12 dsc2)
points(2, ypd.haps.d[ypd.haps.d$line=="8m",]$lsmean+ypd.haps.d[ypd.haps.d$line=="12mdsc",]$lsmean-(ypd.haps.d[ypd.haps.d$line=="wt",]$lsmean), pch=4, col="red", cex=2)

#'7-7 (12-12)
plot(1, type="n", axes=F, xlab="", ylab="")
text(1,1,labels="erg7", cex=3, col=nys.haps.d[nys.haps.d$line=="12m",]$col)

#'add text
mtext("Maximum Growth Rate over 24hr", side=2, line=3.2, adj=0.5, cex=1.2,  outer=TRUE) 
mtext("Nystatin", side=3, line=1.3, adj=0.65, cex=1.5,  outer=TRUE) 
mtext("YPD", side=1, line=2, adj=0.37, cex=1.5,  outer=TRUE) 

#'add lines for YPD heading
arrows(-1.6,0.51,0.13,0.51,length=0,col="black",xpd=NA, lwd=3)
arrows(-1.6,0.51,-1.6,0.56,length=0,col="black",xpd=NA, lwd=3)
arrows(0.13,0.51,0.13,0.56,length=0,col="black",xpd=NA, lwd=3)
#'add lines for nystatin heading
arrows(-0.72,4.08,1.01,4.08,length=0,col="black",xpd=NA, lwd=3)
arrows(-0.72,4.08,-0.72,4.03,length=0,col="black",xpd=NA, lwd=3)
arrows(1.01,4.08,1.01,4.03,length=0,col="black",xpd=NA, lwd=3)
#'add legend
legend(1.65,2.84,c("wildtype","hypothetical double", "mutant (no epistasis)","double mutant","erg3 single mutant","erg5 single mutant","erg6 single mutant","erg7 single mutant"),pch=c(16,4,NA,16,16,16,16,16), bty="n", xpd=NA, col=c("#BEBEBE","#000000",NA,"#000000","#FFD700","#008B00","#8B0000","#87CEEB"), pt.cex=2, x.intersp = 0.8,y.intersp = c(1.4,1.4,1.3,1.4,1.4,1.4,1.4,1.4), cex=1.25)

#'open the plot
dev.off()
system("open DSC2/plots/HapGRPlotDSC2.pdf")


#####PLOT ALL MAXIMUM GROWTH RATES IN TABLES - EXCLUDING STRAINS THAT ARE MUTANT FOR DSC2#####
pdf("DSC2/plots/HapGRPlotNoDSC2.pdf", width=7.5, height=6, family="ArialMT", pointsize=10)

par(mfrow=c(4,4), mar=c(0,0,0,0), oma=c(4,5,4,15))

#'erg3-erg3 (nbm45-nbm45)
plot(1, type="n", axes=F, xlab="", ylab="")
text(1,1,labels="erg3", cex=3, col=nys.haps.nod[nys.haps.nod$line=="45m",]$col)

#'erg3-erg5 (nbm45-nbm58)
plot_pair(nys.haps.nod, "45m", "45m58m", "58m", "wt")
text(1,0.35,"S", cex=2, font=2)

#'erg3-erg6 (nbm45-nbm8)
plot_pair(nys.haps.nod, "45m", "8m45m", "8m", "wt")
text(1,0.35,"notRS - marg", cex=0.75, font=2)

#'erg3-erg7 (nbm45-nbm12)
#'generate plot (no data for double mutant because both have mutations in DSC2)
plot(c(1,2,3), type="n", ylim=c(0.01,0.39), xlim=c(0.5,3.5), xaxt="n", yaxt="n", ylab="")
lines(c(1,2), c(nys.haps.nod[nys.haps.nod$line=="45m",]$lsmean,nys.haps.nod[nys.haps.nod$line=="wt",]$lsmean), lty=nys.haps.nod[nys.haps.nod$line=="45m",]$lty1)
lines(c(2,3), c(nys.haps.nod[nys.haps.nod$line=="wt",]$lsmean,nys.haps.nod[nys.haps.nod$line=="12m",]$lsmean), lty=nys.haps.nod[nys.haps.nod$line=="12m",]$lty1)
points(1, nys.haps.nod[nys.haps.nod$line=="45m",]$lsmean, pch=16, col=nys.haps.nod[nys.haps.nod$line=="45m",]$col, cex=2)
arrows(1, nys.haps.nod[nys.haps.nod$line=="45m",]$lower.CL, 1, nys.haps.nod[nys.haps.nod$line=="45m",]$upper.CL,length=0, col="black")
points(3, nys.haps.nod[nys.haps.nod$line=="12m",]$lsmean, pch=16, col=nys.haps.nod[nys.haps.nod$line=="12m",]$col, cex=2)
arrows(3, nys.haps.nod[nys.haps.nod$line=="12m",]$lower.CL, 3, nys.haps.nod[nys.haps.nod$line=="12m",]$upper.CL,length=0, col="black")
points(2, nys.haps.nod[nys.haps.nod$line=="wt",]$lsmean, pch=16, col=nys.haps.nod[nys.haps.nod$line=="wt",]$col, cex=2)
arrows(2, nys.haps.nod[nys.haps.nod$line=="wt",]$lower.CL, 2, nys.haps.nod[nys.haps.nod$line=="wt",]$upper.CL,length=0, col="black")
points(2, nys.haps.nod[nys.haps.nod$line=="45m",]$lsmean+nys.haps.nod[nys.haps.nod$line=="12m",]$lsmean-(nys.haps.nod[nys.haps.nod$line=="wt",]$lsmean), pch=4, col="black", cex=2)

axis(4, las=1, at=c(0.05,0.1,0.15,0.20,0.25,0.30,0.35))

#'erg3-erg5 (nbm45-nbm58) - ypd
plot_pair(ypd.haps.nod, "45m", "45m58m", "58m", "wt")
axis(2, las=1, at=c(0.05,0.1,0.15,0.20,0.25,0.30,0.35))

#'erg5-erg5 (nbm58-nbm58)
plot(1, type="n", axes=F, xlab="", ylab="")
text(1,1,labels="erg5", cex=3, col=nys.haps.nod[nys.haps.nod$line=="58m",]$col)

#'erg5-erg6 (nbm58-nbm8) 
plot_pair(nys.haps.nod, "58m", "8m58m", "8m", "wt")

#'erg5-erg7 (nbm58-nbm12)
plot_pair(nys.haps.nod, "58m", "12m58m", "12m", "wt")
axis(4, las=1, at=c(0.05,0.1,0.15,0.20,0.25,0.30,0.35))

#'erg3-erg6 (nbm45-nbm8) - ypd
plot_pair(ypd.haps.nod, "45m", "8m45m", "8m", "wt")
axis(2, las=1, at=c(0.05,0.1,0.15,0.20,0.25,0.30,0.35))

#'erg5-erg6 (nbm58-nbm8) - ypd
plot_pair(ypd.haps.nod, "58m", "8m58m", "8m", "wt")

#'erg6-erg6 (nbm8-nbm8) 
plot(1, type="n", axes=F, xlab="", ylab="")
text(1,1,labels="erg6", cex=3, col=nys.haps.nod[nys.haps.nod$line=="8m",]$col)

#'erg6-erg7 (nbm8-nbm12)
plot_pair(nys.haps.nod, "8m", "8m12m", "12m", "wt")
text(1,0.35,"RS", cex=2, font=2)
axis(4, las=1, at=c(0.05,0.1,0.15,0.20,0.25,0.30,0.35))

#'erg3-erg7 (nbm45-nbm12) - ypd
#'generate plot (no data for double mutant because both have mutations in DSC2)
plot(c(1,2,3), type="n", ylim=c(0.01,0.39), xlim=c(0.5,3.5), xaxt="n", yaxt="n", ylab="")
lines(c(1,2), c(ypd.haps.nod[ypd.haps.nod$line=="45m",]$lsmean,ypd.haps.nod[ypd.haps.nod$line=="wt",]$lsmean), lty=ypd.haps.nod[ypd.haps.nod$line=="45m",]$lty1)
lines(c(2,3), c(ypd.haps.nod[ypd.haps.nod$line=="wt",]$lsmean,ypd.haps.nod[ypd.haps.nod$line=="12m",]$lsmean), lty=ypd.haps.nod[ypd.haps.nod$line=="12m",]$lty1)
points(1, ypd.haps.nod[ypd.haps.nod$line=="45m",]$lsmean, pch=16, col=ypd.haps.nod[ypd.haps.nod$line=="45m",]$col, cex=2)
arrows(1, ypd.haps.nod[ypd.haps.nod$line=="45m",]$lower.CL, 1, ypd.haps.nod[ypd.haps.nod$line=="45m",]$upper.CL,length=0, col="black")
points(3, ypd.haps.nod[ypd.haps.nod$line=="12m",]$lsmean, pch=16, col=ypd.haps.nod[ypd.haps.nod$line=="12m",]$col, cex=2)
arrows(3, ypd.haps.nod[ypd.haps.nod$line=="12m",]$lower.CL, 3, ypd.haps.nod[ypd.haps.nod$line=="12m",]$upper.CL,length=0, col="black")
points(2, ypd.haps.nod[ypd.haps.nod$line=="wt",]$lsmean, pch=16, col=ypd.haps.nod[ypd.haps.nod$line=="wt",]$col, cex=2)
arrows(2, ypd.haps.nod[ypd.haps.nod$line=="wt",]$lower.CL, 2, ypd.haps.nod[ypd.haps.nod$line=="wt",]$upper.CL,length=0, col="black")
points(2, ypd.haps.nod[ypd.haps.nod$line=="45m",]$lsmean+ypd.haps.nod[ypd.haps.nod$line=="12m",]$lsmean-(ypd.haps.nod[ypd.haps.nod$line=="wt",]$lsmean), pch=4, col="black", cex=2)

axis(2, las=1, at=c(0.05,0.1,0.15,0.20,0.25,0.30,0.35))

#'erg5-erg7 (nbm58-nbm12) - ypd
plot_pair(ypd.haps.nod, "58m", "12m58m", "12m", "wt")

#'erg6-erg7 (nbm8-nbm12) - ypd
plot_pair(ypd.haps.nod, "8m", "8m12m", "12m", "wt")

#'erg7-erg7 (nbm12-nbm12)
plot(1, type="n", axes=F, xlab="", ylab="")
text(1,1,labels="erg7", cex=3, col=nys.haps.nod[nys.haps.nod$line=="12m",]$col)

#'add text
mtext("Maximum Growth Rate over 24hr", side=2, line=3.2, adj=0.5, cex=1.2,  outer=TRUE) 
mtext("Nystatin", side=3, line=1.3, adj=0.65, cex=1.5,  outer=TRUE) 
mtext("YPD", side=1, line=2, adj=0.37, cex=1.5,  outer=TRUE) 

#'add lines for YPD heading
arrows(-1.6,0.51,0.13,0.51,length=0,col="black",xpd=NA, lwd=3)
arrows(-1.6,0.51,-1.6,0.56,length=0,col="black",xpd=NA, lwd=3)
arrows(0.13,0.51,0.13,0.56,length=0,col="black",xpd=NA, lwd=3)
#'add lines for nystatin heading
arrows(-0.72,4.08,1.01,4.08,length=0,col="black",xpd=NA, lwd=3)
arrows(-0.72,4.08,-0.72,4.03,length=0,col="black",xpd=NA, lwd=3)
arrows(1.01,4.08,1.01,4.03,length=0,col="black",xpd=NA, lwd=3)
#'add legend
legend(1.65,2.84,c("wildtype","hypothetical double", "mutant (no epistasis)","double mutant","erg3 single mutant","erg5 single mutant","erg6 single mutant","erg7 single mutant"),pch=c(16,4,NA,16,16,16,16,16), bty="n", xpd=NA, col=c("#BEBEBE","#000000",NA,"#000000","#FFD700","#008B00","#8B0000","#87CEEB"), pt.cex=2, x.intersp = 0.8,y.intersp = c(1.4,1.4,1.3,1.4,1.4,1.4,1.4,1.4), cex=1.25)

#'open the plot
dev.off()
system("open DSC2/plots/HapGRPlotNoDSC2.pdf")
