library("extrafont")
loadfonts()

#####READ IN DATA#####
nys.haps <- read.csv("GR.ExcludeOne/Nys2HapsMeans.ExclOne.csv", sep=",", as.is=TRUE)

nys.contr <- read.csv("GR.ExcludeOne/Nys2HapsContrasts.ExclOne.csv", sep=",", as.is=TRUE)

#####SET UP DATA#####
#'make a column with line names as we usually use them
nys.haps$line <- ""

for (i in 1:length(nys.haps$line)){
  for (j in 1:4){
    if(nys.haps[i,j]=="m"){
      if(j==1){
        nys.haps$line[i] <- paste(nys.haps$line[i], "8m", sep="") 
      }
      if(j==2){
        nys.haps$line[i] <- paste(nys.haps$line[i], "12m", sep="") 
      }
      if(j==3){
        nys.haps$line[i] <- paste(nys.haps$line[i], "45m", sep="") 
      }
      if(j==4){
        nys.haps$line[i] <- paste(nys.haps$line[i], "58m", sep="") 
      }
    }
  }
}

#'manually add the wt name
nys.haps$line[1] <- "wt"

#'make a column with line names for use with contrasts
nys.haps$geno <- paste(nys.haps$nbm8, nys.haps$nbm12, nys.haps$nbm45, nys.haps$nbm58, sep=",")

#####SETTING UP PLOTTING#####
#'make 2 new columns with lty values 
#'lty1 == 1 if double mutant significantly different from the first single mutant or if single mutant significantly different from the ancestor
#'lty2 == 1 if double mutant significantly different from the second single mutant or if single mutant significantly different from the ancestor
#'otherwise, lty==3

nys.haps$lty1 <- NA
nys.haps$lty2 <- NA

#'write function to set lty
set_lty <- function(data, contr, sngl1, sngl2, dbl, wt){  
  if (contr[contr$contrast==paste(data[data$line==sngl1,]$geno, data[data$line==dbl,]$geno, sep=" - "),]$p<0.05){
    data[data$line==dbl,]$lty1 <- 1
  }else{data[data$line==dbl,]$lty1 <- 3}
  
  if (contr[contr$contrast==paste(data[data$line==sngl2,]$geno, data[data$line==dbl,]$geno, sep=" - "),]$p<0.05){
    data[data$line==dbl,]$lty2 <- 1
  }else{data[data$line==dbl,]$lty2 <- 3}
  
  if (contr[contr$contrast==paste(data[data$line==wt,]$geno, data[data$line==sngl1,]$geno, sep=" - "),]$p<0.05){
    data[data$line==sngl1,]$lty1 <- 1
  }else{data[data$line==sngl1,]$lty1 <- 3}
  
  if (contr[contr$contrast==paste(data[data$line==wt,]$geno, data[data$line==sngl2,]$geno, sep=" - "),]$p<0.05){
    data[data$line==sngl2,]$lty1 <- 1
  }else{data[data$line==sngl2,]$lty1 <- 3}
  
  return(data)
}

#'set ltys
nys.haps <- set_lty(nys.haps, nys.contr, "8m", "12m", "8m12m", "wt")
nys.haps <- set_lty(nys.haps, nys.contr, "45m", "8m", "8m45m", "wt")
nys.haps <- set_lty(nys.haps, nys.contr, "58m", "8m", "8m58m", "wt")
nys.haps <- set_lty(nys.haps, nys.contr, "45m", "12m", "12m45m", "wt")
nys.haps <- set_lty(nys.haps, nys.contr, "58m", "12m", "12m58m", "wt")
nys.haps <- set_lty(nys.haps, nys.contr, "45m", "58m", "45m58m", "wt")

#'set colours of points
nys.haps$col <- NA
nys.haps[nys.haps$line=="wt",]$col <- "#BEBEBE"
nys.haps[nys.haps$line=="8m",]$col <- "#8B0000"
nys.haps[nys.haps$line=="12m",]$col <- "#87CEEB"
nys.haps[nys.haps$line=="45m",]$col <- "#FFD700"
nys.haps[nys.haps$line=="58m",]$col <- "#008B00"
nys.haps[nys.haps$line=="8m12m",]$col <- "#000000"
nys.haps[nys.haps$line=="8m45m",]$col <- "#000000"
nys.haps[nys.haps$line=="8m58m",]$col <- "#000000"
nys.haps[nys.haps$line=="12m45m",]$col <- "#000000"
nys.haps[nys.haps$line=="12m58m",]$col <- "#000000"
nys.haps[nys.haps$line=="45m58m",]$col <- "#000000"

#'write function to make plots
plot_pair <- function(data, sngl1, dbl, sngl2, wt){
  plot(c(1,2,3), type="n", ylim=c(0.01,0.39), xlim=c(0.5,3.5), xaxt="n", yaxt="n", ylab="")
  lines(c(1,2), c(data[data$line==sngl1,]$lsmean,data[data$line==dbl,]$lsmean), lty=data[data$line==dbl,]$lty1)
  lines(c(2,3), c(data[data$line==dbl,]$lsmean,data[data$line==sngl2,]$lsmean), lty=data[data$line==dbl,]$lty2)
  lines(c(1,2), c(data[data$line==sngl1,]$lsmean,data[data$line==wt,]$lsmean), lty=data[data$line==sngl1,]$lty1)
  lines(c(2,3), c(data[data$line==wt,]$lsmean,data[data$line==sngl2,]$lsmean), lty=data[data$line==sngl2,]$lty1)
  points(1, data[data$line==sngl1,]$lsmean, pch=16, col=data[data$line==sngl1,]$col, cex=2)
  arrows(1, data[data$line==sngl1,]$lower.CL, 1, data[data$line==sngl1,]$upper.CL,length=0, col="black")
  points(2, data[data$line==dbl,]$lsmean, pch=16, col=data[data$line==dbl,]$col, cex=2)
  arrows(2, data[data$line==dbl,]$lower.CL, 2, data[data$line==dbl,]$upper.CL,length=0, col="black")
  points(3, data[data$line==sngl2,]$lsmean, pch=16, col=data[data$line==sngl2,]$col, cex=2)
  arrows(3, data[data$line==sngl2,]$lower.CL, 3, data[data$line==sngl2,]$upper.CL,length=0, col="black")
  points(2, data[data$line==wt,]$lsmean, pch=16, col=data[data$line==wt,]$col, cex=2)
  arrows(2, data[data$line==wt,]$lower.CL, 2, data[data$line==wt,]$upper.CL,length=0, col="black")
  points(2, data[data$line==sngl1,]$lsmean+data[data$line==sngl2,]$lsmean-(data[data$line==wt,]$lsmean), pch=4, col="black", cex=2)
}


#####PLOT MAXIMUM GROWTH RATES IN TABLE - HAPLOIDS - ONLY NYSTATIN2 (ONLY CHANGED NYSTATIN2 DATA)#####
pdf("GR.ExcludeOne/HapNys2GRPlot.ExclOne.pdf", width=7.5, height=6, family="ArialMT", pointsize=10)

par(mfrow=c(4,4), mar=c(0,0,0,0), oma=c(4,5,4,15))

#'erg3-erg3 (nbm45-nbm45)
plot(1, type="n", axes=F, xlab="", ylab="")
text(1,1,labels="erg3", cex=3, col=nys.haps[nys.haps$line=="45m",]$col)

#'erg3-erg5 (nbm45-nbm58)
plot_pair(nys.haps, "45m", "45m58m", "58m", "wt")
text(1,0.35,"S", cex=2, font=2)

#'erg3-erg6 (nbm45-nbm8)
plot_pair(nys.haps, "45m", "8m45m", "8m", "wt")
text(1.4,0.25,"S (RS P = 0.058)", cex=1, font=2)

#'erg3-erg7 (nbm45-nbm12)
plot_pair(nys.haps, "45m", "12m45m", "12m", "wt")
text(1,0.35,"S", cex=2, font=2)
axis(4, las=1, at=c(0.05,0.1,0.15,0.20,0.25,0.30,0.35))

#'erg3-erg5 (nbm45-nbm58) - don't plot YPD
plot(1, type="n", axes=F, xlab="", ylab="")

#'erg5-erg5 (nbm58-nbm58)
plot(1, type="n", axes=F, xlab="", ylab="")
text(1,1,labels="erg5", cex=3, col=nys.haps[nys.haps$line=="58m",]$col)

#'erg5-erg6 (nbm58-nbm8) 
plot_pair(nys.haps, "58m", "8m58m", "8m", "wt")

#'erg5-erg7 (nbm58-nbm12)
plot_pair(nys.haps, "58m", "12m58m", "12m", "wt")
axis(4, las=1, at=c(0.05,0.1,0.15,0.20,0.25,0.30,0.35))

#'erg3-erg6 (nbm45-nbm8) - don't plot YPD
plot(1, type="n", axes=F, xlab="", ylab="")

#'erg5-erg6 (nbm58-nbm8) - don't plot YPD
plot(1, type="n", axes=F, xlab="", ylab="")

#'erg6-erg6 (nbm8-nbm8) 
plot(1, type="n", axes=F, xlab="", ylab="")
text(1,1,labels="erg6", cex=3, col=nys.haps[nys.haps$line=="8m",]$col)

#'erg6-erg7 (nbm8-nbm12)
plot_pair(nys.haps, "8m", "8m12m", "12m", "wt")
text(1,0.35,"RS", cex=2, font=2)
axis(4, las=1, at=c(0.05,0.1,0.15,0.20,0.25,0.30,0.35))

#'erg3-erg7 (nbm45-nbm12) - don't plot YPD
plot(1, type="n", axes=F, xlab="", ylab="")

#'erg5-erg7 (nbm58-nbm12) - don't plot YPD
plot(1, type="n", axes=F, xlab="", ylab="")

#'erg6-erg7 (nbm8-nbm12) - don't plot YPD
plot(1, type="n", axes=F, xlab="", ylab="")

#'erg7-erg7 (nbm12-nbm12)
plot(1, type="n", axes=F, xlab="", ylab="")
text(1,1,labels="erg7", cex=3, col=nys.haps[nys.haps$line=="12m",]$col)

#'add text
mtext("Maximum Growth Rate over 24hr (no out)", side=2, line=3.2, adj=0.5, cex=1.2,  outer=TRUE) 
mtext("Nystatin", side=3, line=1.3, adj=0.65, cex=1.5,  outer=TRUE) 
mtext("YPD", side=1, line=2, adj=0.37, cex=1.5,  outer=TRUE) 

#'add lines for YPD heading
arrows(-1.6,0.51,0.13,0.51,length=0,col="black",xpd=NA, lwd=3)
arrows(-1.6,0.51,-1.6,0.56,length=0,col="black",xpd=NA, lwd=3)
arrows(0.13,0.51,0.13,0.56,length=0,col="black",xpd=NA, lwd=3)
#'add lines for nystatin heading
arrows(-0.72,4.08,1.01,4.08,length=0,col="black",xpd=NA, lwd=3)
arrows(-0.72,4.08,-0.72,4.03,length=0,col="black",xpd=NA, lwd=3)
arrows(1.01,4.08,1.01,4.03,length=0,col="black",xpd=NA, lwd=3)
#'add legend
legend(1.65,2.84,c("wildtype","hypothetical double", "mutant (no epistasis)","double mutant","erg3 single mutant","erg5 single mutant","erg6 single mutant","erg7 single mutant"),pch=c(16,4,NA,16,16,16,16,16), bty="n", xpd=NA, col=c("#BEBEBE","#000000",NA,"#000000","#FFD700","#008B00","#8B0000","#87CEEB"), pt.cex=2, x.intersp = 0.8,y.intersp = c(1.4,1.4,1.3,1.4,1.4,1.4,1.4,1.4), cex=1.25)

#'open the plot
dev.off()
system("open GR.ExcludeOne/HapNys2GRPlot.ExclOne.pdf")

