library("lsmeans")
library(lme4)

#####SETTING UP THE DATA#####
#'load already set up haploid data file
ypd.haps <- read.csv("GrowthRateAssays/data_output/lgrYPDHaps.csv", sep=",", as.is=TRUE)

#'make log(OD) column
ypd.haps$logK24.ypd <- log(ypd.haps$K24.ypd)

#'make mat, day, plate, genotype into factors
ypd.haps$nbm8 <- factor(ypd.haps$nbm8, levels=c("w","m"))
ypd.haps$nbm12 <- factor(ypd.haps$nbm12, levels=c("w","m"))
ypd.haps$nbm45 <- factor(ypd.haps$nbm45, levels=c("w","m"))
ypd.haps$nbm58 <- factor(ypd.haps$nbm58, levels=c("w","m"))
ypd.haps$Day <- factor(ypd.haps$Day)
ypd.haps$mat <- factor(ypd.haps$mat)
ypd.haps$Plate <- factor(ypd.haps$Plate)

#####MODEL - YPD HAPLOIDS BOTH MATING TYPES TOGETHER#####
#'write full model
#'plate within day as random effect
dat <- ypd.haps[is.na(ypd.haps$omit)&is.na(ypd.haps$out),]
ypd.haps.mat.model <- lmer(logK24.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat)

#'check assumptions
par(mfrow=c(2,2))
plot(fitted(ypd.haps.mat.model),residuals(ypd.haps.mat.model))
abline(h=0)
hist(residuals(ypd.haps.mat.model)) 
qqnorm(residuals(ypd.haps.mat.model)) 
qqline(residuals(ypd.haps.mat.model))
#'plot
boxplot(logK24.ypd ~ mat*nbm8*nbm12*nbm45*nbm58, dat, las=2)

#'estimates from model
summary(ypd.haps.mat.model)

#'find P-values by dropping terms one at a time
#'full model to compare to
Mfull <- lmer(logK24.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'drop interaction terms one by one
M1.1 <- lmer(logK24.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.2 <- lmer(logK24.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.3 <- lmer(logK24.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.4 <- lmer(logK24.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.5 <- lmer(logK24.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.6 <- lmer(logK24.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'anova comparing full model to model with one interaction term dropped
anova(Mfull, M1.1)
anova(Mfull, M1.2)
anova(Mfull, M1.3)
anova(Mfull, M1.4)
anova(Mfull, M1.5)
anova(Mfull, M1.6)

#'move on to mating type
M1.7 <- lmer(logK24.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
anova(Mfull, M1.7)

#'find the least-squares means (and confidence intervals) for each line
ypd.haps.lsmeans <- summary(lsmeans(ypd.haps.mat.model, c("nbm8","nbm12","nbm45","nbm58")))

#'tell it which comparisons to do - doesn't include doubles with wt
con <- summary(contrast(lsmeans(ypd.haps.mat.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise"))
lines.in <- c("w,w,w,w - m,w,w,w","w,w,w,w - w,m,w,w", "w,w,w,w - w,w,m,w", "w,w,w,w - w,w,w,m","m,w,w,w - m,m,w,w", "m,w,w,w - m,w,m,w", "m,w,w,w - m,w,w,m", "w,m,w,w - m,m,w,w", "w,m,w,w - w,m,m,w", "w,m,w,w - w,m,w,m", "w,w,m,w - m,w,m,w", "w,w,m,w - w,m,m,w", "w,w,m,w - w,w,m,m", "w,w,w,m - m,w,w,m", "w,w,w,m - w,m,w,m", "w,w,w,m - w,w,m,m")
ind.in <- c()
for (i in lines.in){
  ind.in <- c(ind.in, grep(i, con$contrast))
}

#'do the desired contrasts
ypd.haps.contrasts <- summary(contrast(lsmeans(ypd.haps.mat.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise")[ind.in])

#'write output of least-squares means and desired contrasts
write.csv(format(ypd.haps.lsmeans, digits=5), "GR.OpticalDensity/data_output/YPDHapsMeans.OD.csv", row.names=FALSE)
write.csv(format(ypd.haps.contrasts, digits=5), "GR.OpticalDensity/data_output/YPDHapsContrasts.OD.csv", row.names=FALSE)
