library(ggplot2)
library(reshape2)
library(RColorBrewer)

#####READ IN AND SET UP DATA#####
#'load in diploid mean and contrasts data (including heterozygotes)
nys.t <- read.csv("GrowthRateAssays/data_output/Nys2DipsTMeans.csv", sep=",", as.is=TRUE)
nys.t.contr <- read.csv("GrowthRateAssays/data_output/Nys2DipsTContrasts.csv", sep=",", as.is=TRUE)

#'make a column with line names as we usually use them
nys.t$line <- ""

for (i in 1:length(nys.t$line)){
  for (j in 1:4){
    if(nys.t[i,j]=="m"){
      if(j==1){
        nys.t$line[i] <- paste(nys.t$line[i], "8m", sep="") 
      }
      if(j==2){
        nys.t$line[i] <- paste(nys.t$line[i], "12m", sep="") 
      }
      if(j==3){
        nys.t$line[i] <- paste(nys.t$line[i], "45m", sep="") 
      }
      if(j==4){
        nys.t$line[i] <- paste(nys.t$line[i], "58m", sep="") 
      }
    }
    if(nys.t[i,j]=="t"){
      if(j==1){
        nys.t$line[i] <- paste(nys.t$line[i], "8t", sep="") 
      }
      if(j==2){
        nys.t$line[i] <- paste(nys.t$line[i], "12t", sep="") 
      }
      if(j==3){
        nys.t$line[i] <- paste(nys.t$line[i], "45t", sep="") 
      }
      if(j==4){
        nys.t$line[i] <- paste(nys.t$line[i], "58t", sep="") 
      }
    }
  }
}

nys.t$line[1] <- "wt"

#'make a column with line names for use with contrasts
nys.t$geno <- paste(nys.t$nbm8, nys.t$nbm12, nys.t$nbm45, nys.t$nbm58, sep=",")

#####SET UP ARROWS#####
#'write all potential starts and ends of arrows
#'two sets
x1 <- c(1.25,2.25,2.25,1.25,2.25,0,1.25,2.25,2.25)
xe1 <- c(1.75,2.75,2.75,1.75,2.75,0,1.75,2.75,2.75)
y1 <- c(1,1,1.75,2,2,0,3,3,2.25)
ye1 <- c(1,1,1.25,2,2,0,3,3,2.75)

x2 <- c(1,2,3,1,1.25,3,1.75,2,0)
xe2 <- c(1,2,3,1,1.75,3,1.25,2,0)
y2 <- c(1.25,1.25,1.25,2.25,1.25,2.25,2.25,2.25,0)
ye2 <- c(1.75,1.75,1.75,2.75,1.75,2.75,2.75,2.75,0)

#'write function to set which arrows to draw
set_alpha1 <- function(contr, dipg, alpha){  
if(contr[contr$contrast==paste(dipg[1], dipg[2], sep=" - "),]$p<0.05){
  alpha[1]<-1
}
if(contr[contr$contrast==paste(dipg[2], dipg[3], sep=" - "),]$p<0.05){
  alpha[2]<-1
}
if(contr[contr$contrast==paste(dipg[3], dipg[5], sep=" - "),]$p<0.05){
  alpha[3]<-1
}
if(contr[contr$contrast==paste(dipg[4], dipg[5], sep=" - "),]$p<0.05){
  alpha[4]<-1
}
if(contr[contr$contrast==paste(dipg[5], dipg[6], sep=" - "),]$p<0.05){
  alpha[5]<-1
}
if(contr[contr$contrast==paste(dipg[7], dipg[8], sep=" - "),]$p<0.05){
  alpha[7]<-1
}
if(contr[contr$contrast==paste(dipg[8], dipg[9], sep=" - "),]$p<0.05){
  alpha[8]<-1
}
if(contr[contr$contrast==paste(dipg[5], dipg[9], sep=" - "),]$p<0.05){
  alpha[9]<-1
}
return(alpha)
}

set_alpha2 <- function(contr, dipg, alpha){  
  if(contr[contr$contrast==paste(dipg[1], dipg[4], sep=" - "),]$p<0.05){
    alpha[1]<-1
  }
  if(contr[contr$contrast==paste(dipg[2], dipg[5], sep=" - "),]$p<0.05){
    alpha[2]<-1
  }
  if(contr[contr$contrast==paste(dipg[3], dipg[6], sep=" - "),]$p<0.05){
    alpha[3]<-1
  }
  if(contr[contr$contrast==paste(dipg[4], dipg[7], sep=" - "),]$p<0.05){
    alpha[4]<-1
  }
  if(contr[contr$contrast==paste(dipg[1], dipg[5], sep=" - "),]$p<0.05){
    alpha[5]<-1
  }
  if(contr[contr$contrast==paste(dipg[6], dipg[9], sep=" - "),]$p<0.05){
    alpha[6]<-1
  }
  if(contr[contr$contrast==paste(dipg[5], dipg[7], sep=" - "),]$p<0.05){
    alpha[7]<-1
  }
  if(contr[contr$contrast==paste(dipg[5], dipg[8], sep=" - "),]$p<0.05){
    alpha[8]<-1
  }
  return(alpha)
}

#####HEATMAPS#####
#'max lsmean of diploids is 0.21, so set max for colour palette to 0.22
myPalette <- colorRampPalette(rev(brewer.pal(9, "Greens")))
values <- seq(0.22, 0, length=100)

#to make the legend
leg <- c(0.05,0.2,0.22,0.21)
leg.matrix <- matrix(leg, 2, 2)
rnames <- c("y1", "y2")
cnames <- c("x1", "x2")
rownames(leg.matrix) <- rnames
colnames(leg.matrix) <- cnames
longData <- melt(leg.matrix)
names(longData) <- c("Var1","Var2","lgr")

name="Experimental\nCondition"
zp1 <- ggplot(longData, aes(x = Var1, y = Var2, fill = lgr))
zp1 <- zp1 + geom_tile()
zp1 <- zp1 + scale_fill_gradientn(colours = myPalette(100), values = values, rescaler = function(x,...) x, oob = identity)
zp1 <- zp1 + scale_x_discrete(expand = c(0, 0))
zp1 <- zp1 + scale_y_discrete(expand = c(0, 0))
zp1 <- zp1 + coord_equal()
zp1 <- zp1 + theme_bw()
zp1 <- zp1 + theme(text=element_text(size=20))
print(zp1)
ggsave("Figures/HeatmapLegend.S4Fig.pdf")

#NBM45*58 = erg3 erg5 
dip4558.l <- c("wt", "45t", "45m", "58t", "45t58t", "45m58t", "58m", "45t58m", "45m58m")
dip4558 <- c()
for (i in dip4558.l){
  dip4558 <- c(dip4558, nys.t[nys.t$line==i,]$lsmean)
}

dip4558.g <- nys.t$geno[nys.t$line%in%dip4558.l]
a1 <- c(0,0,0,0,0,0,0,0,0)
a2 <- c(0,0,0,0,0,0,0,0,0)
a1 <- set_alpha1(nys.t.contr,dip4558.g,a1)
a2 <- set_alpha2(nys.t.contr,dip4558.g,a2)

dip4558.matrix <- matrix(dip4558, 3, 3)
rnames <- c("+/+","+/m","m/m")
cnames <- c("+/+","+/m","m/m")
rownames(dip4558.matrix) <- rnames
colnames(dip4558.matrix) <- cnames
longData <- melt(dip4558.matrix)
names(longData) <- c("erg3","erg5","lsmean")

zp1 <- ggplot(longData, aes(x = erg3, y = erg5, fill = lsmean))
zp1 <- zp1 + geom_tile()
zp1 <- zp1 + scale_fill_gradientn(colours = myPalette(100), values = values, rescaler = function(x,...) x, oob = identity)
zp1 <- zp1 + scale_x_discrete(expand = c(0, 0))
zp1 <- zp1 + scale_y_discrete(expand = c(0, 0))
zp1 <- zp1 + coord_equal()
zp1 <- zp1 + theme_bw()
zp1 <- zp1 + theme(text=element_text(size=20))
zp1 <- zp1 + geom_segment(x=x1,y=y1,xend=xe1,yend=ye1,arrow=arrow(), size=1, color="deeppink", alpha=a1)
zp1 <- zp1 + geom_segment(x=x2,y=y2,xend=xe2,yend=ye2,arrow=arrow(), size=1, color="deeppink", alpha=a2)
print(zp1)
ggsave("Figures/Heatmap35.S4Fig.pdf", width=5, height=5)

#NBM45*8 = erg3 erg6
dip845.l <- c("wt", "45t", "45m", "8t", "8t45t", "8t45m", "8m", "8m45t", "8m45m")
dip845 <- c()
for (i in dip845.l){
  dip845 <- c(dip845, nys.t[nys.t$line==i,]$lsmean)
}

dip845.g <- nys.t$geno[nys.t$line%in%dip845.l]
a1 <- c(0,0,0,0,0,0,0,0,0)
a2 <- c(0,0,0,0,0,0,0,0,0)
a1 <- set_alpha1(nys.t.contr,dip845.g,a1)
a2 <- set_alpha2(nys.t.contr,dip845.g,a2)
#fix the arrow orientation
#erg6 erg3, arrow should point from erg3/erg3 erg6/+ —> erg3/erg3
x1b <- c(x1[1:6], xe1[7], x1[8:9])
xe1b <- c(xe1[1:6], x1[7], xe1[8:9])

dip845.matrix <- matrix(dip845, 3, 3)
rownames(dip845.matrix) <- rnames
colnames(dip845.matrix) <- cnames
longData <- melt(dip845.matrix)
names(longData) <- c("erg3","erg6","lsmean")

zp1 <- ggplot(longData, aes(x = erg3, y = erg6, fill = lsmean))
zp1 <- zp1 + geom_tile()
zp1 <- zp1 + scale_fill_gradientn(colours = myPalette(100), values = values, rescaler = function(x,...) x, oob = identity)
zp1 <- zp1 + scale_x_discrete(expand = c(0, 0))
zp1 <- zp1 + scale_y_discrete(expand = c(0, 0))
zp1 <- zp1 + coord_equal()
zp1 <- zp1 + theme_bw()
zp1 <- zp1 + theme(text=element_text(size=20))
zp1 <- zp1 + geom_segment(x=y1,y=x1b,xend=ye1,yend=xe1b,arrow=arrow(), size=1, color="deeppink", alpha=a1)
zp1 <- zp1 + geom_segment(x=y2,y=x2,xend=ye2,yend=xe2,arrow=arrow(), size=1, color="deeppink", alpha=a2)
print(zp1)
ggsave("Figures/Heatmap36.S4Fig.pdf", width=5, height=5)

#NBM45*12 - erg3 erg7 
dip1245.l <- c("wt", "45t", "45m", "12t", "12t45t", "12t45m", "12m", "12m45t", "12m45m")
dip1245 <- c()
for (i in dip1245.l){
  dip1245 <- c(dip1245, nys.t[nys.t$line==i,]$lsmean)
}

dip1245.g <- nys.t$geno[nys.t$line%in%dip1245.l]
a1 <- c(0,0,0,0,0,0,0,0,0)
a2 <- c(0,0,0,0,0,0,0,0,0)
a1 <- set_alpha1(nys.t.contr,dip1245.g,a1)
a2 <- set_alpha2(nys.t.contr,dip1245.g,a2)
#fix the arrow orientation
#erg7 erg3, arrow should point from erg3/erg3 erg7/+ —> erg3/erg3
x1c <- c(x1[1:6], xe1[7], x1[8:9])
xe1c <- c(xe1[1:6], x1[7], xe1[8:9])

dip1245.matrix <- matrix(dip1245, 3, 3)
rownames(dip1245.matrix) <- rnames
colnames(dip1245.matrix) <- cnames
longData <- melt(dip1245.matrix)
names(longData) <- c("erg3","erg7","lsmean")

zp1 <- ggplot(longData, aes(x = erg3, y = erg7, fill = lsmean))
zp1 <- zp1 + geom_tile()
zp1 <- zp1 + scale_fill_gradientn(colours = myPalette(100), values = values, rescaler = function(x,...) x, oob = identity)
zp1 <- zp1 + scale_x_discrete(expand = c(0, 0))
zp1 <- zp1 + scale_y_discrete(expand = c(0, 0))
zp1 <- zp1 + coord_equal()
zp1 <- zp1 + theme_bw()
zp1 <- zp1 + theme(text=element_text(size=20))
zp1 <- zp1 + geom_segment(x=y1,y=x1c,xend=ye1,yend=xe1c, arrow=arrow(), size=1, color="deeppink", alpha=a1)
zp1 <- zp1 + geom_segment(x=y2,y=x2,xend=ye2,yend=xe2,arrow=arrow(), size=1, color="deeppink", alpha=a2)
print(zp1)
ggsave("Figures/Heatmap37.S4Fig.pdf", width=5, height=5)

#NBM58*8 - erg5 erg6
dip858.l <- c("wt", "58t", "58m", "8t", "8t58t", "8t58m", "8m", "8m58t", "8m58m")
dip858 <- c()
for (i in dip858.l){
  dip858 <- c(dip858, nys.t[nys.t$line==i,]$lsmean)
}

dip858.g <- nys.t$geno[nys.t$line%in%dip858.l]
a1 <- c(0,0,0,0,0,0,0,0,0)
a2 <- c(0,0,0,0,0,0,0,0,0)
a1 <- set_alpha1(nys.t.contr,dip858.g,a1)
a2 <- set_alpha2(nys.t.contr,dip858.g,a2)

dip858.matrix <- matrix(dip858, 3, 3)
rownames(dip858.matrix) <- rnames
colnames(dip858.matrix) <- cnames
longData <- melt(dip858.matrix)
names(longData) <- c("erg5","erg6","lsmean")

zp1 <- ggplot(longData, aes(x = erg5, y = erg6, fill = lsmean))
zp1 <- zp1 + geom_tile()
zp1 <- zp1 + scale_fill_gradientn(colours = myPalette(100), values = values, rescaler = function(x,...) x, oob = identity)
zp1 <- zp1 + scale_x_discrete(expand = c(0, 0))
zp1 <- zp1 + scale_y_discrete(expand = c(0, 0))
zp1 <- zp1 + coord_equal()
zp1 <- zp1 + theme_bw()
zp1 <- zp1 + theme(text=element_text(size=20))
zp1 <- zp1 + geom_segment(x=y1,y=x1,xend=ye1,yend=xe1,arrow=arrow(), size=1, color="deeppink", alpha=a1)
zp1 <- zp1 + geom_segment(x=y2,y=x2,xend=ye2,yend=xe2,arrow=arrow(), size=1, color="deeppink", alpha=a2)
print(zp1)
ggsave("Figures/Heatmap56.S4Fig.pdf", width=5, height=5)

#NBM58*12 - erg5 erg7
dip1258.l <- c("wt", "58t", "58m", "12t", "12t58t", "12t58m", "12m", "12m58t", "12m58m")
dip1258 <- c()
for (i in dip1258.l){
  dip1258 <- c(dip1258, nys.t[nys.t$line==i,]$lsmean)
}

dip1258.g <- nys.t$geno[nys.t$line%in%dip1258.l]
a1 <- c(0,0,0,0,0,0,0,0,0)
a2 <- c(0,0,0,0,0,0,0,0,0)
a1 <- set_alpha1(nys.t.contr,dip1258.g,a1)
a2 <- set_alpha2(nys.t.contr,dip1258.g,a2)

dip1258.matrix <- matrix(dip1258, 3, 3)
rownames(dip1258.matrix) <- rnames
colnames(dip1258.matrix) <- cnames
longData <- melt(dip1258.matrix)
names(longData) <- c("erg5","erg7","lsmean")

zp1 <- ggplot(longData, aes(x = erg5, y = erg7, fill = lsmean))
zp1 <- zp1 + geom_tile()
zp1 <- zp1 + scale_fill_gradientn(colours = myPalette(100), values = values, rescaler = function(x,...) x, oob = identity)
zp1 <- zp1 + scale_x_discrete(expand = c(0, 0))
zp1 <- zp1 + scale_y_discrete(expand = c(0, 0))
zp1 <- zp1 + coord_equal()
zp1 <- zp1 + theme_bw()
zp1 <- zp1 + theme(text=element_text(size=20))
zp1 <- zp1 + geom_segment(x=y1,y=x1,xend=ye1,yend=xe1,arrow=arrow(), size=1, color="deeppink", alpha=a1)
zp1 <- zp1 + geom_segment(x=y2,y=x2,xend=ye2,yend=xe2,arrow=arrow(), size=1, color="deeppink", alpha=a2)
print(zp1)
ggsave("Figures/Heatmap57.S4Fig.pdf", width=5, height=5)

#NBM8*12 - erg6 erg7
dip812.l <- c("wt", "8t", "8m", "12t", "8t12t", "8m12t", "12m", "8t12m", "8m12m")
dip812 <- c()
for (i in dip812.l){
  dip812 <- c(dip812, nys.t[nys.t$line==i,]$lsmean)
}

dip812.g <- nys.t$geno[nys.t$line%in%dip812.l]
a1 <- c(0,0,0,0,0,0,0,0,0)
a2 <- c(0,0,0,0,0,0,0,0,0)
a1 <- set_alpha1(nys.t.contr,dip812.g,a1)
a2 <- set_alpha2(nys.t.contr,dip812.g,a2)
#fix the arrow orientation
# erg7 erg6, arrow should point from erg7/erg7 erg6/erg6 —> erg7/erg7 erg6/+
# erg7 erg6, arrow should point from erg7/erg7 erg6/erg6 —> erg7/+ erg6/erg6
x1d <- c(x1[1:7], xe1[8], x1[9])
xe1d <- c(xe1[1:7], x1[8], xe1[9])
y2d <- c(y2[1:5], ye2[6], y2[7:9])
ye2d <- c(ye2[1:5], y2[6], ye2[7:9])

dip812.matrix <- matrix(dip812, 3, 3)
rownames(dip812.matrix) <- rnames
colnames(dip812.matrix) <- cnames
longData <- melt(dip812.matrix)
names(longData) <- c("erg6","erg7","lsmean")

zp1 <- ggplot(longData, aes(x = erg6, y = erg7, fill = lsmean))
zp1 <- zp1 + geom_tile()
zp1 <- zp1 + scale_fill_gradientn(colours = myPalette(100), values = values, rescaler = function(x,...) x, oob = identity)
zp1 <- zp1 + scale_x_discrete(expand = c(0, 0))
zp1 <- zp1 + scale_y_discrete(expand = c(0, 0))
zp1 <- zp1 + coord_equal()
zp1 <- zp1 + theme_bw()
zp1 <- zp1 + theme(text=element_text(size=20))
zp1 <- zp1 + geom_segment(x=x1d, y=y1, xend=xe1d, yend=ye1, arrow=arrow(), size=1, color="deeppink", alpha=a1)
zp1 <- zp1 + geom_segment(x=x2, y=y2d, xend=xe2, yend=ye2d, arrow=arrow(), size=1, color="deeppink", alpha=a2)
print(zp1)
ggsave("Figures/Heatmap67.S4Fig.pdf", width=5, height=5)

