library("lsmeans")
library(lme4)

#####SETTING UP THE DATA#####
#'load in data with outliers marked
nys <- read.csv("GrowthRateAssays/data_output/OmitOutlierNys2.csv", sep=",", as.is=TRUE)

#'sep dips and haps
names.dips <- c("812d", "45m", "12t", "845d", "8m45t", "45m8t", "8t",  "58m", "45t", "845t", "1258t", "1245d", "58t", "1258d", "12m", "58m45t", "8m", "1245t",  "d",  "4558t", "12m58t",  "8m12t", "12m45t", "45m12t", "812t",  "4558d", "45m58t", "12m8t", "58m8t", "858t", "8m58t",  "858d", "58m12t")
names.haps <- c("812a", "45l",  "45a",  "58l", "a",  "12a", "1258a", "12l",  "l", "1245a", "4558l",  "845l", "8a", "8l",  "1245l", "845a",  "1258l",  "812l", "58a", "4558a", "858l", "858a")

nys.dips <- subset(nys, Line %in% names.dips)
nys.haps <- subset(nys, Line %in% names.haps)

#'add mating type info for haps
for (i in 1:length(nys.haps$Line)){
    nys.haps$mat[i] <- substring(nys.haps$Line[i], nchar(nys.haps$Line[i]))
}

#'add type info for dips - homozygotes ("m") and heterozygotes (anything heterozygous = "t")
nys.dips$type <- "m"
nys.dips$type[grep("t", nys.dips$Line)] <- "t"

#'add allele information for each gene - "w" = wildtype, "t" = heterozygous, "m" = mutant
nbm8.haps <- c("812a", "845l", "8a", "8l", "845a", "812l", "858l", "858a")
nbm12.haps <- c("812a", "12a", "1258a", "12l", "1245a", "1245l", "1258l", "812l")
nbm45.haps <- c("45l", "45a", "1245a", "4558l", "845l", "1245l", "845a", "4558a")
nbm58.haps <- c("58l", "1258a", "4558l", "1258l", "58a", "4558a", "858l", "858a")

nys.haps$nbm8 <- "w"
nys.haps$nbm12 <- "w"
nys.haps$nbm45 <- "w"
nys.haps$nbm58 <- "w"

nys.haps$nbm8[nys.haps$Line %in% nbm8.haps] <- "m"
nys.haps$nbm12[nys.haps$Line %in% nbm12.haps] <- "m"
nys.haps$nbm45[nys.haps$Line %in% nbm45.haps] <- "m"
nys.haps$nbm58[nys.haps$Line %in% nbm58.haps] <- "m"

nbm8.dips.het <- c("45m8t", "8t", "845t", "812t", "12m8t", "858t", "58m8t")
nbm8.dips.hom <- c("812d", "845d", "8m45t", "8m", "8m12t", "8m58t", "858d")
nbm12.dips.het <- c("12t", "1258t", "1245t", "8m12t", "45m12t", "812t", "58m12t")
nbm12.dips.hom <- c("812d", "1245d", "1258d", "12m", "12m58t", "12m45t", "12m8t")
nbm45.dips.het <- c("8m45t", "45t", "845t", "58m45t", "1245t", "4558t", "12m45t")
nbm45.dips.hom <- c("45m", "845d", "45m8t", "1245d", "45m12t", "4558d", "45m58t")
nbm58.dips.het <- c("1258t", "58t", "4558t", "12m58t", "45m58t", "858t", "8m58t")
nbm58.dips.hom <- c("58m", "1258d", "58m45t", "4558d", "58m12t", "58m8t", "858d")

nys.dips$nbm8 <- "w"
nys.dips$nbm12 <- "w"
nys.dips$nbm45 <- "w"
nys.dips$nbm58 <- "w"

nys.dips$nbm8[nys.dips$Line %in% nbm8.dips.het] <- "t"
nys.dips$nbm12[nys.dips$Line %in% nbm12.dips.het] <- "t"
nys.dips$nbm45[nys.dips$Line %in% nbm45.dips.het] <- "t"
nys.dips$nbm58[nys.dips$Line %in% nbm58.dips.het] <- "t"

nys.dips$nbm8[nys.dips$Line %in% nbm8.dips.hom] <- "m"
nys.dips$nbm12[nys.dips$Line %in% nbm12.dips.hom] <- "m"
nys.dips$nbm45[nys.dips$Line %in% nbm45.dips.hom] <- "m"
nys.dips$nbm58[nys.dips$Line %in% nbm58.dips.hom] <- "m"

#'Recode Day and Plate so unique and not numbers
nys.dips$Day <- paste("d", nys.dips$Day ,sep="")
nys.haps$Day <- paste("d", nys.haps$Day ,sep="")

nys.dips$Plate <- paste(nys.dips$Day, nys.dips$Plate ,sep=".")
nys.haps$Plate <- paste(nys.haps$Day, nys.haps$Plate ,sep=".")

write.csv(nys.haps, "GrowthRateAssays/data_output/lgrNys2Haps.csv", row.names=FALSE)
write.csv(nys.dips, "GrowthRateAssays/data_output/lgrNys2Dips.csv", row.names=FALSE)

#'make mat, day, plate, genotype into factors
nys.haps$nbm8 <- factor(nys.haps$nbm8, levels=c("w","m"))
nys.haps$nbm12 <- factor(nys.haps$nbm12, levels=c("w","m"))
nys.haps$nbm45 <- factor(nys.haps$nbm45, levels=c("w","m"))
nys.haps$nbm58 <- factor(nys.haps$nbm58, levels=c("w","m"))
nys.haps$Day <- factor(nys.haps$Day)
nys.haps$mat <- factor(nys.haps$mat)
nys.haps$Plate <- factor(nys.haps$Plate)

#####MODEL - NYSTATIN2 HAPLOIDS BOTH MATING TYPES TOGETHER#####
#'Generates the data for Table 1

#'write full model
#'plate within day as random effect
dat <- nys.haps[is.na(nys.haps$omit)&is.na(nys.haps$out),]
nys.haps.mat.model <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat)

#'check assumptions
par(mfrow=c(2,2))
plot(fitted(nys.haps.mat.model),residuals(nys.haps.mat.model))
abline(h=0)
hist(residuals(nys.haps.mat.model))
qqnorm(residuals(nys.haps.mat.model))
qqline(residuals(nys.haps.mat.model))
#'plot
boxplot(lgr.nys ~ mat*nbm8*nbm12*nbm45*nbm58, dat, las=2)

#'estimates from model
summary(nys.haps.mat.model)

#'find P-values by dropping terms one at a time
#'full model to compare to
Mfull <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'drop interaction terms one by one
M1.1 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.2 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.3 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.4 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.5 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.6 <- lmer(lgr.nys ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'anova comparing full model to model with one interaction term dropped
anova(Mfull, M1.1)
anova(Mfull, M1.2)
anova(Mfull, M1.3)
anova(Mfull, M1.4)
anova(Mfull, M1.5)
anova(Mfull, M1.6)

#'move on to mating type
M1.7 <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
anova(Mfull, M1.7)

#'find the least-squares means (and confidence intervals) for each line
nys.haps.lsmeans <- summary(lsmeans(nys.haps.mat.model, c("nbm8","nbm12","nbm45","nbm58")))

#'tell it which comparisons to do - doesn't include doubles with wt
con <- summary(contrast(lsmeans(nys.haps.mat.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise"))
lines.in <- c("w,w,w,w - m,w,w,w","w,w,w,w - w,m,w,w", "w,w,w,w - w,w,m,w", "w,w,w,w - w,w,w,m","m,w,w,w - m,m,w,w", "m,w,w,w - m,w,m,w", "m,w,w,w - m,w,w,m", "w,m,w,w - m,m,w,w", "w,m,w,w - w,m,m,w", "w,m,w,w - w,m,w,m", "w,w,m,w - m,w,m,w", "w,w,m,w - w,m,m,w", "w,w,m,w - w,w,m,m", "w,w,w,m - m,w,w,m", "w,w,w,m - w,m,w,m", "w,w,w,m - w,w,m,m")
ind.in <- c()
for (i in lines.in){
  ind.in <- c(ind.in, grep(i, con$contrast))
}

#'do the desired contrasts
nys.haps.contrasts <- summary(contrast(lsmeans(nys.haps.mat.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise")[ind.in])

#'write output of least-squares means and desired contrasts
write.csv(format(nys.haps.lsmeans, digits=5), "GrowthRateAssays/data_output/Nys2HapsMeans.csv", row.names=FALSE)
write.csv(format(nys.haps.contrasts, digits=5), "GrowthRateAssays/data_output/Nys2HapsContrasts.csv", row.names=FALSE)

#####MODEL - NYSTATIN2 HAPLOIDS MATa#####
#'write full model
#'plate within day as random effect
dat <- nys.haps[is.na(nys.haps$omit)&nys.haps$mat=="a"&is.na(nys.haps$out),]
nys.mata.model <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat)

#'check assumptions
par(mfrow=c(2,2))
plot(fitted(nys.mata.model),residuals(nys.mata.model))
abline(h=0)
hist(residuals(nys.mata.model))
qqnorm(residuals(nys.mata.model))
qqline(residuals(nys.mata.model))
#'plot
boxplot(lgr.nys ~ nbm8*nbm12*nbm45*nbm58, dat, las=2)

#'estimates from model
summary(nys.mata.model)
#'No differences from the full model.

#'find P-values by dropping terms one at a time
#'full model to compare to
Mfull <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'drop interaction terms one by one
M1.1 <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.2 <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.3 <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.4 <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.5 <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.6 <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'anova comparing full model to model with one interaction term dropped
anova(Mfull, M1.1)
anova(Mfull, M1.2)
anova(Mfull, M1.3)
anova(Mfull, M1.4)
anova(Mfull, M1.5)
anova(Mfull, M1.6)
#'No differences from the full model.

#####MODEL - NYSTATIN2 HAPLOIDS MATl#####
#'write full model
#'plate within day as random effect
dat <- nys.haps[is.na(nys.haps$omit)&nys.haps$mat=="l"&is.na(nys.haps$out),]
nys.matl.model <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat)

#'check assumptions
par(mfrow=c(2,2))
plot(fitted(nys.matl.model),residuals(nys.matl.model))
abline(h=0)
hist(residuals(nys.matl.model))
qqnorm(residuals(nys.matl.model))
qqline(residuals(nys.matl.model))
#'plot
boxplot(lgr.nys ~ nbm8*nbm12*nbm45*nbm58, dat, las=2)

#'estimates from model
summary(nys.matl.model)
#'No differences from the full model.

#'find P-values by dropping terms one at a time
#'full model to compare to
Mfull <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'drop interaction terms one by one
M1.1 <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.2 <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.3 <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.4 <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.5 <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.6 <- lmer(lgr.nys ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'anova comparing full model to model with one interaction term dropped
anova(Mfull, M1.1)
anova(Mfull, M1.2)
anova(Mfull, M1.3)
anova(Mfull, M1.4)
anova(Mfull, M1.5)
anova(Mfull, M1.6)
#'No differences from the full model.