library("lsmeans")
library(lme4)

#####SETTING UP THE DATA#####
#'load in data with outliers marked
ypd <- read.csv("GrowthRateAssays/data_output/OmitOutlierYPD.csv", sep=",", as.is=TRUE)

#'sep dips and haps
names.dips <- c("812d", "45m", "12t", "845d", "8m45t", "45m8t", "8t",  "58m", "45t", "845t", "1258t", "1245d", "58t", "1258d", "12m", "58m45t", "8m", "1245t",  "d",  "4558t", "12m58t",  "8m12t", "12m45t", "45m12t", "812t",  "4558d", "45m58t", "12m8t", "58m8t", "858t", "8m58t",  "858d", "58m12t")
names.haps <- c("812a", "45l",  "45a",  "58l", "a",  "12a", "1258a", "12l",  "l", "1245a", "4558l",  "845l", "8a", "8l",  "1245l", "845a",  "1258l",  "812l", "58a", "4558a", "858l", "858a")

ypd.dips <- subset(ypd, Line %in% names.dips)
ypd.haps <- subset(ypd, Line %in% names.haps)

#'add mating type info for haps
for (i in 1:length(ypd.haps$Line)){
  ypd.haps$mat[i] <- substring(ypd.haps$Line[i], nchar(ypd.haps$Line[i]))
}

#'add type info for dips - homozygotes ("m") and heterozygotes (anything heterozygous = "t")
ypd.dips$type <- "m"
ypd.dips$type[grep("t", ypd.dips$Line)] <- "t"

#'add allele information for each gene - "w" = wildtype, "t" = heterozygous, "m" = mutant
nbm8.haps <- c("812a", "845l", "8a", "8l", "845a", "812l", "858l", "858a")
nbm12.haps <- c("812a", "12a", "1258a", "12l", "1245a", "1245l", "1258l", "812l")
nbm45.haps <- c("45l", "45a", "1245a", "4558l", "845l", "1245l", "845a", "4558a")
nbm58.haps <- c("58l", "1258a", "4558l", "1258l", "58a", "4558a", "858l", "858a")

ypd.haps$nbm8 <- "w"
ypd.haps$nbm12 <- "w"
ypd.haps$nbm45 <- "w"
ypd.haps$nbm58 <- "w"

ypd.haps$nbm8[ypd.haps$Line %in% nbm8.haps] <- "m"
ypd.haps$nbm12[ypd.haps$Line %in% nbm12.haps] <- "m"
ypd.haps$nbm45[ypd.haps$Line %in% nbm45.haps] <- "m"
ypd.haps$nbm58[ypd.haps$Line %in% nbm58.haps] <- "m"

nbm8.dips.het <- c("45m8t", "8t", "845t", "812t", "12m8t", "858t", "58m8t")
nbm8.dips.hom <- c("812d", "845d", "8m45t", "8m", "8m12t", "8m58t", "858d")
nbm12.dips.het <- c("12t", "1258t", "1245t", "8m12t", "45m12t", "812t", "58m12t")
nbm12.dips.hom <- c("812d", "1245d", "1258d", "12m", "12m58t", "12m45t", "12m8t")
nbm45.dips.het <- c("8m45t", "45t", "845t", "58m45t", "1245t", "4558t", "12m45t")
nbm45.dips.hom <- c("45m", "845d", "45m8t", "1245d", "45m12t", "4558d", "45m58t")
nbm58.dips.het <- c("1258t", "58t", "4558t", "12m58t", "45m58t", "858t", "8m58t")
nbm58.dips.hom <- c("58m", "1258d", "58m45t", "4558d", "58m12t", "58m8t", "858d")

ypd.dips$nbm8 <- "w"
ypd.dips$nbm12 <- "w"
ypd.dips$nbm45 <- "w"
ypd.dips$nbm58 <- "w"

ypd.dips$nbm8[ypd.dips$Line %in% nbm8.dips.het] <- "t"
ypd.dips$nbm12[ypd.dips$Line %in% nbm12.dips.het] <- "t"
ypd.dips$nbm45[ypd.dips$Line %in% nbm45.dips.het] <- "t"
ypd.dips$nbm58[ypd.dips$Line %in% nbm58.dips.het] <- "t"

ypd.dips$nbm8[ypd.dips$Line %in% nbm8.dips.hom] <- "m"
ypd.dips$nbm12[ypd.dips$Line %in% nbm12.dips.hom] <- "m"
ypd.dips$nbm45[ypd.dips$Line %in% nbm45.dips.hom] <- "m"
ypd.dips$nbm58[ypd.dips$Line %in% nbm58.dips.hom] <- "m"

#'Recode Day and Plate so unique and not numbers
ypd.dips$Day <- paste("d", ypd.dips$Day ,sep="")
ypd.haps$Day <- paste("d", ypd.haps$Day ,sep="")

ypd.dips$Plate <- paste(ypd.dips$Day, ypd.dips$Plate ,sep=".")
ypd.haps$Plate <- paste(ypd.haps$Day, ypd.haps$Plate ,sep=".")

write.csv(ypd.haps, "GrowthRateAssays/data_output/lgrYPDHaps.csv", row.names=FALSE)
write.csv(ypd.dips, "GrowthRateAssays/data_output/lgrYPDDips.csv", row.names=FALSE)

#'make mat, day, plate, genotype into factors
ypd.haps$nbm8 <- factor(ypd.haps$nbm8, levels=c("w","m"))
ypd.haps$nbm12 <- factor(ypd.haps$nbm12, levels=c("w","m"))
ypd.haps$nbm45 <- factor(ypd.haps$nbm45, levels=c("w","m"))
ypd.haps$nbm58 <- factor(ypd.haps$nbm58, levels=c("w","m"))
ypd.haps$Day <- factor(ypd.haps$Day)
ypd.haps$mat <- factor(ypd.haps$mat)
ypd.haps$Plate <- factor(ypd.haps$Plate)

#####MODEL - YPD HAPLOIDS BOTH MATING TYPES TOGETHER#####
#'write full model
#'plate within day as random effect
dat <- ypd.haps[is.na(ypd.haps$omit)&is.na(ypd.haps$out),]
ypd.haps.mat.model <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat)

#'check assumptions
par(mfrow=c(2,2))
plot(fitted(ypd.haps.mat.model),residuals(ypd.haps.mat.model))
abline(h=0)
hist(residuals(ypd.haps.mat.model)) 
qqnorm(residuals(ypd.haps.mat.model)) 
qqline(residuals(ypd.haps.mat.model))
#'plot
boxplot(lgr.ypd ~ mat*nbm8*nbm12*nbm45*nbm58, dat, las=2)

#'estimates from model
summary(ypd.haps.mat.model)

#'find P-values by dropping terms one at a time
#'full model to compare to
Mfull <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'drop interaction terms one by one
M1.1 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.2 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.3 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.4 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.5 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.6 <- lmer(lgr.ypd ~ mat + nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'anova comparing full model to model with one interaction term dropped
anova(Mfull, M1.1)
anova(Mfull, M1.2)
anova(Mfull, M1.3)
anova(Mfull, M1.4)
anova(Mfull, M1.5)
anova(Mfull, M1.6)

#'move on to mating type
M1.7 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
anova(Mfull, M1.7)

#'find the least-squares means (and confidence intervals) for each line
ypd.haps.lsmeans <- summary(lsmeans(ypd.haps.mat.model, c("nbm8","nbm12","nbm45","nbm58")))

#'tell it which comparisons to do - doesn't include doubles with wt
con <- summary(contrast(lsmeans(ypd.haps.mat.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise"))
lines.in <- c("w,w,w,w - m,w,w,w","w,w,w,w - w,m,w,w", "w,w,w,w - w,w,m,w", "w,w,w,w - w,w,w,m","m,w,w,w - m,m,w,w", "m,w,w,w - m,w,m,w", "m,w,w,w - m,w,w,m", "w,m,w,w - m,m,w,w", "w,m,w,w - w,m,m,w", "w,m,w,w - w,m,w,m", "w,w,m,w - m,w,m,w", "w,w,m,w - w,m,m,w", "w,w,m,w - w,w,m,m", "w,w,w,m - m,w,w,m", "w,w,w,m - w,m,w,m", "w,w,w,m - w,w,m,m")
ind.in <- c()
for (i in lines.in){
  ind.in <- c(ind.in, grep(i, con$contrast))
}

#'do the desired contrasts
ypd.haps.contrasts <- summary(contrast(lsmeans(ypd.haps.mat.model, c("nbm8","nbm12","nbm45","nbm58")), method="pairwise")[ind.in])

#'write output of least-squares means and desired contrasts
write.csv(format(ypd.haps.lsmeans, digits=5), "GrowthRateAssays/data_output/YPDHapsMeans.csv", row.names=FALSE)
write.csv(format(ypd.haps.contrasts, digits=5), "GrowthRateAssays/data_output/YPDHapsContrasts.csv", row.names=FALSE)

#####MODEL - YPD HAPLOIDS MATa#####
#'write full model
#'plate within day as random effect
dat <- ypd.haps[is.na(ypd.haps$omit)&ypd.haps$mat=="a"&is.na(ypd.haps$out),]
ypd.mata.model <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat)

#'check assumptions
par(mfrow=c(2,2))
plot(fitted(ypd.mata.model),residuals(ypd.mata.model))
abline(h=0)
hist(residuals(ypd.mata.model)) 
qqnorm(residuals(ypd.mata.model)) 
qqline(residuals(ypd.mata.model))
#'plot
boxplot(lgr.ypd ~ nbm8*nbm12*nbm45*nbm58, dat, las=2)

#'estimates from model
summary(ypd.mata.model)
#'Differences from the full model: 
#'nbm58 (erg5) coefficient is positive
#'nbm8:nbm45 (erg3 erg6) coefficient is negative
#'nbm8:nbm58 (erg5 erg6) coefficient is negative

#'find P-values by dropping terms one at a time
#'full model to compare to
Mfull <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'drop interaction terms one by one
M1.1 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.2 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.3 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.4 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.5 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.6 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'anova comparing full model to model with one interaction term dropped
anova(Mfull, M1.1)
anova(Mfull, M1.2)
anova(Mfull, M1.3)
anova(Mfull, M1.4)
anova(Mfull, M1.5)
anova(Mfull, M1.6)
#'Differences from the full model: 
#'nbm12*nbm58 (erg5*erg7) is significant
#'nbm12*nbm45 (erg3*erg7) is not significant
#'nbm8*nbm58 (erg5*erg6) is significant
#'Despite these differences from the full model, our conclusions remain unchanged.

#####MODEL - YPD HAPLOIDS MATl#####
#'write full model
#'plate within day as random effect
dat <- ypd.haps[is.na(ypd.haps$omit)&ypd.haps$mat=="l"&is.na(ypd.haps$out),]
ypd.matl.model <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat)

#'check assumptions
par(mfrow=c(2,2))
plot(fitted(ypd.matl.model),residuals(ypd.matl.model))
abline(h=0)
hist(residuals(ypd.matl.model)) 
qqnorm(residuals(ypd.matl.model)) 
qqline(residuals(ypd.matl.model))
#'plot
boxplot(lgr.ypd ~ nbm8*nbm12*nbm45*nbm58, dat, las=2)

#'estimates from model
summary(ypd.matl.model)
#'Differences from the full model: 
#'nbm12:nbm58 (erg5 erg7) coefficient is positive

#'find P-values by dropping terms one at a time
#'full model to compare to
Mfull <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'drop interaction terms one by one
M1.1 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.2 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.3 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.4 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm45 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.5 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm12 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
M1.6 <- lmer(lgr.ypd ~ nbm8 + nbm12 + nbm45 + nbm58 + nbm8*nbm45 + nbm8*nbm58 + nbm12*nbm45 + nbm12*nbm58 + nbm45*nbm58 + (1|Day/Plate), data=dat, REML=FALSE)
#'anova comparing full model to model with one interaction term dropped
anova(Mfull, M1.1)
anova(Mfull, M1.2)
anova(Mfull, M1.3)
anova(Mfull, M1.4)
anova(Mfull, M1.5)
anova(Mfull, M1.6)
#'Differences from the full model: 
#'nbm45*nbm58 (erg3*erg5) is not significant
#'Despite these differences from the full model, our conclusions remain unchanged.
