library("dplyr")

#'code used to determine the maximum growth rate
nderiv <- function(fit, x, eps=1e-5)
  (predict(fit, x + eps) - predict(fit, x - eps))/(2 * eps)

spline.slope <- function(x, y, n=101, eps=1e-5)
  max(nderiv(loess(log(y) ~ x, degree=1, span=0.2),
             seq(min(x), max(x), length=n)), na.rm=TRUE)

spline.slope.dat <- function(d, ...)
  sapply(d[-1], spline.slope, x=d$t, ...)

######LOAD IN DATA######
#'Assay 1
#'read in data
d1.1 <- read.csv("GrowthRateAssays/data/Assay1Pl1.csv", sep=",", as.is=TRUE, header=FALSE)
names(d1.1) <- c("t", paste("C", seq(length=ncol(d1.1)-1), sep=""))

d2.1 <- read.csv("GrowthRateAssays/data/Assay1Pl2.csv", sep=",", as.is=TRUE, header=FALSE)
names(d2.1) <- c("t", paste("C", seq(length=ncol(d2.1)-1), sep=""))

wells.1 <- read.csv("GrowthRateAssays/data/Assay1_wells.csv", sep=",", as.is=TRUE, header=TRUE)

#'make sure wells are ordered properly
wells.1 <- wells.1[order(wells.1$Well),]

#'wells in YPD plate 2 were upside down - fix this
wells.nys.1 <- wells.1
wells.ypd.1 <- wells.1
wells.ypd.1 <- mutate(wells.ypd.1, newWell = Well)

for (i in 101:200){
  wells.ypd.1$newWell[i] <- 200-i+101
}
wells.ypd.1$Well <- wells.ypd.1$newWell

#'make sure ypd wells are ordered properly
wells.ypd.1 <- wells.ypd.1[order(wells.ypd.1$Well),]

#'split data into ypd and nystatin2
d.ypd.1 <- data.frame(d1.1[,1:101], d2.1[,2:101])
d.nys.1 <- data.frame(d1.1[,1], d1.1[,102:201], d2.1[,102:201])

#'make sure the data is the same length as the wells file
d.ypd.1 <- d.ypd.1[1:(length(wells.ypd.1[,1])+1)]
d.nys.1 <- d.nys.1[1:(length(wells.nys.1[,1])+1)]

#'name the first well of the nystatin2 data set "t" for time
names(d.nys.1)[1] <- "t"

#'only use the first 24hrs of data
d.ypd.1 <- d.ypd.1[1:49,]
d.nys.1 <- d.nys.1[1:49,]

#'now find the maximum growth rate for each well
lgr.ypd.1 <- spline.slope.dat(d.ypd.1)
lgr.nys.1 <- spline.slope.dat(d.nys.1)

#'find the OD24 for each well by taking the median of the last three time points
K24.ypd.1 <- c()
for (i in 1:length(d.ypd.1[1,])){
  K24.ypd.1[i] <- median(d.ypd.1[47:49,i])
}
K24.ypd.1 <- K24.ypd.1[-1]

K24.nys.1 <- c()
for (i in 1:length(d.nys.1[1,])){
  K24.nys.1[i] <- median(d.nys.1[47:49,i])
}
K24.nys.1 <- K24.nys.1[-1]

#'put the maximum growth rates and ODs into a data frame with the well information
full.ypd.1 <- data.frame(wells.ypd.1, lgr.ypd.1, K24.ypd.1)
full.nys.1 <- data.frame(wells.nys.1, lgr.nys.1, K24.nys.1)

#'Assay 2
#'read in data
d1.2 <- read.csv("GrowthRateAssays/data/Assay2Pl1.csv", sep=",", as.is=TRUE, header=FALSE)
names(d1.2) <- c("t", paste("C", seq(length=ncol(d1.2)-1), sep=""))

d2.2 <- read.csv("GrowthRateAssays/data/Assay2Pl2.csv", sep=",", as.is=TRUE, header=FALSE)
names(d2.2) <- c("t", paste("C", seq(length=ncol(d2.2)-1), sep=""))

wells.2 <- read.csv("GrowthRateAssays/data/Assay2_wells.csv", sep=",", as.is=TRUE, header=TRUE)

#'make sure wells are ordered properly
wells.2<-wells.2[order(wells.2$Well),]

#'split data into ypd and nystatin2
d.nys.2 <- data.frame(d1.2[,1:101], d2.2[1:49,2:101])
d.ypd.2 <- data.frame(d1.2[,1], d1.2[,102:201], d2.2[1:49,102:201])

#'make sure the data is the same length as the wells file
d.ypd.2 <- d.ypd.2[1:(length(wells.2[,1])+1)]
d.nys.2 <- d.nys.2[1:(length(wells.2[,1])+1)]

#'name the first well of the ypd data set "t" for time
names(d.ypd.2)[1] <- "t"

#'only use the first 24hrs of data
d.ypd.2 <- d.ypd.2[1:49,]
d.nys.2 <- d.nys.2[1:49,]

#'now find the maximum growth rate for each well
lgr.ypd.2 <- spline.slope.dat(d.ypd.2)
lgr.nys.2 <- spline.slope.dat(d.nys.2)

#'find the OD24 for each well by taking the median of the last three time points
K24.ypd.2 <- c()
for (i in 1:length(d.ypd.2[1,])){
  K24.ypd.2[i] <- median(d.ypd.2[47:49,i])
}
K24.ypd.2 <- K24.ypd.2[-1]

K24.nys.2 <- c()
for (i in 1:length(d.nys.2[1,])){
  K24.nys.2[i] <- median(d.nys.2[47:49,i])
}
K24.nys.2 <- K24.nys.2[-1]

#'put the maximum growth rates and ODs into a data frame with the well information
full.ypd.2 <- data.frame(wells.2, lgr.ypd.2, K24.ypd.2)
full.nys.2 <- data.frame(wells.2, lgr.nys.2, K24.nys.2)

#'Assay 3
#'read in data
d1.3 <- read.csv("GrowthRateAssays/data/Assay3Pl1.csv", sep=",", as.is=TRUE, header=FALSE)
names(d1.3) <- c("t", paste("C", seq(length=ncol(d1.3)-1), sep=""))

d2.3 <- read.csv("GrowthRateAssays/data/Assay3Pl2.csv", sep=",", as.is=TRUE, header=FALSE)
names(d2.3) <- c("t", paste("C", seq(length=ncol(d2.3)-1), sep=""))

wells.3 <- read.csv("GrowthRateAssays/data/Assay3_wells.csv", sep=",", as.is=TRUE, header=TRUE)

#'make sure wells are ordered properly
wells.3<-wells.3[order(wells.3$Well),]

#'split data into ypd and nystatin2
d.nys.3 <- data.frame(d1.3[,1], d1.3[,102:201], d2.3[1:96,102:201])
d.ypd.3 <- data.frame(d1.3[,1:101], d2.3[1:96,2:101])

#'make sure the data is the same length as the wells file
d.ypd.3 <- d.ypd.3[1:(length(wells.3[,1])+1)]
d.nys.3 <- d.nys.3[1:(length(wells.3[,1])+1)]

#'name the first well of the nystatin2 data set "t" for time
names(d.nys.3)[1] <- "t"

#'only use the first 24hrs of data
d.ypd.3 <- d.ypd.3[1:49,]
d.nys.3 <- d.nys.3[1:49,]

#'now find the maximum growth rate for each well
lgr.ypd.3 <- spline.slope.dat(d.ypd.3)
lgr.nys.3 <- spline.slope.dat(d.nys.3)

#'find the OD24 for each well by taking the median of the last three time points
K24.ypd.3 <- c()
for (i in 1:length(d.ypd.3[1,])){
  K24.ypd.3[i] <- median(d.ypd.3[47:49,i])
}
K24.ypd.3 <- K24.ypd.3[-1]

K24.nys.3 <- c()
for (i in 1:length(d.nys.3[1,])){
  K24.nys.3[i] <- median(d.nys.3[47:49,i])
}
K24.nys.3 <- K24.nys.3[-1]

#'put the maximum growth rates and ODs into a data frame with the well information
full.ypd.3 <- data.frame(wells.3, lgr.ypd.3, K24.ypd.3)
full.nys.3 <- data.frame(wells.3, lgr.nys.3, K24.nys.3)

#'Assay 4
#'read in data
d1.4 <- read.csv("GrowthRateAssays/data/Assay4Pl12.csv", sep=",", as.is=TRUE, header=FALSE)
names(d1.4) <- c("t", paste("C", seq(length=ncol(d1.4)-1), sep=""))

d2.4 <- read.csv("GrowthRateAssays/data/Assay4Pl3.csv", sep=",", as.is=TRUE, header=FALSE)
names(d2.4) <- c("t", paste("C", seq(length=ncol(d2.4)-1), sep=""))

wells.4 <- read.csv("GrowthRateAssays/data/Assay4_wells.csv", sep=",", as.is=TRUE, header=TRUE)

#'make sure wells are ordered properly
wells.4<-wells.4[order(wells.4$Old.Well),]

#'make one big data frame
d.4 <- data.frame(d1.4[,1:201], d2.4[,2:101])

#'make sure the data is the same length as the wells file*2
d.4 <- d.4[1:(length(wells.4[,1])*2+1)]

#'only use the first 24hrs of data
d.4 <- d.4[1:49,]

#'now find the maximum growth rate for each well
lgr.4 <- spline.slope.dat(d.4)

#'find the OD24 for each well by taking the median of the last three time points
K24.4 <- c()
for (i in 1:length(d.4[1,])){
  K24.4[i] <- median(d.4[47:49,i])
}
K24.4 <- K24.4[-1]

#'put the maximum growth rates and ODs into a data frame with the well information for YPD and nystatin2 separately
wells.4<-wells.4[order(wells.4$Well1),]
full.ypd.4 <- data.frame(wells.4, lgr.4[wells.4$Well1], K24.4[wells.4$Well1])
names(full.ypd.4)[6:7] <- c("lgr.ypd.4","K24.ypd.4")

wells.4<-wells.4[order(wells.4$Well2),]
full.nys.4 <- data.frame(wells.4, lgr.4[wells.4$Well2], K24.4[wells.4$Well2])
names(full.nys.4)[6:7] <- c("lgr.nys.4","K24.nys.4")

#'Assay 5
#'plates 1 and 2 stopped being read - omit
#'read in data
d2.5 <- read.csv("GrowthRateAssays/data/Assay5Pl3.csv", sep=",", as.is=TRUE, header=FALSE)
names(d2.5) <- c("t", paste("C", seq(length=ncol(d2.5)-1), sep=""))

wells.5 <- read.csv("GrowthRateAssays/data/Assay5_wells.csv", sep=",", as.is=TRUE, header=TRUE)

#'make sure wells are ordered properly
wells.5<-wells.5[order(wells.5$Old.Well),]

#'rename the one data frame
d.5 <- data.frame(d2.5)

#'since plates 1 and 2 were lost - get rid of these wells
wells.5 <- subset(wells.5, Old.Well>100)

#'make sure the data is the same length as the wells file*2
d.5 <- d.5[1:(length(wells.5[,1])*2+1)]

#'only use the first 24hrs of data
d.5 <- d.5[1:49,]

#'now find the maximum growth rate for each well
lgr.5 <- spline.slope.dat(d.5)

#'find the OD24 for each well by taking the median of the last three time points
K24.5 <- c()
for (i in 1:length(d.5[1,])){
  K24.5[i] <- median(d.5[47:49,i])
}
K24.5 <- K24.5[-1]

#'put the maximum growth rates and ODs into a data frame with the well information for YPD and nystatin2 separately
wells.5<-wells.5[order(wells.5$Well1),]
full.ypd.5 <- data.frame(wells.5, lgr.5[wells.5$Well1-200], K24.5[wells.5$Well1-200])
names(full.ypd.5)[6:7] <- c("lgr.ypd.5","K24.ypd.5")

wells.5<-wells.5[order(wells.5$Well2),]
full.nys.5 <- data.frame(wells.5, lgr.5[wells.5$Well2-200], K24.5[wells.5$Well2-200])
names(full.nys.5)[6:7] <- c("lgr.nys.5","K24.nys.5")

#'Assay 6
#'read in data
d1.6 <- read.csv("GrowthRateAssays/data/Assay6Pl12.csv", sep=",", as.is=TRUE, header=FALSE)
names(d1.6) <- c("t", paste("C", seq(length=ncol(d1.6)-1), sep=""))

d2.6 <- read.csv("GrowthRateAssays/data/Assay6Pl3.csv", sep=",", as.is=TRUE, header=FALSE)
names(d2.6) <- c("t", paste("C", seq(length=ncol(d2.6)-1), sep=""))

wells.6 <- read.csv("GrowthRateAssays/data/Assay6_wells.csv", sep=",", as.is=TRUE, header=TRUE)

#'make sure wells are ordered properly
wells.6<-wells.6[order(wells.6$Old.Well),]

#'make one big data frame
d.6 <- data.frame(d1.6[,1:201], d2.6[,2:101])

#'make sure the data is the same length as the wells file*2
d.6 <- d.6[1:(length(wells.6[,1])*2+1)]

#'only use the first 24hrs of data
d.6 <- d.6[1:49,]

#'now find the maximum growth rate for each well
lgr.6 <- spline.slope.dat(d.6)

#'find the OD24 for each well by taking the median of the last three time points
K24.6 <- c()
for (i in 1:length(d.6[1,])){
  K24.6[i] <- median(d.6[47:49,i])
}
K24.6 <- K24.6[-1]

#'put the maximum growth rates and ODs into a data frame with the well information for YPD and nystatin2 separately
wells.6<-wells.6[order(wells.6$Well1),]
full.ypd.6 <- data.frame(wells.6, lgr.6[wells.6$Well1], K24.6[wells.6$Well1])
names(full.ypd.6)[6:7] <- c("lgr.ypd.6","K24.ypd.6")

wells.6<-wells.6[order(wells.6$Well2),]
full.nys.6 <- data.frame(wells.6, lgr.6[wells.6$Well2], K24.6[wells.6$Well2])
names(full.nys.6)[6:7] <- c("lgr.nys.6","K24.nys.6")

#'Assay 7
#'read in data
d.7 <- read.csv("GrowthRateAssays/data/Assay7Pl1.csv", sep=",", as.is=TRUE, header=FALSE)
names(d.7) <- c("t", paste("C", seq(length=ncol(d.7)-1), sep=""))

wells.7 <- read.csv("GrowthRateAssays/data/Assay7_wells.csv", sep=",", as.is=TRUE, header=TRUE)

#'make sure wells are ordered properly
wells.7<-wells.7[order(wells.7$Old.Well),]

#'make sure the data is the same length as the wells file*2
d.7 <- d.7[1:(length(wells.7[,1])*2+1)]

#'only use the first 24hrs of data
d.7 <- d.7[1:49,]

#'now find the maximum growth rate for each well
lgr.7 <- spline.slope.dat(d.7)

#'find the OD24 for each well by taking the median of the last three time points
K24.7 <- c()
for (i in 1:length(d.7[1,])){
  K24.7[i] <- median(d.7[47:49,i])
}
K24.7 <- K24.7[-1]

#'put the maximum growth rates and ODs into a data frame with the well information for YPD and nystatin2 separately
wells.7<-wells.7[order(wells.7$Well1),]
full.ypd.7 <- data.frame(wells.7, lgr.7[wells.7$Well1], K24.7[wells.7$Well1])
names(full.ypd.7)[6:7] <- c("lgr.ypd.7","K24.ypd.7")

wells.7<-wells.7[order(wells.7$Well2),]
full.nys.7 <- data.frame(wells.7, lgr.7[wells.7$Well2], K24.7[wells.7$Well2])
names(full.nys.7)[6:7] <- c("lgr.nys.7","K24.nys.7")

#####REMOVE DATA FROM LINES LATER FOUND TO BE INCORRECT#####
#'get rid of incorrect data about 58m12t from first 3 assays
full.nys.1 <- subset(full.nys.1, Line!="58m12t")
full.nys.2 <- subset(full.nys.2, Line!="58m12t")
full.nys.3 <- subset(full.nys.3, Line!="58m12t")

full.ypd.1 <- subset(full.ypd.1, Line!="58m12t")
full.ypd.2 <- subset(full.ypd.2, Line!="58m12t")
full.ypd.3 <- subset(full.ypd.3, Line!="58m12t")

#'get rid of incorrect data about 858d from Assays 4, 5,6
full.nys.4 <- subset(full.nys.4, Line!="858d")
full.nys.5 <- subset(full.nys.5, Line!="858d")
full.nys.6 <- subset(full.nys.6, Line!="858d")

full.ypd.4 <- subset(full.ypd.4, Line!="858d")
full.ypd.5 <- subset(full.ypd.5, Line!="858d")
full.ypd.6 <- subset(full.ypd.6, Line!="858d")

#####FIND THE MEAN OF THE WTS FOR EACH DAY#####
#'first, add plate and day info for each well
full.nys.1$Day <- 1
full.nys.1$Plate <- ((full.nys.1$Well-1)%/%100)+1
full.nys.2$Day <- 2
full.nys.2$Plate <- ((full.nys.2$Well-1)%/%100)+1
full.nys.3$Day <- 3
full.nys.3$Plate <- ((full.nys.3$Well-1)%/%100)+1
full.nys.4$Day <- 4
full.nys.4$Plate <- ((full.nys.4$Well2-1)%/%100)+1
full.nys.5$Day <- 5
full.nys.5$Plate <- ((full.nys.5$Well2-1)%/%100)+1
full.nys.6$Day <- 6
full.nys.6$Plate <- ((full.nys.6$Well2-1)%/%100)+1
full.nys.7$Day <- 7
full.nys.7$Plate <- ((full.nys.7$Well2-1)%/%100)+1

full.ypd.1$Day <- 1
full.ypd.1$Plate <- ((full.ypd.1$Well-1)%/%100)+1
full.ypd.2$Day <- 2
full.ypd.2$Plate <- ((full.ypd.2$Well-1)%/%100)+1
full.ypd.3$Day <- 3
full.ypd.3$Plate <- ((full.ypd.3$Well-1)%/%100)+1
full.ypd.4$Day <- 4
full.ypd.4$Plate <- ((full.ypd.4$Well1-1)%/%100)+1
full.ypd.5$Day <- 5
full.ypd.5$Plate <- ((full.ypd.5$Well1-1)%/%100)+1
full.ypd.6$Day <- 6
full.ypd.6$Plate <- ((full.ypd.6$Well1-1)%/%100)+1
full.ypd.7$Day <- 7
full.ypd.7$Plate <- ((full.ypd.7$Well1-1)%/%100)+1

#'make big data frame with all of the data
#'rename the columns so they're all the same
names(full.nys.1) <- c("Well", "Tube.Name", "Line", "lgr.nys", "K24.nys", "Day", "Plate")
names(full.nys.2) <- c("Well", "Tube.Name", "Line", "lgr.nys", "K24.nys", "Day", "Plate")
names(full.nys.3) <- c("Well", "Tube.Name", "Line", "lgr.nys", "K24.nys", "Day", "Plate")

names(full.ypd.1) <- c("Well", "Tube.Name", "Line", "newWell", "lgr.ypd", "K24.ypd", "Day", "Plate")
names(full.ypd.2) <- c("Well", "Tube.Name", "Line", "lgr.ypd", "K24.ypd", "Day", "Plate")
names(full.ypd.3) <- c("Well", "Tube.Name", "Line", "lgr.ypd", "K24.ypd", "Day", "Plate")

#'also get rid of extra well columns
full.nys.4$Old.Well <- NULL
full.nys.4$Well1 <- NULL
names(full.nys.4) <- c("Well", "Tube.Name", "Line", "lgr.nys", "K24.nys", "Day", "Plate")
full.nys.5$Old.Well <- NULL
full.nys.5$Well1 <- NULL
names(full.nys.5) <- c("Well", "Tube.Name", "Line", "lgr.nys", "K24.nys", "Day", "Plate")
full.nys.6$Old.Well <- NULL
full.nys.6$Well1 <- NULL
names(full.nys.6) <- c("Well", "Tube.Name", "Line", "lgr.nys", "K24.nys", "Day", "Plate")
full.nys.7$Old.Well <- NULL
full.nys.7$Well1 <- NULL
names(full.nys.7) <- c("Well", "Tube.Name", "Line", "lgr.nys", "K24.nys", "Day", "Plate")

full.ypd.1$newWell <- NULL
full.ypd.4$Old.Well <- NULL
full.ypd.4$Well2 <- NULL
names(full.ypd.4) <- c("Well", "Tube.Name", "Line", "lgr.ypd", "K24.ypd", "Day", "Plate")
full.ypd.5$Old.Well <- NULL
full.ypd.5$Well2 <- NULL
names(full.ypd.5) <- c("Well", "Tube.Name", "Line", "lgr.ypd", "K24.ypd", "Day", "Plate")
full.ypd.6$Old.Well <- NULL
full.ypd.6$Well2 <- NULL
names(full.ypd.6) <- c("Well", "Tube.Name", "Line", "lgr.ypd", "K24.ypd", "Day", "Plate")
full.ypd.7$Old.Well <- NULL
full.ypd.7$Well2 <- NULL
names(full.ypd.7) <- c("Well", "Tube.Name", "Line", "lgr.ypd", "K24.ypd", "Day", "Plate")

#'merge all
full.nys.all <- merge(full.nys.1, full.nys.2, all=TRUE)
full.nys.all <- merge(full.nys.all, full.nys.3, all=TRUE)
full.nys.all <- merge(full.nys.all, full.nys.4, all=TRUE)
full.nys.all <- merge(full.nys.all, full.nys.5, all=TRUE)
full.nys.all <- merge(full.nys.all, full.nys.6, all=TRUE)
full.nys.all <- merge(full.nys.all, full.nys.7, all=TRUE)

full.ypd.all <- merge(full.ypd.1, full.ypd.2, all=TRUE)
full.ypd.all <- merge(full.ypd.all, full.ypd.3, all=TRUE)
full.ypd.all <- merge(full.ypd.all, full.ypd.4, all=TRUE)
full.ypd.all <- merge(full.ypd.all, full.ypd.5, all=TRUE)
full.ypd.all <- merge(full.ypd.all, full.ypd.6, all=TRUE)
full.ypd.all <- merge(full.ypd.all, full.ypd.7, all=TRUE)

#'subset the data for all of the wts
#'note - different numbers of lines and plates in each assay
wts <- c('a','l','d')

nys.wt <- subset(full.nys.all, Line %in% wts)
ypd.wt <- subset(full.ypd.all, Line %in% wts)

#'find control mean for each plate in each day
nys.wt.means <- c()
nys.wt.order <- c()

for (i in unique(nys.wt$Day)){
  sub <- subset(nys.wt, Day==i)
  for (j in unique(sub$Plate)){
    sub2 <- subset(sub, Plate==j)
    nys.wt.means <- c(nys.wt.means, mean(sub2$lgr.nys))
    nys.wt.order <- c(nys.wt.order, paste(i,j))
  }
}

ypd.wt.means <- c()
ypd.wt.order <- c()

for (i in unique(ypd.wt$Day)){
  sub <- subset(ypd.wt, Day==i)
  for (j in unique(sub$Plate)){
    sub2 <- subset(sub, Plate==j)
    ypd.wt.means <- c(ypd.wt.means, mean(sub2$lgr.ypd))
    ypd.wt.order <- c(ypd.wt.order, paste(i,j))
  }
}


#####NORMALIZE#####
#'find global means 
nys.wt.globalmean <- mean(nys.wt.means)
ypd.wt.globalmean <- mean(ypd.wt.means)

#'find differences of plate means from global mean
nys.wt.diffs <- nys.wt.globalmean-nys.wt.means
ypd.wt.diffs <- ypd.wt.globalmean-ypd.wt.means

#'add the differences to each line
x <- 1
full.nys.all$lgr.norm <- NA
for (i in nys.wt.order){
  d <- substring(i, 1,1)
  p <- substring(i, 3,3)
  iday <- grep(d, full.nys.all$Day)
  iplate <- grep(p, full.nys.all$Plate)
  ind <- intersect(iday, iplate)
  full.nys.all$lgr.norm[ind] <- full.nys.all$lgr.nys[ind]+nys.wt.diffs[x] 
  x <- x + 1
}

x <- 1
full.ypd.all$lgr.norm <- NA
for (i in ypd.wt.order){
  d <- substring(i, 1,1)
  p <- substring(i, 3,3)
  iday <- grep(d, full.ypd.all$Day)
  iplate <- grep(p, full.ypd.all$Plate)
  ind <- intersect(iday, iplate)
  full.ypd.all$lgr.norm[ind] <- full.ypd.all$lgr.ypd[ind]+ypd.wt.diffs[x] 
  x <- x + 1
}

######PLOT ALL NORMALIZED POINTS#####
#'make all reps of 858d the same
full.nys.all[grep("858d",full.nys.all$Line),]$Line <- "858d"
full.ypd.all[grep("858d",full.ypd.all$Line),]$Line <- "858d"

plot.order <- c("a", "8a", "12a", "45a", "58a", "812a", "845a", "858a", "1245a", "1258a", "4558a", "l", "8l", "12l", "45l", "58l", "812l", "845l", "858l", "1245l", "1258l", "4558l", "d", "8t", "8m", "12t", "12m", "45t", "45m", "58t", "58m", "812t", "8m12t", "12m8t", "812d", "845t", "8m45t", "45m8t", "845d", "858t", "8m58t", "58m8t", "858d", "1245t", "12m45t", "45m12t", "1245d",  "1258t", "12m58t", "58m12t", "1258d", "4558t", "45m58t", "58m45t", "4558d", "Medium")

#reorder data frame by plot.order
full.nys.all$Line <- factor(full.nys.all$Line, levels = plot.order)
full.nys.all <- full.nys.all[order(full.nys.all$Line),]

full.ypd.all$Line <- factor(full.ypd.all$Line, levels = plot.order)
full.ypd.all <- full.ypd.all[order(full.ypd.all$Line),]

full.nys.all.ag <- aggregate(full.nys.all["lgr.norm"], full.nys.all[c("Line")], mean)
stripchart(full.nys.all$lgr.norm~full.nys.all$Line, vertical = TRUE, pch=16, las=2)
points(seq_along(full.nys.all.ag$Line), full.nys.all.ag$lgr.norm, col="red", pch="-", lwd=5)

full.ypd.all.ag <- aggregate(full.ypd.all["lgr.norm"], full.ypd.all[c("Line")], mean)
stripchart(full.ypd.all$lgr.norm~full.ypd.all$Line, vertical = TRUE, pch=16, las=2)
points(seq_along(full.ypd.all.ag$Line), full.ypd.all.ag$lgr.norm, col="red", pch="-", lwd=5)

######WRITE OUTPUT OF NORMALIZATION#####
write.csv(full.nys.all, "GrowthRateAssays/data_output/NormalizedNys2.csv", row.names=FALSE)
write.csv(full.ypd.all, "GrowthRateAssays/data_output/NormalizedYPD.csv", row.names=FALSE)


