#####SETTING UP THE DATA#####
#'load in data with outliers marked - nystatin2
nys <- read.csv("GrowthRateAssays/data_output/OmitOutlierNys2.csv", sep=",", as.is=TRUE)
#'remove wells to omit, wells containing only medium
nys <- nys[is.na(nys$omit)&nys$Line!="Medium",]

#'load in data with outliers marked - YPD
ypd <- read.csv("GrowthRateAssays/data_output/OmitOutlierYPD.csv", sep=",", as.is=TRUE)
#'remove wells to omit, wells containing only medium
ypd <- ypd[is.na(ypd$omit)&ypd$Line!="Medium",]

#####PLOT THE DATA COLOURED BY PRE-GROWTH MEDIUM#####
#'reorder strains for plotting
plot.order <- c("a", "l","d","8a", "12a", "45a", "58a", "812a", "845a", "858a", "1245a", "1258a", "4558a", "8l", "12l", "45l", "58l", "812l", "845l", "858l", "1245l", "1258l", "4558l", "8t", "8m", "12t", "12m", "45t", "45m", "58t", "58m", "812t", "8m12t", "12m8t", "812d", "845t", "8m45t", "45m8t", "845d", "858t", "8m58t", "58m8t", "858d", "1245t", "12m45t", "45m12t", "1245d",  "1258t", "12m58t", "58m12t", "1258d", "4558t", "45m58t", "58m45t", "4558d")

#reorder data frame by plot.order
nys$Line <- factor(nys$Line, levels = plot.order)
nys <- nys[order(nys$Line),]

ypd$Line <- factor(ypd$Line, levels = plot.order)
ypd <- ypd[order(ypd$Line),]

#'make stripchart of all maximum growth rate data 
#'Assay 1 (pre-growth in YPD) in red
#'All others (pre-growth in 0.5uM nystatin) in black
#'outliers outlined with a green box
par(mfrow=c(2,1), mar=c(4,4,1,1), oma=c(0,0,0,4))
#'plot growth rate in Nystatin2
stripchart(nys$lgr.nys~nys$Line, vertical=TRUE, pch=16, las=2, col="black", ylab="Max Growth Rate in Nystatin2")
points(nys[nys$Day==1,]$Line, nys[nys$Day==1,]$lgr.nys, col="red", pch=16)
points(nys[!is.na(nys$out),]$Line, nys[!is.na(nys$out),]$lgr.nys, col="green", pch=0)
legend(56.5,-0.05,c("not Assay 1","Assay 1","outlier"),pch=c(16,16,0), bty="n", xpd=NA, col=c("black","red","green"),x.intersp = 0.5, cex=0.75,pt.cex=1)
#'plot growth rate in YPD
stripchart(ypd$lgr.ypd~ypd$Line, vertical=TRUE, pch=16, las=2, col="black", ylab="Max Growth Rate in YPD")
points(ypd[ypd$Day==1,]$Line, ypd[ypd$Day==1,]$lgr.ypd, col="red", pch=16)
points(ypd[!is.na(ypd$out),]$Line, ypd[!is.na(ypd$out),]$lgr.ypd, col="green", pch=0)

#####SETTING UP DATA TO TEST THE EFFECT OF THE PRE-GROWTH MEDIUM#####
#'remove outliers 
nys <- nys[is.na(nys$out),]
ypd <- ypd[is.na(ypd$out),]

#'find the mean maximum growth rate (+/- SE) for each line on each day (assay) in each medium
ypd.ag <- aggregate(ypd[c("lgr.ypd")], ypd[c("Line","Day")], mean)
ypd.ag$lgrse <- aggregate(ypd["lgr.ypd"], ypd[c("Line","Day")], se)[,3]

nys.ag <- aggregate(nys[c("lgr.nys")], nys[c("Line","Day")], mean)
nys.ag$lgrse <- aggregate(nys["lgr.nys"], nys[c("Line","Day")], se)[,3]

#' if SE == NA (if there is only 1 data point), set SE to 0
ypd.ag[is.na(ypd.ag$lgrse),]$lgrse <- 0

nys.ag[is.na(nys.ag$lgrse),]$lgrse <- 0

#'subset Assay 1 and Assay 2
ypd1 <- subset(ypd.ag, Day==1)
ypd2 <- subset(ypd.ag, Day==2)

nys1 <- subset(nys.ag, Day==1)
nys2 <- subset(nys.ag, Day==2)

#'only include strains that were run in both Assay 1 and Assay 2
ypd1 <- subset(ypd1, Line%in%ypd2$Line)
ypd2 <- subset(ypd2, Line%in%ypd1$Line)

nys1 <- subset(nys1, Line%in%nys2$Line)
nys2 <- subset(nys2, Line%in%nys1$Line)

#####SIGN TEST######
#'plot mean maximum growth rate data
#'Assay 1 (pre-growth in YPD) in red
#'Assay 2 (pre-growth in 0.5uM nystatin) in black
par(mfrow=c(2,1), mar=c(3,3,1,1), oma=c(2,2,2,2))

#first in Nystatin2
plot(seq_along(nys1$Line), nys1$lgr.nys, ylim=c(0, range(nys1$lgr.nys+nys1$lgrse)[2]), yaxt="n", ylab="", xlab="",xaxt="n", col="red", pch=16)
points(seq_along(nys2$Line), nys2$lgr.nys, col="black", pch=16)
axis(2,las=2, labels=TRUE)
mtext("Max Growth Rate in Nystatin2",2, line=3)
arrows(seq_along(nys1$Line),nys1$lgr.nys+nys1$lgrse,seq_along(nys1$Line),nys1$lgr.nys-nys1$lgrse, length=0, col="red")
arrows(seq_along(nys2$Line),nys2$lgr.nys+nys2$lgrse,seq_along(nys2$Line),nys2$lgr.nys-nys2$lgrse, length=0, col="black")
axis(1, at=seq_along(nys1$Line) ,labels=nys1$Line,las=2)
axis(1, at=seq_along(nys2$Line) ,labels=nys2$Line,las=2)
legend("topleft", c("Assay 1","Assay 2"), fill=c("red","black"))

#then in YPD
plot(seq_along(ypd1$Line), ypd1$lgr.ypd, ylim=c(0, range(ypd1$lgr.ypd+ypd1$lgrse)[2]), yaxt="n", ylab="", xlab="",xaxt="n", col="red", pch=16)
points(seq_along(ypd2$Line), ypd2$lgr.ypd, col="black", pch=16)
axis(2,las=2, labels=TRUE)
mtext("Max Growth Rate in YPD",2, line=3)
arrows(seq_along(ypd1$Line),ypd1$lgr.ypd+ypd1$lgrse,seq_along(ypd1$Line),ypd1$lgr.ypd-ypd1$lgrse, length=0, col="red")
arrows(seq_along(ypd2$Line),ypd2$lgr.ypd+ypd2$lgrse,seq_along(ypd2$Line),ypd2$lgr.ypd-ypd2$lgrse, length=0, col="black")
axis(1, at=seq_along(ypd1$Line) ,labels=ypd1$Line,las=2)
axis(1, at=seq_along(ypd2$Line) ,labels=ypd2$Line,las=2)
legend("topleft", c("Assay 1","Assay 2"), fill=c("red","black"))

#'do a sign test (binomial test) to see if prob=0.5 that max growth rate is higher in Assay 2 than Assay 1
higherin2.ypd <- sum(ypd2$lgr.ypd>ypd1$lgr.ypd)
higherin2.nys <- sum(nys2$lgr.nys>nys1$lgr.nys)

higherin2.ypd.test <- binom.test(higherin2.ypd, length(ypd1$lgr.ypd), p=0.5)
higherin2.nys.test <- binom.test(higherin2.nys, length(nys1$lgr.nys), p=0.5)
higherin2.ypd.test$p.value
#0.770867
higherin2.ypd.test$estimate
#probability of success  0.5319149 
higherin2.nys.test$p.value
# 0.5600646
higherin2.nys.test$estimate
#probability of success 0.4468085 

#####PAIRED T-TEST#####
#'find differences between the growth rates in Assay 2 and Assay 1
dypd <- ypd2$lgr.ypd-ypd1$lgr.ypd
dnys <- nys2$lgr.nys-nys1$lgr.nys

#'do a paired t-test to see if Assay 2-Assay 1 difference is not equal to 0
dequal.ypd.test <- t.test(ypd2$lgr.ypd,ypd1$lgr.ypd, alternative="two.sided", mu=0, paired=TRUE)
dequal.nys.test <- t.test(nys2$lgr.nys,nys1$lgr.nys, alternative="two.sided", mu=0, paired=TRUE)
dequal.ypd.test$p.value
#0.04957481
dequal.ypd.test$estimate
#mean of the differences  0.0088505 
dequal.nys.test$p.value
# 0.241047
dequal.nys.test$estimate
#mean of the differences  -0.004778246 



