#####LOAD IN DATA#####
#'load in normalized data
nys.norm <- read.csv("GrowthRateAssays/data_output/NormalizedNys2.csv", sep=",", as.is=TRUE)
ypd.norm <- read.csv("GrowthRateAssays/data_output/NormalizedYPD.csv", sep=",", as.is=TRUE)

#####MAKE OMIT COLUMN FOR LOW GROWTH#####
#'make new col for omitting
nys.norm$omit <- NA
ypd.norm$omit <- NA

#'omit wells OD<0.3 from Assay 1
#'wells 1,6,37,58,61,121,175,181,194 - for nystatin2
om <- c(1,6,37,58,61,121,175,181,194)
nys.norm$omit[nys.norm$Well %in% om & nys.norm$Day == 1] <- 1
#'in ypd - have to account for upside down plate
#'wells in YPD plate 2 were upside down - fix this
om <- c(1,6,37,58,61,180,126,120,107)
ypd.norm$omit[ypd.norm$Well %in% om & ypd.norm$Day == 1] <- 1

#'omit wells OD<0.3 from Assay 2
#'wells 66,144,181
om <- c(66,144,181)
nys.norm$omit[nys.norm$Well %in% om & nys.norm$Day == 2] <- 1
ypd.norm$omit[ypd.norm$Well %in% om & ypd.norm$Day == 2] <- 1

#'omit wells OD<0.3 from Assay 3
#'wells 17, 41, 57, 127, 187, 198
om <- c(17,41,57,127,187,198)
nys.norm$omit[nys.norm$Well %in% om & nys.norm$Day == 3] <- 1
ypd.norm$omit[ypd.norm$Well %in% om & ypd.norm$Day == 3] <- 1

#'omit wells OD<0.3 from Assay 4
#'only wells <0.4 are 812d - leave these alone
#'64/24, 35/75

#'#'omit wells OD<0.3 from Assay 5
#'only wells <0.4 are 812d - leave these
#'don't have data anyways

#'omit wells OD<0.3 from Assay 6
#'none to omit

#'omit wells OD<0.3 from Assay 7
#'none to omit

#####DETECT OUTLIERS#####
library("outliers")

getoutliers <- function (data){
  #'do outlier tests on all data that wasn't omitted
  #'do grubbs test for all (to find one outlier)
  lines <- levels(as.factor(data$Line))
  p <- c()
  alt <- c()
  
  for (i in lines){
    sub <- subset(data, Line==i & is.na(omit))
    test.1 <- grubbs.test(sub$lgr.norm, type=10, two.sided=TRUE)
    p <- c(p, test.1$p.value)
    alt <- c(alt, test.1$alternative)
  }
  
  #'now go through p-values to find those <0.05
  sig <- c()
  for (i in 1:length(p)){
    if (length(p[[i]])==1){
      if (p[[i]]<0.05){
        sig <- c(sig, i)
      }  
    }
    else{
      if(p[[i]][1]<0.05){
        sig <- c(sig, list(c(i,1)))
      }
      if (p[[i]][2]<0.05){
        sig <- c(sig, list(c(i,2)))
      }
    }
  }
  
  #'find lines with significant outlier
  sig.lines <- c()
  for (i in 1:length(sig)){
    sig.lines <- c(sig.lines, lines[sig[[i]][1]])
  }
  
  #'find the alternative hypothesis (and therefore the outliers)
  sig.alt <- c()
  for (i in 1:length(sig)){
    if (length(sig[[i]])==1){
      sig.alt <- c(sig.alt, alt[sig[[i]][1]])
    }
    else{
      sig.alt <- c(sig.alt, alt[[sig[[i]][1]]][sig[[i]][2]])
    }
  }
  
  #'make new col for outliers
  data$out <- NA
  
  for (i in 1:length(sig.alt)){
    if (i %in% grep("and", sig.alt)){
      iline <- grep(sig.lines[i],data$Line)
      ival <- grep(substring(sig.alt[i], 2,9), data$lgr.norm)
      ival2 <- grep(substring(sig.alt[i], 28,35), data$lgr.norm)
      ind <- intersect(iline, ival)
      ind2 <- intersect(iline, ival2)
      data$out[ind] <- 1
      data$out[ind2] <- 1
    }
    else{
      iline <- grep(sig.lines[i],data$Line)
      ival <- grep(substring(sig.alt[i], 16,23), data$lgr.norm)
      ind <- intersect(iline, ival)
      data$out[ind] <- 1
    }
  }
  return(data)
}

nys.norm <- getoutliers(nys.norm)
ypd.norm <- getoutliers(ypd.norm)

#####PLOT WITH OUTLIERS AND OMITTED HIGHLIGHTED#####
#'plot stripchart without omits
stripchart(nys.norm[is.na(nys.norm$omit)&nys.norm$Line!="Medium",]$lgr.nys ~ nys.norm[is.na(nys.norm$omit)&nys.norm$Line!="Medium",]$Line, vertical=TRUE, pch=16, las=2, ylab="Maximum Growth Rate in Nystatin2")
stripchart(ypd.norm[is.na(ypd.norm$omit)&ypd.norm$Line!="Medium",]$lgr.ypd ~ ypd.norm[is.na(ypd.norm$omit)&ypd.norm$Line!="Medium",]$Line, vertical=TRUE, pch=16, las=2, ylab="Maximum Growth Rate in YPD")

plot.order <- c("a", "8a", "12a", "45a", "58a", "812a", "845a", "858a", "1245a", "1258a", "4558a", "l", "8l", "12l", "45l", "58l", "812l", "845l", "858l", "1245l", "1258l", "4558l", "d", "8t", "8m", "12t", "12m", "45t", "45m", "58t", "58m", "812t", "8m12t", "12m8t", "812d", "845t", "8m45t", "45m8t", "845d", "858t", "8m58t", "58m8t", "858d", "1245t", "12m45t", "45m12t", "1245d",  "1258t", "12m58t", "58m12t", "1258d", "4558t", "45m58t", "58m45t", "4558d", "Medium")

#reorder data frame by plot.order
nys.norm$Line <- factor(nys.norm$Line, levels = plot.order)
nys.norm <- nys.norm[order(nys.norm$Line),]

ypd.norm$Line <- factor(ypd.norm$Line, levels = plot.order)
ypd.norm <- ypd.norm[order(ypd.norm$Line),]

#'subset those that shouldn't be excluded because of standardization problem or because they're an outlier
nys.omit <- subset(nys.norm, is.na(omit))
nys.out <- subset(nys.norm, is.na(omit)&is.na(out))
ypd.omit <- subset(ypd.norm, is.na(omit))
ypd.out <- subset(ypd.norm, is.na(omit)&is.na(out))

#'find means of full data and data without outliers/omitted
nys.out.ag <- aggregate(nys.out["lgr.norm"], nys.out[c("Line")], mean)
nys.ag <- aggregate(nys.norm["lgr.norm"], nys.norm[c("Line")], mean)

ypd.out.ag <- aggregate(ypd.out["lgr.norm"], ypd.out[c("Line")], mean)
ypd.ag <- aggregate(ypd.norm["lgr.norm"], ypd.norm[c("Line")], mean)

#'plot omitted data in yellow, outliers in orange, data excluding outliers/omitted in black
#'full data means in blue, data without outliers/omitted means in red
#'NYSTATIN2
stripchart(nys.norm$lgr.norm~nys.norm$Line, vertical = TRUE, pch=16, las=2, col="yellow")
points(nys.omit$Line, nys.omit$lgr.norm, col="orange", pch=16)
points(nys.out$Line, nys.out$lgr.norm, col="black", pch=16)
points(seq_along(nys.ag$Line), nys.ag$lgr.norm, col="blue", pch="-", cex=1.5)
points(seq_along(nys.out.ag$Line), nys.out.ag$lgr.norm, col="red", pch="-", cex=2)

#'YPD
stripchart(ypd.norm$lgr.norm~ypd.norm$Line, vertical = TRUE, pch=16, las=2, col="yellow")
points(ypd.omit$Line, ypd.omit$lgr.norm, col="orange", pch=16)
points(ypd.out$Line, ypd.out$lgr.norm, col="black", pch=16)
points(seq_along(ypd.ag$Line), ypd.ag$lgr.norm, col="blue", pch="-", cex=1.5)
points(seq_along(ypd.out.ag$Line), ypd.out.ag$lgr.norm, col="red", pch="-", cex=2)

#####WRITE OUTPUT OF OUTLIER DETECTION#####
write.csv(nys.norm, "GrowthRateAssays/data_output/OmitOutlierNys2.csv", row.names=FALSE)
write.csv(ypd.norm, "GrowthRateAssays/data_output/OmitOutlierYPD.csv", row.names=FALSE)