#####SET UP DATA#####
#'load absorbance data
d <- read.csv("SterolAssay/SterolAbs.csv", sep=",", as.is=TRUE, header=TRUE)

#'make vectors with all wavelengths measured at, strain names and colours those strains will be coloured
wavelengths <- seq(200, 300, 3)
lines <- unique(d$Line)
cols <- c("#BEBEBE", "#87CEEB", "#000000", "#008B00", "#000000", "#8B0000", "#000000", "#000000", "#FFD700", "#000000", "#000000")

#####PLOT THE BLANK - NBM8:12-2#####
plot(wavelengths, seq(-0.05,3,length=length(wavelengths)), type="n", xlab="Wavelength", ylab="Absorbance")
lines(wavelengths, d[d$Line=="NBM812"&d$Rep==2,4:37], col=cols[which(lines=="NBM812")])   
text(200,0.5,pos=4,offset=-0.2, "812-2")

#'omit blank - NBM8:12 rep2
d <- d[!(d$Line=="NBM812"&d$Rep==2),]

#####PLOT ALL STRAINS BY CROSS - AVERAGES#####
#'define standard error function
#'NOTE: var(x) is the sample variance
se <- function(x) sqrt(var(x)/length(x))

#'write function to find averages and se
abs.avg <- function(data, line){
  sub <- subset(data, Line==line)
  avg <- colMeans(sub[,4:37], na.rm = TRUE)
  d.se <- apply(sub[,4:37], 2, se)
  avgse <- cbind(avg, d.se)
  avgse <- as.data.frame(avgse)
  return(avgse)
}

#'find averages and se
avgby <- abs.avg(d, "BY4741")
avg8 <- abs.avg(d, "NBM8")
avg12 <- abs.avg(d, "NBM12")
avg45 <- abs.avg(d, "NBM45")
avg58 <- abs.avg(d, "NBM58")
avg812 <- abs.avg(d, "NBM812")
avg845 <- abs.avg(d, "NBM845")
avg858 <- abs.avg(d, "NBM858")
avg1245 <- abs.avg(d, "NBM1245")
avg1258 <- abs.avg(d, "NBM1258")
avg4558 <- abs.avg(d, "NBM4558")

#'Generates Fig 6
pdf("Figures/SterolPlot.Fig6.pdf", width=8, height=3, family="ArialMT", pointsize=10)
par(mfrow=c(1,6), mar=c(2.25,0.25,0.75,1), oma=c(2.25,4,0,0))
labels<-c("200","220","240","260","280","300")
#NBM45 NBM58 - erg3 erg5
plot(wavelengths, seq(-0.05,1.5,length=length(wavelengths)), type="n", xlab="", ylab="", las=2, xaxt="n")
axis(1, tick=T, labels=FALSE)
text(c(200,220,240,260,280,300), -0.19, srt=-45, adj=0 , labels=labels, xpd=TRUE)
axis(2, labels=FALSE)
lines(wavelengths, avgby$avg, col=cols[which(lines=="BY4741")], lwd=2)
arrows(wavelengths, avgby$avg+avgby$d.se, wavelengths, avgby$avg-avgby$d.se, col=cols[which(lines=="BY4741")], length=0)
lines(wavelengths, avg45$avg, col=cols[which(lines=="NBM45")], lwd=2)
arrows(wavelengths, avg45$avg+avg45$d.se, wavelengths, avg45$avg-avg45$d.se, col=cols[which(lines=="NBM45")], length=0)
lines(wavelengths, avg58$avg, col=cols[which(lines=="NBM58")], lwd=2)
arrows(wavelengths, avg58$avg+avg58$d.se, wavelengths, avg58$avg-avg58$d.se, col=cols[which(lines=="NBM58")], length=0)
lines(wavelengths, avg4558$avg, col=cols[which(lines=="NBM4558")], lwd=2)
arrows(wavelengths, avg4558$avg+avg4558$d.se, wavelengths, avg4558$avg-avg4558$d.se, col=cols[which(lines=="NBM4558")], length=0)
text(205,1.45,pos=4,offset=-0.2, "erg3", cex=1.5, col=cols[which(lines=="NBM45")])
text(205,1.45,pos=4,offset=2.7, "erg5", cex=1.5, col=cols[which(lines=="NBM58")])
#NBM8 NBM45 - erg3 erg6 
plot(wavelengths, seq(-0.05,1.5,length=length(wavelengths)), type="n", xlab="", ylab="", las=2, xaxt="n", yaxt="n")
axis(1, tick=T, labels=FALSE)
text(c(200,220,240,260,280,300), -0.19, srt=-45, adj=0 , labels=labels, xpd=TRUE)
axis(2, labels=FALSE)
lines(wavelengths, avgby$avg, col=cols[which(lines=="BY4741")], lwd=2)
arrows(wavelengths, avgby$avg+avgby$d.se, wavelengths, avgby$avg-avgby$d.se, col=cols[which(lines=="BY4741")], length=0)
lines(wavelengths, avg8$avg, col=cols[which(lines=="NBM8")], lwd=2)
arrows(wavelengths, avg8$avg+avg8$d.se, wavelengths, avg8$avg-avg8$d.se, col=cols[which(lines=="NBM8")], length=0)
lines(wavelengths, avg45$avg, col=cols[which(lines=="NBM45")], lwd=2)
arrows(wavelengths, avg45$avg+avg45$d.se, wavelengths, avg45$avg-avg45$d.se, col=cols[which(lines=="NBM45")], length=0)
lines(wavelengths, avg845$avg, col=cols[which(lines=="NBM845")], lwd=2)
arrows(wavelengths, avg845$avg+avg845$d.se, wavelengths, avg845$avg-avg845$d.se, col=cols[which(lines=="NBM845")], length=0)
text(205,1.45,pos=4,offset=-0.2, "erg3", cex=1.5, col=cols[which(lines=="NBM45")])
text(205,1.45,pos=4,offset=2.7, "erg6", cex=1.5, col=cols[which(lines=="NBM8")])
#NBM12 NBM45 - erg3 erg7
plot(wavelengths, seq(-0.05,1.5,length=length(wavelengths)), type="n", xlab="", ylab="", las=2, xaxt="n", yaxt="n")
axis(1, tick=T, labels=FALSE)
text(c(200,220,240,260,280,300), -0.19, srt=-45, adj=0 , labels=labels, xpd=TRUE)
axis(2, labels=FALSE)
lines(wavelengths, avgby$avg, col=cols[which(lines=="BY4741")], lwd=2)
arrows(wavelengths, avgby$avg+avgby$d.se, wavelengths, avgby$avg-avgby$d.se, col=cols[which(lines=="BY4741")], length=0)
lines(wavelengths, avg12$avg, col=cols[which(lines=="NBM12")], lwd=2)
arrows(wavelengths, avg12$avg+avg12$d.se, wavelengths, avg12$avg-avg12$d.se, col=cols[which(lines=="NBM12")], length=0)
lines(wavelengths, avg45$avg, col=cols[which(lines=="NBM45")], lwd=2)
arrows(wavelengths, avg45$avg+avg45$d.se, wavelengths, avg45$avg-avg45$d.se, col=cols[which(lines=="NBM45")], length=0)
lines(wavelengths, avg1245$avg, col=cols[which(lines=="NBM1245")], lwd=2)
arrows(wavelengths, avg1245$avg+avg1245$d.se, wavelengths, avg1245$avg-avg1245$d.se, col=cols[which(lines=="NBM1245")], length=0)
text(205,1.45,pos=4,offset=-0.2, "erg3", cex=1.5, col=cols[which(lines=="NBM45")])
text(205,1.45,pos=4,offset=2.7, "erg7", cex=1.5, col=cols[which(lines=="NBM12")])
#NBM8 NBM58 - erg5 erg6
plot(wavelengths, seq(-0.05,1.5,length=length(wavelengths)), type="n", xlab="", ylab="", las=2, xaxt="n", yaxt="n")
axis(1, tick=T, labels=FALSE)
text(c(200,220,240,260,280,300), -0.19, srt=-45, adj=0 , labels=labels, xpd=TRUE)
axis(2, labels=FALSE)
lines(wavelengths, avgby$avg, col=cols[which(lines=="BY4741")], lwd=2)
arrows(wavelengths, avgby$avg+avgby$d.se, wavelengths, avgby$avg-avgby$d.se, col=cols[which(lines=="BY4741")], length=0)
lines(wavelengths, avg8$avg, col=cols[which(lines=="NBM8")], lwd=2)
arrows(wavelengths, avg8$avg+avg8$d.se, wavelengths, avg8$avg-avg8$d.se, col=cols[which(lines=="NBM8")], length=0)
lines(wavelengths, avg58$avg, col=cols[which(lines=="NBM58")], lwd=2)
arrows(wavelengths, avg58$avg+avg58$d.se, wavelengths, avg58$avg-avg58$d.se, col=cols[which(lines=="NBM58")], length=0)
lines(wavelengths, avg858$avg, col=cols[which(lines=="NBM858")], lwd=2)
arrows(wavelengths, avg858$avg+avg858$d.se, wavelengths, avg858$avg-avg858$d.se, col=cols[which(lines=="NBM858")], length=0)
text(205,1.45,pos=4,offset=-0.2, "erg5", cex=1.5, col=cols[which(lines=="NBM58")])
text(205,1.45,pos=4,offset=2.7, "erg6", cex=1.5, col=cols[which(lines=="NBM8")])
#NBM12 NBM58 - erg5 erg7
plot(wavelengths, seq(-0.05,1.5,length=length(wavelengths)), type="n", xlab="", ylab="", las=2, xaxt="n", yaxt="n")
axis(1, tick=T, labels=FALSE)
text(c(200,220,240,260,280,300), -0.19, srt=-45, adj=0 , labels=labels, xpd=TRUE)
axis(2, labels=FALSE)
lines(wavelengths, avgby$avg, col=cols[which(lines=="BY4741")], lwd=2)
arrows(wavelengths, avgby$avg+avgby$d.se, wavelengths, avgby$avg-avgby$d.se, col=cols[which(lines=="BY4741")], length=0)
lines(wavelengths, avg12$avg, col=cols[which(lines=="NBM12")], lwd=2)
arrows(wavelengths, avg12$avg+avg12$d.se, wavelengths, avg12$avg-avg12$d.se, col=cols[which(lines=="NBM12")], length=0)
lines(wavelengths, avg58$avg, col=cols[which(lines=="NBM58")], lwd=2)
arrows(wavelengths, avg58$avg+avg58$d.se, wavelengths, avg58$avg-avg58$d.se, col=cols[which(lines=="NBM58")], length=0)
lines(wavelengths, avg1258$avg, col=cols[which(lines=="NBM1258")], lwd=2)
arrows(wavelengths, avg1258$avg+avg1258$d.se, wavelengths, avg1258$avg-avg1258$d.se, col=cols[which(lines=="NBM1258")], length=0)
text(205,1.45,pos=4,offset=-0.2, "erg5", cex=1.5, col=cols[which(lines=="NBM58")])
text(205,1.45,pos=4,offset=2.7, "erg7", cex=1.5, col=cols[which(lines=="NBM12")])
#NBM8 NBM12 - erg6 erg7
plot(wavelengths, seq(-0.05,1.5,length=length(wavelengths)), type="n", xlab="", ylab="", las=2, xaxt="n", yaxt="n")
axis(1, tick=T, labels=FALSE)
text(c(200,220,240,260,280,300), -0.19, srt=-45, adj=0 , labels=labels, xpd=TRUE)
axis(2, labels=FALSE)
lines(wavelengths, avgby$avg, col=cols[which(lines=="BY4741")], lwd=2)
arrows(wavelengths, avgby$avg+avgby$d.se, wavelengths, avgby$avg-avgby$d.se, col=cols[which(lines=="BY4741")], length=0)
lines(wavelengths, avg8$avg, col=cols[which(lines=="NBM8")], lwd=2)
arrows(wavelengths, avg8$avg+avg8$d.se, wavelengths, avg8$avg-avg8$d.se, col=cols[which(lines=="NBM8")], length=0)
lines(wavelengths, avg12$avg, col=cols[which(lines=="NBM12")], lwd=2)
arrows(wavelengths, avg12$avg+avg12$d.se, wavelengths, avg12$avg-avg12$d.se, col=cols[which(lines=="NBM12")], length=0)
lines(wavelengths, avg812$avg, col=cols[which(lines=="NBM812")], lwd=2)
arrows(wavelengths, avg812$avg+avg812$d.se, wavelengths, avg812$avg-avg812$d.se, col=cols[which(lines=="NBM812")], length=0)
text(205,1.45,pos=4,offset=-0.2, "erg6", cex=1.5, col=cols[which(lines=="NBM8")])
text(205,1.45,pos=4,offset=2.7, "erg7", cex=1.5, col=cols[which(lines=="NBM12")])

#'add text
mtext("Wavelength (nm)", side=1, line=0.75, outer=TRUE, cex=1.2)
mtext("Absorbance", side=2, line=2.25, outer=TRUE, cex=1.2)

dev.off()
system("open Figures/SterolPlot.Fig6.pdf")
