library("dplyr")
library(ggplot2)
library(colorspace)

#'define standard error function 
#'NOTE: var(x) is the sample variance
se <- function(x) sqrt(var(x)/length(x))

#####SET UP DATA#####
#'load well map information
wells <- read.csv("ToleranceAssay/Tolerance_wells.csv", sep=",", header=TRUE, as.is=TRUE)

#'add well numbers to the map that go across the box
for (i in 1:length(wells$Well)){
  if (substr(wells$Well[i],1,1) == "A"){
    wells$WellNum[i] <- as.numeric(substring(wells$Well[i],2))
  }
  if (substr(wells$Well[i],1,1) == "B"){
    wells$WellNum[i] <- as.numeric(substring(wells$Well[i],2))+12
  }
  if (substr(wells$Well[i],1,1) == "C"){
    wells$WellNum[i] <- as.numeric(substring(wells$Well[i],2))+24
  }
  if (substr(wells$Well[i],1,1) == "D"){
    wells$WellNum[i] <- as.numeric(substring(wells$Well[i],2))+36
  }
  if (substr(wells$Well[i],1,1) == "E"){
    wells$WellNum[i] <- as.numeric(substring(wells$Well[i],2))+48
  }
  if (substr(wells$Well[i],1,1) == "F"){
    wells$WellNum[i] <- as.numeric(substring(wells$Well[i],2))+60
  }
  if (substr(wells$Well[i],1,1) == "G"){
    wells$WellNum[i] <- as.numeric(substring(wells$Well[i],2))+72
  }
  if (substr(wells$Well[i],1,1) == "H"){
    wells$WellNum[i] <- as.numeric(substring(wells$Well[i],2))+84
  }   
}

#'load the data (optical density measured after 24 hours of growth)
data <- read.csv("ToleranceAssay/ToleranceOD24.csv", header=FALSE, as.is=TRUE, sep=",")

#'create a sequence of numbers with the order in which the boxes will be read
s <- seq(1:96)
or <- c(1,13,25,37,49,61,73,85)
order <- s[or]
for (i in 1:11){
  order <- c(order, s[or+i])
}

#'split the data by replicate (and therefore by map)
data1 <- data[1:100,]
data2 <- data[101:200,]
data3 <- data[201:300,]
data4 <- data[301:399,]

#get all of the concentrations of nystatin
ident <- grep("Raw", data1[,1], value=TRUE)
levels <- gsub("Raw Data (", "", ident, fixed=TRUE)
levels <- substr(levels, 1, nchar(levels)-3)

#get rid of the two empty rows that precede the data
data1 <- data1[complete.cases(data1),]
data2 <- data2[complete.cases(data2),]
data3 <- data3[complete.cases(data3),]
data4 <- data4[complete.cases(data4),]

#make one long vector of optical density measurements
od1 <- as.vector(as.matrix(data1))
od2 <- as.vector(as.matrix(data2))
od3 <- as.vector(as.matrix(data3))
od4 <- as.vector(as.matrix(data4))

#make long vectors for the well numbers, line identities and concentrations
#split wells file into 4
wells1 <- subset(wells, Plate==1)
wells2 <- subset(wells, Plate==2)
wells3 <- subset(wells, Plate==3)
wells4 <- subset(wells, Plate==4)
#order the wells within them
wells1<-wells1[order(wells1$WellNum),]
wells2<-wells2[order(wells2$WellNum),]
wells3<-wells3[order(wells3$WellNum),]
wells4<-wells4[order(wells4$WellNum),]

#'create long vector of well numbers (1-96) but reading plates down so that it's in the same order as the OD vector (ex:1,13,25,37...multiplied by # of plates)
t.wells <- c(rep(wells1$WellNum[order][1:8], length(ident)),rep(wells1$WellNum[order][9:16],length(ident)),rep(wells1$WellNum[order][17:24],length(ident)),rep(wells1$WellNum[order][25:32],length(ident)),rep(wells1$WellNum[order][33:40],length(ident)),rep(wells1$WellNum[order][41:48],length(ident)),rep(wells1$WellNum[order][49:56],length(ident)),rep(wells1$WellNum[order][57:64],length(ident)),rep(wells1$WellNum[order][65:72],length(ident)),rep(wells1$WellNum[order][73:80],length(ident)),rep(wells1$WellNum[order][81:88],length(ident)),rep(wells1$WellNum[order][89:96],length(ident)))

#'create long vectors of line identities
t.line.1 <- c(rep(wells1$Line[order][1:8],length(ident)),rep(wells1$Line[order][9:16],length(ident)),rep(wells1$Line[order][17:24],length(ident)),rep(wells1$Line[order][25:32],length(ident)),rep(wells1$Line[order][33:40],length(ident)),rep(wells1$Line[order][41:48],length(ident)),rep(wells1$Line[order][49:56],length(ident)),rep(wells1$Line[order][57:64],length(ident)),rep(wells1$Line[order][65:72],length(ident)),rep(wells1$Line[order][73:80],length(ident)),rep(wells1$Line[order][81:88],length(ident)),rep(wells1$Line[order][89:96],length(ident)))
t.line.2 <- c(rep(wells2$Line[order][1:8],length(ident)),rep(wells2$Line[order][9:16],length(ident)),rep(wells2$Line[order][17:24],length(ident)),rep(wells2$Line[order][25:32],length(ident)),rep(wells2$Line[order][33:40],length(ident)),rep(wells2$Line[order][41:48],length(ident)),rep(wells2$Line[order][49:56],length(ident)),rep(wells2$Line[order][57:64],length(ident)),rep(wells2$Line[order][65:72],length(ident)),rep(wells2$Line[order][73:80],length(ident)),rep(wells2$Line[order][81:88],length(ident)),rep(wells2$Line[order][89:96],length(ident)))
t.line.3 <- c(rep(wells3$Line[order][1:8],length(ident)),rep(wells3$Line[order][9:16],length(ident)),rep(wells3$Line[order][17:24],length(ident)),rep(wells3$Line[order][25:32],length(ident)),rep(wells3$Line[order][33:40],length(ident)),rep(wells3$Line[order][41:48],length(ident)),rep(wells3$Line[order][49:56],length(ident)),rep(wells3$Line[order][57:64],length(ident)),rep(wells3$Line[order][65:72],length(ident)),rep(wells3$Line[order][73:80],length(ident)),rep(wells3$Line[order][81:88],length(ident)),rep(wells3$Line[order][89:96],length(ident)))
t.line.4 <- c(rep(wells4$Line[order][1:8],length(ident)),rep(wells4$Line[order][9:16],length(ident)),rep(wells4$Line[order][17:24],length(ident)),rep(wells4$Line[order][25:32],length(ident)),rep(wells4$Line[order][33:40],length(ident)),rep(wells4$Line[order][41:48],length(ident)),rep(wells4$Line[order][49:56],length(ident)),rep(wells4$Line[order][57:64],length(ident)),rep(wells4$Line[order][65:72],length(ident)),rep(wells4$Line[order][73:80],length(ident)),rep(wells4$Line[order][81:88],length(ident)),rep(wells4$Line[order][89:96],length(ident)))

#'create long vector of concentrations of nystatin
t.levels <- c(rep(c(rep(as.numeric(levels), each=8)),12))

#make a single dataframe for each replicate/plate map containing all of the information 
od1 <- data.frame(t.wells, t.line.1, t.levels, od=as.numeric(as.character(od1)))
od2 <- data.frame(t.wells, t.line.2, t.levels, od=as.numeric(as.character(od2)))
od3 <- data.frame(t.wells, t.line.3, t.levels, od=as.numeric(as.character(od3)))
od4 <- data.frame(t.wells, t.line.4, t.levels, od=as.numeric(as.character(od4)))

#now merge them all back together
names(od1)[2] <- "t.line"
names(od2)[2] <- "t.line"
names(od3)[2] <- "t.line"
names(od4)[2] <- "t.line"

od1$Rep <- 1
od2$Rep <- 2
od3$Rep <- 3
od4$Rep <- 4

tol <- bind_rows(od1, od2, od3, od4)

#'make a column where can mark wells with lower volume as omit
#'wells where noticed lower vol at 24hr: 
#'NOTE: plates are denoted "concentration" - "replicate"
#'16-4: 1D 12D, 64-4: 1D 12D, 4-4: 1E 12E, 
#'1-2: 1E 12E, 32-2: 1D 12D, 
#'0-3: 1D 12D, 1-3: 1E 12E, 2-3: 1-E 12-E, 32-3: 12E 1E
#'128-1: 1E 12E 
tol$omit <- NA

#'16-4: 1D 12D
tol[tol$t.levels==16&tol$Rep==4&tol$t.wells==37,]$omit <- 1 
tol[tol$t.levels==16&tol$Rep==4&tol$t.wells==48,]$omit <- 1 
#'64-4: 1D 12D
tol[tol$t.levels==64&tol$Rep==4&tol$t.wells==37,]$omit <- 1 
tol[tol$t.levels==64&tol$Rep==4&tol$t.wells==48,]$omit <- 1 
#'4-4: 1E 12E, 
tol[tol$t.levels==4&tol$Rep==4&tol$t.wells==49,]$omit <- 1 
tol[tol$t.levels==4&tol$Rep==4&tol$t.wells==60,]$omit <- 1 
#'1-2: 1E 12E, 
tol[tol$t.levels==1&tol$Rep==2&tol$t.wells==49,]$omit <- 1 
tol[tol$t.levels==1&tol$Rep==2&tol$t.wells==60,]$omit <- 1 
#'32-2: 1D 12D,t.levels==32, Rep==2, 37, 48
tol[tol$t.levels==32&tol$Rep==2&tol$t.wells==37,]$omit <- 1 
tol[tol$t.levels==32&tol$Rep==2&tol$t.wells==48,]$omit <- 1 
#'0-3: 1D 12D, t.levels==0, Rep==3, 37, 48
tol[tol$t.levels==0&tol$Rep==3&tol$t.wells==37,]$omit <- 1 
tol[tol$t.levels==0&tol$Rep==3&tol$t.wells==48,]$omit <- 1 
#'1-3: 1E 12E, t.levels==1, Rep==3, 49, 60
tol[tol$t.levels==1&tol$Rep==3&tol$t.wells==49,]$omit <- 1 
tol[tol$t.levels==1&tol$Rep==3&tol$t.wells==60,]$omit <- 1 
#'2-3: 1-E 12-E, t.levels==2, Rep==3, 49, 60
tol[tol$t.levels==2&tol$Rep==3&tol$t.wells==49,]$omit <- 1 
tol[tol$t.levels==2&tol$Rep==3&tol$t.wells==60,]$omit <- 1 
#'32-3: 12E 1E t.levels==32, Rep==3, 49, 60
tol[tol$t.levels==32&tol$Rep==3&tol$t.wells==49,]$omit <- 1 
tol[tol$t.levels==32&tol$Rep==3&tol$t.wells==60,]$omit <- 1 
#'128-1: 1E 12E t.levels==128, Rep==1, 49, 60
tol[tol$t.levels==128&tol$Rep==1&tol$t.wells==49,]$omit <- 1 
tol[tol$t.levels==128&tol$Rep==1&tol$t.wells==60,]$omit <- 1 

#'create a new column with common names for a and alpha haploids ("linenomat")
tol$linenomat <- as.character(tol$t.line)
for (i in 1:length(tol$linenomat)){
  if(substring(tol$linenomat, nchar(tol$linenomat))[i] =="a"|substring(tol$linenomat, nchar(tol$linenomat))[i] =="l"){ 
    substring(tol$linenomat, nchar(tol$linenomat))[i] <- "h"
  }
}

####SUBTRACT BACKGROUND OD AT EACH LEVEL##########
k<-0
avg<-c()
env<-c()
for (i in unique(tol$t.levels)){
  k <- k+1
  sub <- subset(tol, t.levels==i)
  sub.0 <- subset(sub, t.line=="Medium")
  avg[k] <- mean(sub.0$od)
  env[k] <- i
}

for (k in 1:length(env)){
  tol$ODn[tol$t.levels==env[k]] <- tol$od[tol$t.levels==env[k]]-avg[k]
}

#'write output of organized ODs after 24 hours (including with background subtracted)
write.csv(tol, "ToleranceAssay/Tolerance_sorted.csv", row.names=FALSE)

#'just remove all omits
tol <- tol[is.na(tol$omit),]

#####CHECK MATING TYPE NOT SIGNIFICANTLY DIFFERENT#####
#'make a data file with only the haploid data
haps <- tol[grep("h", tol$linenomat),]
#'add mating type data in a new column
haps$mat <- 0
haps$mat[grep("l", haps$t.line)] <- "l"
haps$mat[grep("a", haps$t.line)] <- "a"

#'look at the data in boxplots
for (i in unique(haps$t.levels)){
  sub <- subset(haps, t.levels==i)
  print(ggplot(sub, aes(x=linenomat, y=ODn, color=mat)) +
    geom_boxplot(position=position_dodge(0.8))+
    geom_jitter(position=position_dodge(0.8))+
    labs(title=paste(i,"uM nystatin")))
}

#'linear model with mating type, concentration of nystatin and strain identity as fixed effects
haps.mat.model <- lm(ODn ~ mat + t.levels + linenomat, data=haps)
summary(haps.mat.model)
anova(haps.mat.model)

#####T-TESTS#####
#'Do all t-tests between double mutants and parent single mutants
#'write function to do all t-tests for a pair
pair.ttests <- function(sub, lines){
x <- c(2,3)
y <- c(4,4)

linex <- c()
liney <- c()
t <- c()
df <- c()
p <- c()
estx <- c()
esty <- c()
level <- c()

for (i in unique(sub$t.levels)){
  for (j in 1:2){
    subx <- sub[sub$linenomat==lines[x[j]]&sub$t.levels==i,]
    suby <- sub[sub$linenomat==lines[y[j]]&sub$t.levels==i,]
    test <- t.test(subx$ODn, suby$ODn)  
    linex <- c(linex, lines[x[j]])
    liney <- c(liney, lines[y[j]])
    t <- c(t, test$statistic)
    df <- c(df, test$parameter)
    p <- c(p, test$p.value)
    estx <- c(estx, test$estimate[1])
    esty <- c(esty, test$estimate[2])
    level <- c(level, i)
  }
}

ttest <- data.frame(linex, liney, level, estx, esty, t, df, p, sig=p<0.05)
return(ttest)
}

#'run t-tests on haploids
#'nbm8:12 - erg6 erg7
lines.812.h <- c("h", "8h", "12h", "812h")
tol.812.h <- tol[tol$linenomat%in%lines.812.h,]
ttests.812 <- pair.ttests(tol.812.h, lines.812.h)

#'nbm8:45 - erg3 erg6
lines.845.h <- c("h", "8h", "45h", "845h")
tol.845.h <- tol[tol$linenomat%in%lines.845.h,]
ttests.845 <- pair.ttests(tol.845.h, lines.845.h)

#'nbm8:58 - erg5 erg6
lines.858.h <- c("h", "8h", "58h", "858h")
tol.858.h <- tol[tol$linenomat%in%lines.858.h,]
ttests.858 <- pair.ttests(tol.858.h, lines.858.h)

#'nbm12:45 - erg3 erg7
lines.1245.h <- c("h", "12h", "45h", "1245h")
tol.1245.h <- tol[tol$linenomat%in%lines.1245.h,]
ttests.1245 <- pair.ttests(tol.1245.h, lines.1245.h)

#'nbm12:58 - erg5 erg7
lines.1258.h <- c("h", "12h", "58h", "1258h")
tol.1258.h <- tol[tol$linenomat%in%lines.1258.h,]
ttests.1258 <- pair.ttests(tol.1258.h, lines.1258.h)

#'nbm45:58 - erg3 erg5
lines.4558.h <- c("h", "45h", "58h", "4558h")
tol.4558.h <- tol[tol$linenomat%in%lines.4558.h,]
ttests.4558 <- pair.ttests(tol.4558.h, lines.4558.h)

##########PLOT HAPLOIDS###########
#'plot all points on graph for each pair
#'put ancestor as an arrow on the y-axis
#'single mutants on sides 
#'double mutant in middle 
#'lines connecting single mutants and double mutant lty=1 if sig diff, lty=3 if not sig
#'use all available data except low vol wells - arrows/points are averages
#'all haploid data

#'make colour palette
colours <- rainbow_hcl(10)
values <- c(unique(tol$t.levels))

#'nbm8:12 - erg6 erg7
#'find the mean and se in each concentration
tol.812.h.ag <- aggregate(tol.812.h[c("ODn")], tol.812.h[c("linenomat","t.levels")], mean)
tol.812.h.ag$se <- aggregate(tol.812.h["ODn"], tol.812.h[c("linenomat","t.levels")], se)[,3]

#'add locations for plotting
tol.812.h.ag$loc <- NA
tol.812.h.ag[tol.812.h.ag$linenomat=="h",]$loc <- 0
tol.812.h.ag[tol.812.h.ag$linenomat=="8h",]$loc <- 1
tol.812.h.ag[tol.812.h.ag$linenomat=="12h",]$loc <- 3
tol.812.h.ag[tol.812.h.ag$linenomat=="812h",]$loc <- 2

#'add colours
tol.812.h.ag$colr <- NA
tol.812.h.ag$colg <- NA
tol.812.h.ag$colb <- NA
for (i in 1:length(tol.812.h.ag$ODn)){
  tol.812.h.ag$colr[i] <- col2rgb(colours[which(values==tol.812.h.ag$t.levels[i])])[1]
  tol.812.h.ag$colg[i] <- col2rgb(colours[which(values==tol.812.h.ag$t.levels[i])])[2]
  tol.812.h.ag$colb[i] <- col2rgb(colours[which(values==tol.812.h.ag$t.levels[i])])[3]
}

#'add lty values - lty=1 if significantly different from single mutant, lty=3 if not
tol.812.h.ag$lty <- NA
for (i in unique(tol.812.h.ag$t.levels)){
  sub <- subset(ttests.812, level==i)
  if(sub$sig[1]==TRUE){
    tol.812.h.ag[tol.812.h.ag$t.levels==i&tol.812.h.ag$linenomat=="8h",]$lty <- 1
  }
  else{tol.812.h.ag[tol.812.h.ag$t.levels==i&tol.812.h.ag$linenomat=="8h",]$lty <- 3}
  if(sub$sig[2]==TRUE){
    tol.812.h.ag[tol.812.h.ag$t.levels==i&tol.812.h.ag$linenomat=="12h",]$lty <- 1
  }
  else{tol.812.h.ag[tol.812.h.ag$t.levels==i&tol.812.h.ag$linenomat=="12h",]$lty <- 3}
}

#'nbm8:45 - erg3 erg6
#'find the mean and se in each concentration
tol.845.h.ag <- aggregate(tol.845.h[c("ODn")], tol.845.h[c("linenomat","t.levels")], mean)
tol.845.h.ag$se <- aggregate(tol.845.h["ODn"], tol.845.h[c("linenomat","t.levels")], se)[,3]

#'add locations for plotting
tol.845.h.ag$loc <- NA
tol.845.h.ag[tol.845.h.ag$linenomat=="h",]$loc <- 0
tol.845.h.ag[tol.845.h.ag$linenomat=="8h",]$loc <- 3
tol.845.h.ag[tol.845.h.ag$linenomat=="45h",]$loc <- 1
tol.845.h.ag[tol.845.h.ag$linenomat=="845h",]$loc <- 2

#'add colours
tol.845.h.ag$colr <- NA
tol.845.h.ag$colg <- NA
tol.845.h.ag$colb <- NA
for (i in 1:length(tol.845.h.ag$ODn)){
  tol.845.h.ag$colr[i] <- col2rgb(colours[which(values==tol.845.h.ag$t.levels[i])])[1]
  tol.845.h.ag$colg[i] <- col2rgb(colours[which(values==tol.845.h.ag$t.levels[i])])[2]
  tol.845.h.ag$colb[i] <- col2rgb(colours[which(values==tol.845.h.ag$t.levels[i])])[3]
}

#'add lty values - lty=1 if significantly different from single mutant, lty=3 if not
tol.845.h.ag$lty <- NA
for (i in unique(tol.845.h.ag$t.levels)){
  sub <- subset(ttests.845, level==i)
  if(sub$sig[1]==TRUE){
    tol.845.h.ag[tol.845.h.ag$t.levels==i&tol.845.h.ag$linenomat=="8h",]$lty <- 1
  }
  else{tol.845.h.ag[tol.845.h.ag$t.levels==i&tol.845.h.ag$linenomat=="8h",]$lty <- 3}
  if(sub$sig[2]==TRUE){
    tol.845.h.ag[tol.845.h.ag$t.levels==i&tol.845.h.ag$linenomat=="45h",]$lty <- 1
  }
  else{tol.845.h.ag[tol.845.h.ag$t.levels==i&tol.845.h.ag$linenomat=="45h",]$lty <- 3}
}

#'nbm8:58 - erg5 erg6
#'find the mean and se in each concentration
tol.858.h.ag <- aggregate(tol.858.h[c("ODn")], tol.858.h[c("linenomat","t.levels")], mean)
tol.858.h.ag$se <- aggregate(tol.858.h["ODn"], tol.858.h[c("linenomat","t.levels")], se)[,3]

#'add locations for plotting
tol.858.h.ag$loc <- NA
tol.858.h.ag[tol.858.h.ag$linenomat=="h",]$loc <- 0
tol.858.h.ag[tol.858.h.ag$linenomat=="8h",]$loc <- 3
tol.858.h.ag[tol.858.h.ag$linenomat=="58h",]$loc <- 1
tol.858.h.ag[tol.858.h.ag$linenomat=="858h",]$loc <- 2

#'add colours
tol.858.h.ag$colr <- NA
tol.858.h.ag$colg <- NA
tol.858.h.ag$colb <- NA
for (i in 1:length(tol.858.h.ag$ODn)){
  tol.858.h.ag$colr[i] <- col2rgb(colours[which(values==tol.858.h.ag$t.levels[i])])[1]
  tol.858.h.ag$colg[i] <- col2rgb(colours[which(values==tol.858.h.ag$t.levels[i])])[2]
  tol.858.h.ag$colb[i] <- col2rgb(colours[which(values==tol.858.h.ag$t.levels[i])])[3]
}

#'add lty values - lty=1 if significantly different from single mutant, lty=3 if not
tol.858.h.ag$lty <- NA
for (i in unique(tol.858.h.ag$t.levels)){
  sub <- subset(ttests.858, level==i)
  if(sub$sig[1]==TRUE){
    tol.858.h.ag[tol.858.h.ag$t.levels==i&tol.858.h.ag$linenomat=="8h",]$lty <- 1
  }
  else{tol.858.h.ag[tol.858.h.ag$t.levels==i&tol.858.h.ag$linenomat=="8h",]$lty <- 3}
  if(sub$sig[2]==TRUE){
    tol.858.h.ag[tol.858.h.ag$t.levels==i&tol.858.h.ag$linenomat=="58h",]$lty <- 1
  }
  else{tol.858.h.ag[tol.858.h.ag$t.levels==i&tol.858.h.ag$linenomat=="58h",]$lty <- 3}
}

#'nbm12:45 - erg3 erg7
#'find the mean and se in each concentration
tol.1245.h.ag <- aggregate(tol.1245.h[c("ODn")], tol.1245.h[c("linenomat","t.levels")], mean)
tol.1245.h.ag$se <- aggregate(tol.1245.h["ODn"], tol.1245.h[c("linenomat","t.levels")], se)[,3]

#'add locations for plotting
tol.1245.h.ag$loc <- NA
tol.1245.h.ag[tol.1245.h.ag$linenomat=="h",]$loc <- 0
tol.1245.h.ag[tol.1245.h.ag$linenomat=="12h",]$loc <- 3
tol.1245.h.ag[tol.1245.h.ag$linenomat=="45h",]$loc <- 1
tol.1245.h.ag[tol.1245.h.ag$linenomat=="1245h",]$loc <- 2

#'add colours
tol.1245.h.ag$colr <- NA
tol.1245.h.ag$colg <- NA
tol.1245.h.ag$colb <- NA
for (i in 1:length(tol.1245.h.ag$ODn)){
  tol.1245.h.ag$colr[i] <- col2rgb(colours[which(values==tol.1245.h.ag$t.levels[i])])[1]
  tol.1245.h.ag$colg[i] <- col2rgb(colours[which(values==tol.1245.h.ag$t.levels[i])])[2]
  tol.1245.h.ag$colb[i] <- col2rgb(colours[which(values==tol.1245.h.ag$t.levels[i])])[3]
}

#'add lty values - lty=1 if significantly different from single mutant, lty=3 if not
tol.1245.h.ag$lty <- NA
for (i in unique(tol.1245.h.ag$t.levels)){
  sub <- subset(ttests.1245, level==i)
  if(sub$sig[1]==TRUE){
    tol.1245.h.ag[tol.1245.h.ag$t.levels==i&tol.1245.h.ag$linenomat=="12h",]$lty <- 1
  }
  else{tol.1245.h.ag[tol.1245.h.ag$t.levels==i&tol.1245.h.ag$linenomat=="12h",]$lty <- 3}
  if(sub$sig[2]==TRUE){
    tol.1245.h.ag[tol.1245.h.ag$t.levels==i&tol.1245.h.ag$linenomat=="45h",]$lty <- 1
  }
  else{tol.1245.h.ag[tol.1245.h.ag$t.levels==i&tol.1245.h.ag$linenomat=="45h",]$lty <- 3}
}

#'nbm12:58 - erg5 erg7
#'find the mean and se in each concentration
tol.1258.h.ag <- aggregate(tol.1258.h[c("ODn")], tol.1258.h[c("linenomat","t.levels")], mean)
tol.1258.h.ag$se <- aggregate(tol.1258.h["ODn"], tol.1258.h[c("linenomat","t.levels")], se)[,3]

#'add locations for plotting
tol.1258.h.ag$loc <- NA
tol.1258.h.ag[tol.1258.h.ag$linenomat=="h",]$loc <- 0
tol.1258.h.ag[tol.1258.h.ag$linenomat=="12h",]$loc <- 3
tol.1258.h.ag[tol.1258.h.ag$linenomat=="58h",]$loc <- 1
tol.1258.h.ag[tol.1258.h.ag$linenomat=="1258h",]$loc <- 2

#'add colours
tol.1258.h.ag$colr <- NA
tol.1258.h.ag$colg <- NA
tol.1258.h.ag$colb <- NA
for (i in 1:length(tol.1258.h.ag$ODn)){
  tol.1258.h.ag$colr[i] <- col2rgb(colours[which(values==tol.1258.h.ag$t.levels[i])])[1]
  tol.1258.h.ag$colg[i] <- col2rgb(colours[which(values==tol.1258.h.ag$t.levels[i])])[2]
  tol.1258.h.ag$colb[i] <- col2rgb(colours[which(values==tol.1258.h.ag$t.levels[i])])[3]
}

#'add lty values - lty=1 if significantly different from single mutant, lty=3 if not
tol.1258.h.ag$lty <- NA
for (i in unique(tol.1258.h.ag$t.levels)){
  sub <- subset(ttests.1258, level==i)
  if(sub$sig[1]==TRUE){
    tol.1258.h.ag[tol.1258.h.ag$t.levels==i&tol.1258.h.ag$linenomat=="12h",]$lty <- 1
  }
  else{tol.1258.h.ag[tol.1258.h.ag$t.levels==i&tol.1258.h.ag$linenomat=="12h",]$lty <- 3}
  if(sub$sig[2]==TRUE){
    tol.1258.h.ag[tol.1258.h.ag$t.levels==i&tol.1258.h.ag$linenomat=="58h",]$lty <- 1
  }
  else{tol.1258.h.ag[tol.1258.h.ag$t.levels==i&tol.1258.h.ag$linenomat=="58h",]$lty <- 3}
}

#'nbm45:58 - erg3 erg5
#'find the mean and se in each concentration
tol.4558.h.ag <- aggregate(tol.4558.h[c("ODn")], tol.4558.h[c("linenomat","t.levels")], mean)
tol.4558.h.ag$se <- aggregate(tol.4558.h["ODn"], tol.4558.h[c("linenomat","t.levels")], se)[,3]

#'add locations for plotting
tol.4558.h.ag$loc <- NA
tol.4558.h.ag[tol.4558.h.ag$linenomat=="h",]$loc <- 0
tol.4558.h.ag[tol.4558.h.ag$linenomat=="45h",]$loc <- 1
tol.4558.h.ag[tol.4558.h.ag$linenomat=="58h",]$loc <- 3
tol.4558.h.ag[tol.4558.h.ag$linenomat=="4558h",]$loc <- 2

#'add colours
tol.4558.h.ag$colr <- NA
tol.4558.h.ag$colg <- NA
tol.4558.h.ag$colb <- NA
for (i in 1:length(tol.4558.h.ag$ODn)){
  tol.4558.h.ag$colr[i] <- col2rgb(colours[which(values==tol.4558.h.ag$t.levels[i])])[1]
  tol.4558.h.ag$colg[i] <- col2rgb(colours[which(values==tol.4558.h.ag$t.levels[i])])[2]
  tol.4558.h.ag$colb[i] <- col2rgb(colours[which(values==tol.4558.h.ag$t.levels[i])])[3]
}

#'add lty values - lty=1 if significantly different from single mutant, lty=3 if not
tol.4558.h.ag$lty <- NA
for (i in unique(tol.4558.h.ag$t.levels)){
  sub <- subset(ttests.4558, level==i)
  if(sub$sig[1]==TRUE){
    tol.4558.h.ag[tol.4558.h.ag$t.levels==i&tol.4558.h.ag$linenomat=="45h",]$lty <- 1
  }
  else{tol.4558.h.ag[tol.4558.h.ag$t.levels==i&tol.4558.h.ag$linenomat=="45h",]$lty <- 3}
  if(sub$sig[2]==TRUE){
    tol.4558.h.ag[tol.4558.h.ag$t.levels==i&tol.4558.h.ag$linenomat=="58h",]$lty <- 1
  }
  else{tol.4558.h.ag[tol.4558.h.ag$t.levels==i&tol.4558.h.ag$linenomat=="58h",]$lty <- 3}
}

#'Generates Fig 5
pdf("Figures/HapTolPlot.Fig5.pdf", width=6, height=4, family="ArialMT", pointsize=10)

par(mfrow=c(2,3), mar=c(3,1,0,0.5), oma=c(0,4.5,1,4))

spl <- split(tol.845.h.ag, tol.845.h.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, bg="black", las=2)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[3])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3) ,labels=c("erg3", "erg3 erg6", "erg6") ,las=1)
for (i in 1:length(wt$t.levels)){
  arrows(0.8, wt$ODn[i], 0.67, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

spl <- split(tol.1245.h.ag, tol.1245.h.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, bg="black", yaxt="n")
axis(side=2, labels=F)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[3])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3) ,labels=c("erg3", "erg3 erg7", "erg7") ,las=1)
for (i in 1:length(wt$t.levels)){
  arrows(0.8, wt$ODn[i], 0.67, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

spl <- split(tol.812.h.ag, tol.812.h.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, bg="black", yaxt="n")
axis(side=2, labels=F)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[3])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3) ,labels=c("erg6", "erg6 erg7", "erg7") ,las=1)
for (i in 1:length(wt$t.levels)){
  arrows(0.8, wt$ODn[i], 0.67, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

spl <- split(tol.4558.h.ag, tol.4558.h.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, bg="black", las=2)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[3])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3) ,labels=c("erg3", "erg3 erg5", "erg5") ,las=1)
for (i in 1:length(wt$t.levels)){
  arrows(0.8, wt$ODn[i], 0.67, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

spl <- split(tol.858.h.ag, tol.858.h.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, bg="black", yaxt="n")
axis(side=2, labels=F)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[3])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3) ,labels=c("erg5", "erg5 erg6", "erg6") ,las=1)
for (i in 1:length(wt$t.levels)){
  arrows(0.8, wt$ODn[i], 0.67, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

spl <- split(tol.1258.h.ag, tol.1258.h.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, bg="black", yaxt="n")
axis(side=2, labels=F)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[3])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3) ,labels=c("erg5", "erg5 erg7", "erg7") ,las=1)
for (i in 1:length(wt$t.levels)){
  arrows(0.8, wt$ODn[i], 0.67, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

legend(3.4,1.65, as.character(values), fill=colours, xpd=NA, bty="n", cex=1)
mtext("Optical Density at 24hr", side=2, line= 2, adj=0.5, cex=1,  outer=TRUE) 

#'open the plot
dev.off()
system("open Figures/HapTolPlot.Fig5.pdf")

#####PLOT HOMOZYGOUS DIPLOIDS#####
#'no t-tests
#'plot all points on graph for each pair
#'put ancestor as an arrow on the y-axis
#'single mutants on sides 
#'double mutant in middle 
#'lines connecting single mutants and double mutant all lty=1
#'use all available data except low vol wells - arrows/points are averages
#'all homozygous diploid data

#'find the mean and se in each concentration
tol.ag <- aggregate(tol[c("ODn")], tol[c("linenomat","t.levels")], mean)
tol.ag$se <- aggregate(tol["ODn"], tol[c("linenomat","t.levels")], se)[,3]

#'add locations for plotting - only ancestor and double
tol.ag$loc <- NA
tol.ag[tol.ag$linenomat%in%c("d","h"),]$loc <- 0
tol.ag[tol.ag$linenomat%in%c("812d","812h","845d","845h","858d","858h","1245d","1245h","1258d","1258h","4558d","4558h"),]$loc <- 2

#'add colours
tol.ag$colr <- NA
tol.ag$colg <- NA
tol.ag$colb <- NA
for (i in 1:length(tol.ag$ODn)){
  tol.ag$colr[i] <- col2rgb(colours[which(values==tol.ag$t.levels[i])])[1]
  tol.ag$colg[i] <- col2rgb(colours[which(values==tol.ag$t.levels[i])])[2]
  tol.ag$colb[i] <- col2rgb(colours[which(values==tol.ag$t.levels[i])])[3]
}

#'add lty values - all lty=1
tol.ag$lty <- 1

#'nbm8:12 - erg6 erg7
lines.812.m <- c("d", "8m", "12m", "812d")
tol.812.m.ag <- tol.ag[tol.ag$linenomat%in%lines.812.m,]
tol.812.m.ag[tol.812.m.ag$linenomat=="8m",]$loc <- 1
tol.812.m.ag[tol.812.m.ag$linenomat=="12m",]$loc <- 3

#'nbm8:45 - erg3 erg6
lines.845.m <- c("d", "8m", "45m", "845d")
tol.845.m.ag <- tol.ag[tol.ag$linenomat%in%lines.845.m,]
tol.845.m.ag[tol.845.m.ag$linenomat=="8m",]$loc <- 3
tol.845.m.ag[tol.845.m.ag$linenomat=="45m",]$loc <- 1

#'nbm8:58 - erg5 erg6
lines.858.m <- c("d", "8m", "58m", "858d")
tol.858.m.ag <- tol.ag[tol.ag$linenomat%in%lines.858.m,]
tol.858.m.ag[tol.858.m.ag$linenomat=="8m",]$loc <- 3
tol.858.m.ag[tol.858.m.ag$linenomat=="58m",]$loc <- 1

#'nbm12:45 - erg3 erg7
lines.1245.m <- c("d", "12m", "45m", "1245d")
tol.1245.m.ag <- tol.ag[tol.ag$linenomat%in%lines.1245.m,]
tol.1245.m.ag[tol.1245.m.ag$linenomat=="12m",]$loc <- 3
tol.1245.m.ag[tol.1245.m.ag$linenomat=="45m",]$loc <- 1

#'nbm12:58 - erg5 erg7
lines.1258.m <- c("d", "12m", "58m", "1258d")
tol.1258.m.ag <- tol.ag[tol.ag$linenomat%in%lines.1258.m,]
tol.1258.m.ag[tol.1258.m.ag$linenomat=="12m",]$loc <- 3
tol.1258.m.ag[tol.1258.m.ag$linenomat=="58m",]$loc <- 1

#'nbm45:58 - erg3 erg5
lines.4558.m <- c("d", "45m", "58m", "4558d")
tol.4558.m.ag <- tol.ag[tol.ag$linenomat%in%lines.4558.m,]
tol.4558.m.ag[tol.4558.m.ag$linenomat=="45m",]$loc <- 1
tol.4558.m.ag[tol.4558.m.ag$linenomat=="58m",]$loc <- 3

#'Generates S3 Fig
pdf("Figures/DipMTolPlot.S3Fig.pdf", width=6, height=4, family="ArialMT", pointsize=10)

par(mfrow=c(2,3), mar=c(3,1,0,0.5), oma=c(0,4.5,1,4))

spl <- split(tol.845.m.ag, tol.845.m.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, bg="black", las=2)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[3])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3) ,labels=c("erg3", "erg3 erg6", "erg6") ,las=1)
for (i in 1:length(wt$t.levels)){
  arrows(0.8, wt$ODn[i], 0.67, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

spl <- split(tol.1245.m.ag, tol.1245.m.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, bg="black", yaxt="n")
axis(side=2, labels=F)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[3])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3) ,labels=c("erg3", "erg3 erg7", "erg7") ,las=1)
for (i in 1:length(wt$t.levels)){
  arrows(0.8, wt$ODn[i], 0.67, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

spl <- split(tol.812.m.ag, tol.812.m.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, bg="black", yaxt="n")
axis(side=2, labels=F)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[3])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3) ,labels=c("erg6", "erg6 erg7", "erg7") ,las=1)
for (i in 1:length(wt$t.levels)){
  arrows(0.8, wt$ODn[i], 0.67, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

spl <- split(tol.4558.m.ag, tol.4558.m.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, bg="black", las=2)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[3])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3) ,labels=c("erg3", "erg3 erg5", "erg5") ,las=1)
for (i in 1:length(wt$t.levels)){
  arrows(0.8, wt$ODn[i], 0.67, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

spl <- split(tol.858.m.ag, tol.858.m.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, bg="black", yaxt="n")
axis(side=2, labels=F)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[3])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3) ,labels=c("erg5", "erg5 erg6", "erg6") ,las=1)
for (i in 1:length(wt$t.levels)){
  arrows(0.8, wt$ODn[i], 0.67, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

spl <- split(tol.1258.m.ag, tol.1258.m.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, bg="black", yaxt="n")
axis(side=2, labels=F)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,3.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[3])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3) ,labels=c("erg5", "erg5 erg7", "erg7") ,las=1)
for (i in 1:length(wt$t.levels)){
  arrows(0.8, wt$ODn[i], 0.67, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

legend(3.4,1.65, as.character(values), fill=colours, xpd=NA, bty="n", cex=1)
mtext("Optical Density at 24hr", side=2, line= 2, adj=0.5, cex=1,  outer=TRUE) 

#'open the plot
dev.off()
system("open Figures/DipMTolPlot.S3Fig.pdf")

#####PLOT ALL DIPLOIDS#####
#’no t-tests
#'plot all points on graph for each pair
#'put ancestor as an arrow on the y-axis
#’lines connecting single mutants and double mutant all lty=1
#'use all available data except low vol wells - arrows/points are averages
#'all heterozygous homozygous diploid data
#'double heterozygote in the middle 
#'single heterozygotes next
#'single homozygotes next
#'homozygous for one mutations and heterozygous for the other next
#'double homozygote on either end

#'add locations for plotting - only ancestor, double heterozygote and double homozygote
tol.ag$loc <- NA
tol.ag[tol.ag$linenomat%in%c("d","h"),]$loc <- 0
tol.ag[tol.ag$linenomat%in%c("812t","845t","858t","1245t","1258t","4558t"),]$loc <- 5
tol.ag[tol.ag$linenomat%in%c("812d","845d","858d","1245d","1258d","4558d"),]$loc <- 1
#'will have to manually plot double homozygote on the other side

#'add lty values - all lty=1
tol.ag$lty <- 1

#'nbm8:12 - erg6 erg7
lines.812.t <- c("d", "12m8t","8t","812t","12t","8m12t","8m","12m", "812d")
tol.812.t.ag <- tol.ag[tol.ag$linenomat%in%lines.812.t,]
tol.812.t.ag[tol.812.t.ag$linenomat=="8m12t",]$loc <- 2
tol.812.t.ag[tol.812.t.ag$linenomat=="8m",]$loc <- 3
tol.812.t.ag[tol.812.t.ag$linenomat=="8t",]$loc <- 4
tol.812.t.ag[tol.812.t.ag$linenomat=="12t",]$loc <- 6
tol.812.t.ag[tol.812.t.ag$linenomat=="12m",]$loc <- 7
tol.812.t.ag[tol.812.t.ag$linenomat=="12m8t",]$loc <- 8

#'nbm8:45 - erg3 erg6
lines.845.t <- c("d", "45m8t","8t","845t","45t","8m45t","8m","45m","845d")
tol.845.t.ag <- tol.ag[tol.ag$linenomat%in%lines.845.t,]
tol.845.t.ag[tol.845.t.ag$linenomat=="8m45t",]$loc <- 8
tol.845.t.ag[tol.845.t.ag$linenomat=="8m",]$loc <- 7
tol.845.t.ag[tol.845.t.ag$linenomat=="8t",]$loc <- 6
tol.845.t.ag[tol.845.t.ag$linenomat=="45t",]$loc <- 4
tol.845.t.ag[tol.845.t.ag$linenomat=="45m",]$loc <- 3
tol.845.t.ag[tol.845.t.ag$linenomat=="45m8t",]$loc <- 2

#'nbm8:58 - erg5 erg6
lines.858.t <- c("d", "58m8t","8t","858t","58t","8m58t", "8m","58m","858d")
tol.858.t.ag <- tol.ag[tol.ag$linenomat%in%lines.858.t,]
tol.858.t.ag[tol.858.t.ag$linenomat=="8m58t",]$loc <- 8
tol.858.t.ag[tol.858.t.ag$linenomat=="8m",]$loc <- 7
tol.858.t.ag[tol.858.t.ag$linenomat=="8t",]$loc <- 6
tol.858.t.ag[tol.858.t.ag$linenomat=="58t",]$loc <- 4
tol.858.t.ag[tol.858.t.ag$linenomat=="58m",]$loc <- 3
tol.858.t.ag[tol.858.t.ag$linenomat=="58m8t",]$loc <- 2

#'nbm12:45 - erg3 erg7
lines.1245.t <- c("d", "45m12t","12t","1245t","45t","12m45t", "12m","45m","1245d")
tol.1245.t.ag <- tol.ag[tol.ag$linenomat%in%lines.1245.t,]
tol.1245.t.ag[tol.1245.t.ag$linenomat=="12m45t",]$loc <- 8
tol.1245.t.ag[tol.1245.t.ag$linenomat=="12m",]$loc <- 7
tol.1245.t.ag[tol.1245.t.ag$linenomat=="12t",]$loc <- 6
tol.1245.t.ag[tol.1245.t.ag$linenomat=="45t",]$loc <- 4
tol.1245.t.ag[tol.1245.t.ag$linenomat=="45m",]$loc <- 3
tol.1245.t.ag[tol.1245.t.ag$linenomat=="45m12t",]$loc <- 2

#'nbm12:58 - erg5 erg7
lines.1258.t <- c("d", "58m12t","12t","1258t","58t","12m58t", "12m","58m","1258d")
tol.1258.t.ag <- tol.ag[tol.ag$linenomat%in%lines.1258.t,]
tol.1258.t.ag[tol.1258.t.ag$linenomat=="12m58t",]$loc <- 8
tol.1258.t.ag[tol.1258.t.ag$linenomat=="12m",]$loc <- 7
tol.1258.t.ag[tol.1258.t.ag$linenomat=="12t",]$loc <- 6
tol.1258.t.ag[tol.1258.t.ag$linenomat=="58t",]$loc <- 4
tol.1258.t.ag[tol.1258.t.ag$linenomat=="58m",]$loc <- 3
tol.1258.t.ag[tol.1258.t.ag$linenomat=="58m12t",]$loc <- 2

#'nbm45:58 - erg3 erg5
lines.4558.t <- c("d", "58m45t","45t","4558t","58t","45m58t","45m","58m","4558d")
tol.4558.t.ag <- tol.ag[tol.ag$linenomat%in%lines.4558.t,]
tol.4558.t.ag[tol.4558.t.ag$linenomat=="45m58t",]$loc <- 2
tol.4558.t.ag[tol.4558.t.ag$linenomat=="45m",]$loc <- 3
tol.4558.t.ag[tol.4558.t.ag$linenomat=="45t",]$loc <- 4
tol.4558.t.ag[tol.4558.t.ag$linenomat=="58t",]$loc <- 6
tol.4558.t.ag[tol.4558.t.ag$linenomat=="58m",]$loc <- 7
tol.4558.t.ag[tol.4558.t.ag$linenomat=="58m45t",]$loc <- 8

#'Generates S5 Fig
pdf("Figures/DipTTolPlot.S5Fig.pdf", width=8.5, height=4, family="ArialMT", pointsize=10)

par(mfrow=c(3,2), mar=c(3.5,1,0,0.5), oma=c(0,4.5,1,4))

spl <- split(tol.845.t.ag, tol.845.t.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,9.25), pch=16, bg="black", las=2, xlab=NA)
polygon(c(0.43, 0.43, 3.5, 3.5), c(-0.14, 1.14,1.14,-0.14), col="gray86", border=NA)
polygon(c(6.5, 6.5, 9.57, 9.57), c(-0.14, 1.14,1.14,-0.14), col="gray86", border=NA)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,9.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
points(c(rep.int(9,10)),mut[mut$linenomat=="845d",]$ODn, pch=16, col=rgb(mut[mut$linenomat=="845d",]$colr,mut[mut$linenomat=="845d",]$colg,mut[mut$linenomat=="845d",]$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[2])
  lines(sub2$loc[3:4], sub2$ODn[3:4], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[4])
  lines(sub2$loc[4:5], sub2$ODn[4:5], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[5:6], sub2$ODn[5:6], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[6:7], sub2$ODn[6:7], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[7:8], sub2$ODn[7:8], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(c(8,9), c(sub2$ODn[8],sub2$ODn[1]), col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
  arrows(9,sub2$ODn[1]+sub2$se[1],9,sub2$ODn[1]-sub2$se[1], length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3,4,5,6,7,8,9),labels=NA)
text(c(1,2,3,4,5,6,7,8,9),-0.45,labels=c("erg6/erg6","erg6/+   ", "   +/+   ", "   +/+   ", "erg6/+   ", "erg6/+   ", "erg6/erg6", "erg6/erg6","erg6/erg6") ,xpd=TRUE,cex=0.95)
text(c(1,2,3,4,5,6,7,8,9),-0.32, labels=c("erg3/erg3","erg3/erg3", "erg3/erg3", "erg3/+   ", "erg3/+   ", "   +/+   ", "   +/+   ", "erg3/+   ","erg3/erg3"), xpd=TRUE, cex=0.95)
for (i in 1:length(wt$t.levels)){
  arrows(0.66, wt$ODn[i], 0.44, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

spl <- split(tol.1245.t.ag, tol.1245.t.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,9.25), pch=16, bg="black", xlab=NA, yaxt="n")
axis(side=2, labels=F)
polygon(c(0.43, 0.43, 3.5, 3.5), c(-0.14, 1.14,1.14,-0.14), col="gray86", border=NA)
polygon(c(6.5, 6.5, 9.57, 9.57), c(-0.14, 1.14,1.14,-0.14), col="gray86", border=NA)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,9.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
points(c(rep.int(9,10)),mut[mut$linenomat=="1245d",]$ODn, pch=16, col=rgb(mut[mut$linenomat=="1245d",]$colr,mut[mut$linenomat=="1245d",]$colg,mut[mut$linenomat=="1245d",]$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[2])
  lines(sub2$loc[3:4], sub2$ODn[3:4], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[4])
  lines(sub2$loc[4:5], sub2$ODn[4:5], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[5:6], sub2$ODn[5:6], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[6:7], sub2$ODn[6:7], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[7:8], sub2$ODn[7:8], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(c(8,9), c(sub2$ODn[8],sub2$ODn[1]), col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
  arrows(9,sub2$ODn[1]+sub2$se[1],9,sub2$ODn[1]-sub2$se[1], length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3,4,5,6,7,8,9),labels=NA)
text(c(1,2,3,4,5,6,7,8,9),-0.45,labels=c("erg7/erg7","erg7/+   ", "   +/+   ", "   +/+   ", "erg7/+   ", "erg7/+   ", "erg7/erg7", "erg7/erg7","erg7/erg7") ,xpd=TRUE,cex=0.95)
text(c(1,2,3,4,5,6,7,8,9),-0.32, labels=c("erg3/erg3","erg3/erg3", "erg3/erg3", "erg3/+   ", "erg3/+   ", "   +/+   ", "   +/+   ", "erg3/+   ","erg3/erg3"), xpd=TRUE, cex=0.95)
for (i in 1:length(wt$t.levels)){
  arrows(0.66, wt$ODn[i], 0.44, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

spl <- split(tol.812.t.ag, tol.812.t.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,9.25), pch=16, bg="black", las=2, xlab=NA)
polygon(c(0.43, 0.43, 3.5, 3.5), c(-0.14, 1.14,1.14,-0.14), col="gray86", border=NA)
polygon(c(6.5, 6.5, 9.57, 9.57), c(-0.14, 1.14,1.14,-0.14), col="gray86", border=NA)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,9.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
points(c(rep.int(9,10)),mut[mut$linenomat=="812d",]$ODn, pch=16, col=rgb(mut[mut$linenomat=="812d",]$colr,mut[mut$linenomat=="812d",]$colg,mut[mut$linenomat=="812d",]$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[2])
  lines(sub2$loc[3:4], sub2$ODn[3:4], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[4])
  lines(sub2$loc[4:5], sub2$ODn[4:5], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[5:6], sub2$ODn[5:6], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[6:7], sub2$ODn[6:7], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[7:8], sub2$ODn[7:8], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(c(8,9), c(sub2$ODn[8],sub2$ODn[1]), col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
  arrows(9,sub2$ODn[1]+sub2$se[1],9,sub2$ODn[1]-sub2$se[1], length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3,4,5,6,7,8,9),labels=NA)
text(c(1,2,3,4,5,6,7,8,9),-0.32,labels=c("erg6/erg6","erg6/erg6", "erg6/erg6", "erg6/+   ", "erg6/+   ", "   +/+   ", "   +/+   ", "erg6/+   ","erg6/erg6") ,xpd=TRUE,cex=0.95)
text(c(1,2,3,4,5,6,7,8,9),-0.45, labels=c("erg7/erg7","erg7/+   ", "   +/+   ", "   +/+   ", "erg7/+   ", "erg7/+   ", "erg7/erg7", "erg7/erg7","erg7/erg7"), xpd=TRUE, cex=0.95)
for (i in 1:length(wt$t.levels)){
  arrows(0.66, wt$ODn[i], 0.44, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

spl <- split(tol.4558.t.ag, tol.4558.t.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,9.25), pch=16, bg="black", xlab=NA, yaxt="n")
polygon(c(0.43, 0.43, 3.5, 3.5), c(-0.14, 1.14,1.14,-0.14), col="gray86", border=NA)
polygon(c(6.5, 6.5, 9.57, 9.57), c(-0.14, 1.14,1.14,-0.14), col="gray86", border=NA)
axis(side=2, labels=F)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,9.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
points(c(rep.int(9,10)),mut[mut$linenomat=="4558d",]$ODn, pch=16, col=rgb(mut[mut$linenomat=="4558d",]$colr,mut[mut$linenomat=="4558d",]$colg,mut[mut$linenomat=="4558d",]$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[2])
  lines(sub2$loc[3:4], sub2$ODn[3:4], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[4])
  lines(sub2$loc[4:5], sub2$ODn[4:5], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[5:6], sub2$ODn[5:6], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[6:7], sub2$ODn[6:7], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[7:8], sub2$ODn[7:8], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(c(8,9), c(sub2$ODn[8],sub2$ODn[1]), col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
  arrows(9,sub2$ODn[1]+sub2$se[1],9,sub2$ODn[1]-sub2$se[1], length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3,4,5,6,7,8,9),labels=NA)
text(c(1,2,3,4,5,6,7,8,9),-0.32,labels=c("erg3/erg3","erg3/erg3", "erg3/erg3", "erg3/+   ", "erg3/+   ", "   +/+   ", "   +/+   ","erg3/+   ","erg3/erg3") ,xpd=TRUE,cex=0.95)
text(c(1,2,3,4,5,6,7,8,9),-0.45, labels=c("erg5/erg5","erg5/+   ", "   +/+   ", "   +/+   ", "erg5/+   ", "erg5/+   ", "erg5/erg5","erg5/erg5","erg5/erg5"), xpd=TRUE, cex=0.95)
for (i in 1:length(wt$t.levels)){
  arrows(0.66, wt$ODn[i], 0.44, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

spl <- split(tol.858.t.ag, tol.858.t.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,9.25), pch=16, bg="black", las=2, xlab=NA)
polygon(c(0.43, 0.43, 3.5, 3.5), c(-0.14, 1.14,1.14,-0.14), col="gray86", border=NA)
polygon(c(6.5, 6.5, 9.57, 9.57), c(-0.14, 1.14,1.14,-0.14), col="gray86", border=NA)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,9.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
points(c(rep.int(9,10)),mut[mut$linenomat=="858d",]$ODn, pch=16, col=rgb(mut[mut$linenomat=="858d",]$colr,mut[mut$linenomat=="858d",]$colg,mut[mut$linenomat=="858d",]$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[2])
  lines(sub2$loc[3:4], sub2$ODn[3:4], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[4])
  lines(sub2$loc[4:5], sub2$ODn[4:5], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[5:6], sub2$ODn[5:6], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[6:7], sub2$ODn[6:7], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[7:8], sub2$ODn[7:8], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(c(8,9), c(sub2$ODn[8],sub2$ODn[1]), col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
  arrows(9,sub2$ODn[1]+sub2$se[1],9,sub2$ODn[1]-sub2$se[1], length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3,4,5,6,7,8,9),labels=NA)
text(c(1,2,3,4,5,6,7,8,9),-0.45,labels=c("erg6/erg6","erg6/+   ", "   +/+   ", "   +/+   ", "erg6/+   ", "erg6/+   ", "erg6/erg6", "erg6/erg6","erg6/erg6") ,xpd=TRUE,cex=0.95)
text(c(1,2,3,4,5,6,7,8,9),-0.32, labels=c("erg5/erg5","erg5/erg5", "erg5/erg5", "erg5/+   ", "erg5/+   ", "   +/+   ", "   +/+   ","erg5/+   ","erg5/erg5"), xpd=TRUE, cex=0.95)
for (i in 1:length(wt$t.levels)){
  arrows(0.66, wt$ODn[i], 0.44, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

spl <- split(tol.1258.t.ag, tol.1258.t.ag$loc==0)
mut <- spl$"FALSE"
wt <- spl$"TRUE"
mut <- mut[ order(mut$t.levels, mut$loc), ]
plot(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,9.25), pch=16, bg="black", las=2, xlab=NA, yaxt="n")
polygon(c(0.43, 0.43, 3.5, 3.5), c(-0.14, 1.14,1.14,-0.14), col="gray86", border=NA)
polygon(c(6.5, 6.5, 9.57, 9.57), c(-0.14, 1.14,1.14,-0.14), col="gray86", border=NA)
axis(side=2, labels=F)
points(mut$loc, mut$ODn, xaxt="n", ylim=c(-0.1,1.1), xlim=c(0.75,9.25), pch=16, col=rgb(mut$colr,mut$colg,mut$colb,maxColorValue=255), cex=1.5)
points(c(rep.int(9,10)),mut[mut$linenomat=="1258d",]$ODn, pch=16, col=rgb(mut[mut$linenomat=="1258d",]$colr,mut[mut$linenomat=="1258d",]$colg,mut[mut$linenomat=="1258d",]$colb,maxColorValue=255), cex=1.5)
for (i in mut$t.levels){
  sub2 <- subset(mut, t.levels==i)
  lines(sub2$loc[1:2], sub2$ODn[1:2], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[1])
  lines(sub2$loc[2:3], sub2$ODn[2:3], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[2])
  lines(sub2$loc[3:4], sub2$ODn[3:4], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[4])
  lines(sub2$loc[4:5], sub2$ODn[4:5], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[5:6], sub2$ODn[5:6], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[6:7], sub2$ODn[6:7], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(sub2$loc[7:8], sub2$ODn[7:8], col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  lines(c(8,9), c(sub2$ODn[8],sub2$ODn[1]), col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255), lty=sub2$lty[5])
  arrows(sub2$loc,sub2$ODn+sub2$se,sub2$loc,sub2$ODn-sub2$se, length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
  arrows(9,sub2$ODn[1]+sub2$se[1],9,sub2$ODn[1]-sub2$se[1], length=0, col=rgb(sub2$colr,sub2$colg,sub2$colb,maxColorValue=255))
}
axis(1, at=c(1,2,3,4,5,6,7,8,9),labels=NA)
text(c(1,2,3,4,5,6,7,8,9),-0.45,labels=c("erg7/erg7","erg7/+   ", "   +/+   ", "   +/+   ", "erg7/+   ", "erg7/+   ", "erg7/erg7", "erg7/erg7","erg7/erg7") ,xpd=TRUE,cex=0.95)
text(c(1,2,3,4,5,6,7,8,9),-0.32, labels=c("erg5/erg5","erg5/erg5", "erg5/erg5", "erg5/+   ", "erg5/+   ", "   +/+   ", "   +/+   ", "erg5/+   ","erg5/erg5"), xpd=TRUE, cex=0.95)
for (i in 1:length(wt$t.levels)){
  arrows(0.66, wt$ODn[i], 0.44, wt$ODn[i], xpd=TRUE, col=rgb(wt$colr[i],wt$colg[i],wt$colb[i],maxColorValue=255, alpha=200), lwd=1.5, length=0.04, angle=30)  
}

legend(9.6,3.2, as.character(values), fill=colours, xpd=NA, bty="n", cex=1)
mtext("Optical Density at 24hr", side=2, line= 2, adj=0.5, cex=1,  outer=TRUE) 

#'open the plot
dev.off()
system("open Figures/DipTTolPlot.S5Fig.pdf")
